<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'süüse: persuun, persuun, laacht hidjet an madel laacht hidj',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'süüse: persuun, persuun, laacht hidjet an madel hidj',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'süüse: persuun, persuun, laacht hidjet an madel jonk hidj',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'süüse: persuun, persuun, laacht hidjet an jonk hidj',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'süüse: persuun, persuun, madel laacht hidj an laacht hidjet',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'süüse: persuun, persuun, madel laacht hidj an madel hidj',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'süüse: persuun, persuun, madel laacht hidj an madel jonk hidj',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'süüse: persuun, persuun, madel laacht hidj an jonk hidj',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'süüse: persuun, persuun, madel hidj an laacht hidjet',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'süüse: persuun, persuun, madel hidj an madel laacht hidj',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'süüse: persuun, persuun, madel hidj an madel jonk hidj',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'süüse: persuun, persuun, madel hidj an jonk hidj',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'süüse: persuun, persuun, madel jonk hidj an laacht hidjet',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'süüse: persuun, persuun, madel jonk hidj an madel laacht hidj',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'süüse: persuun, persuun, madel jonk hidj an madel hidj',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'süüse: persuun, persuun, madel jonk hidj an jonk hidj',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'süüse: persuun, persuun, jonk hidj an laacht hidjet',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'süüse: persuun, persuun, jonk hidj an madel laacht hidj',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'süüse: persuun, persuun, jonk hidj an madel hidj',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'süüse: persuun, persuun, jonk hidj an madel jonk hidj',
    '👨🏻‍❤‍💋‍👨🏻' => 'süüse: maan, maan an laacht hidjet',
    '👨🏻‍❤‍💋‍👨🏼' => 'süüse: maan, maan, laacht hidjet an madel laacht hidj',
    '👨🏻‍❤‍💋‍👨🏽' => 'süüse: maan, maan, laacht hidjet an madel hidj',
    '👨🏻‍❤‍💋‍👨🏾' => 'süüse: maan, maan, laacht hidjet an madel jonk hidj',
    '👨🏻‍❤‍💋‍👨🏿' => 'süüse: maan, maan, laacht hidjet an jonk hidj',
    '👨🏼‍❤‍💋‍👨🏻' => 'süüse: maan, maan, madel laacht hidj an laacht hidjet',
    '👨🏼‍❤‍💋‍👨🏼' => 'süüse: maan, maan an madel laacht hidj',
    '👨🏼‍❤‍💋‍👨🏽' => 'süüse: maan, maan, madel laacht hidj an madel hidj',
    '👨🏼‍❤‍💋‍👨🏾' => 'süüse: maan, maan, madel laacht hidj an madel jonk hidj',
    '👨🏼‍❤‍💋‍👨🏿' => 'süüse: maan, maan, madel laacht hidj an jonk hidj',
    '👨🏽‍❤‍💋‍👨🏻' => 'süüse: maan, maan, madel hidj an laacht hidjet',
    '👨🏽‍❤‍💋‍👨🏼' => 'süüse: maan, maan, madel hidj an madel laacht hidj',
    '👨🏽‍❤‍💋‍👨🏽' => 'süüse: maan, maan an madel hidj',
    '👨🏽‍❤‍💋‍👨🏾' => 'süüse: maan, maan, madel hidj an madel jonk hidj',
    '👨🏽‍❤‍💋‍👨🏿' => 'süüse: maan, maan, madel hidj an jonk hidj',
    '👨🏾‍❤‍💋‍👨🏻' => 'süüse: maan, maan, madel jonk hidj an laacht hidjet',
    '👨🏾‍❤‍💋‍👨🏼' => 'süüse: maan, maan, madel jonk hidj an madel laacht hidj',
    '👨🏾‍❤‍💋‍👨🏽' => 'süüse: maan, maan, madel jonk hidj an madel hidj',
    '👨🏾‍❤‍💋‍👨🏾' => 'süüse: maan, maan an madel jonk hidj',
    '👨🏾‍❤‍💋‍👨🏿' => 'süüse: maan, maan, madel jonk hidj an jonk hidj',
    '👨🏿‍❤‍💋‍👨🏻' => 'süüse: maan, maan, jonk hidj an laacht hidjet',
    '👨🏿‍❤‍💋‍👨🏼' => 'süüse: maan, maan, jonk hidj an madel laacht hidj',
    '👨🏿‍❤‍💋‍👨🏽' => 'süüse: maan, maan, jonk hidj an madel hidj',
    '👨🏿‍❤‍💋‍👨🏾' => 'süüse: maan, maan, jonk hidj an madel jonk hidj',
    '👨🏿‍❤‍💋‍👨🏿' => 'süüse: maan, maan an jonk hidj',
    '👩🏻‍❤‍💋‍👨🏻' => 'süüse: wüf, maan an laacht hidjet',
    '👩🏻‍❤‍💋‍👨🏼' => 'süüse: wüf, maan, laacht hidjet an madel laacht hidj',
    '👩🏻‍❤‍💋‍👨🏽' => 'süüse: wüf, maan, laacht hidjet an madel hidj',
    '👩🏻‍❤‍💋‍👨🏾' => 'süüse: wüf, maan, laacht hidjet an madel jonk hidj',
    '👩🏻‍❤‍💋‍👨🏿' => 'süüse: wüf, maan, laacht hidjet an jonk hidj',
    '👩🏼‍❤‍💋‍👨🏻' => 'süüse: wüf, maan, madel laacht hidj an laacht hidjet',
    '👩🏼‍❤‍💋‍👨🏼' => 'süüse: wüf, maan an madel laacht hidj',
    '👩🏼‍❤‍💋‍👨🏽' => 'süüse: wüf, maan, madel laacht hidj an madel hidj',
    '👩🏼‍❤‍💋‍👨🏾' => 'süüse: wüf, maan, madel laacht hidj an madel jonk hidj',
    '👩🏼‍❤‍💋‍👨🏿' => 'süüse: wüf, maan, madel laacht hidj an jonk hidj',
    '👩🏽‍❤‍💋‍👨🏻' => 'süüse: wüf, maan, madel hidj an laacht hidjet',
    '👩🏽‍❤‍💋‍👨🏼' => 'süüse: wüf, maan, madel hidj an madel laacht hidj',
    '👩🏽‍❤‍💋‍👨🏽' => 'süüse: wüf, maan an madel hidj',
    '👩🏽‍❤‍💋‍👨🏾' => 'süüse: wüf, maan, madel hidj an madel jonk hidj',
    '👩🏽‍❤‍💋‍👨🏿' => 'süüse: wüf, maan, madel hidj an jonk hidj',
    '👩🏾‍❤‍💋‍👨🏻' => 'süüse: wüf, maan, madel jonk hidj an laacht hidjet',
    '👩🏾‍❤‍💋‍👨🏼' => 'süüse: wüf, maan, madel jonk hidj an madel laacht hidj',
    '👩🏾‍❤‍💋‍👨🏽' => 'süüse: wüf, maan, madel jonk hidj an madel hidj',
    '👩🏾‍❤‍💋‍👨🏾' => 'süüse: wüf, maan an madel jonk hidj',
    '👩🏾‍❤‍💋‍👨🏿' => 'süüse: wüf, maan, madel jonk hidj an jonk hidj',
    '👩🏿‍❤‍💋‍👨🏻' => 'süüse: wüf, maan, jonk hidj an laacht hidjet',
    '👩🏿‍❤‍💋‍👨🏼' => 'süüse: wüf, maan, jonk hidj an madel laacht hidj',
    '👩🏿‍❤‍💋‍👨🏽' => 'süüse: wüf, maan, jonk hidj an madel hidj',
    '👩🏿‍❤‍💋‍👨🏾' => 'süüse: wüf, maan, jonk hidj an madel jonk hidj',
    '👩🏿‍❤‍💋‍👨🏿' => 'süüse: wüf, maan an jonk hidj',
    '👩🏻‍❤‍💋‍👩🏻' => 'süüse: wüf, wüf an laacht hidjet',
    '👩🏻‍❤‍💋‍👩🏼' => 'süüse: wüf, wüf, laacht hidjet an madel laacht hidj',
    '👩🏻‍❤‍💋‍👩🏽' => 'süüse: wüf, wüf, laacht hidjet an madel hidj',
    '👩🏻‍❤‍💋‍👩🏾' => 'süüse: wüf, wüf, laacht hidjet an madel jonk hidj',
    '👩🏻‍❤‍💋‍👩🏿' => 'süüse: wüf, wüf, laacht hidjet an jonk hidj',
    '👩🏼‍❤‍💋‍👩🏻' => 'süüse: wüf, wüf, madel laacht hidj an laacht hidjet',
    '👩🏼‍❤‍💋‍👩🏼' => 'süüse: wüf, wüf an madel laacht hidj',
    '👩🏼‍❤‍💋‍👩🏽' => 'süüse: wüf, wüf, madel laacht hidj an madel hidj',
    '👩🏼‍❤‍💋‍👩🏾' => 'süüse: wüf, wüf, madel laacht hidj an madel jonk hidj',
    '👩🏼‍❤‍💋‍👩🏿' => 'süüse: wüf, wüf, madel laacht hidj an jonk hidj',
    '👩🏽‍❤‍💋‍👩🏻' => 'süüse: wüf, wüf, madel hidj an laacht hidjet',
    '👩🏽‍❤‍💋‍👩🏼' => 'süüse: wüf, wüf, madel hidj an madel laacht hidj',
    '👩🏽‍❤‍💋‍👩🏽' => 'süüse: wüf, wüf an madel hidj',
    '👩🏽‍❤‍💋‍👩🏾' => 'süüse: wüf, wüf, madel hidj an madel jonk hidj',
    '👩🏽‍❤‍💋‍👩🏿' => 'süüse: wüf, wüf, madel hidj an jonk hidj',
    '👩🏾‍❤‍💋‍👩🏻' => 'süüse: wüf, wüf, madel jonk hidj an laacht hidjet',
    '👩🏾‍❤‍💋‍👩🏼' => 'süüse: wüf, wüf, madel jonk hidj an madel laacht hidj',
    '👩🏾‍❤‍💋‍👩🏽' => 'süüse: wüf, wüf, madel jonk hidj an madel hidj',
    '👩🏾‍❤‍💋‍👩🏾' => 'süüse: wüf, wüf an madel jonk hidj',
    '👩🏾‍❤‍💋‍👩🏿' => 'süüse: wüf, wüf, madel jonk hidj an jonk hidj',
    '👩🏿‍❤‍💋‍👩🏻' => 'süüse: wüf, wüf, jonk hidj an laacht hidjet',
    '👩🏿‍❤‍💋‍👩🏼' => 'süüse: wüf, wüf, jonk hidj an madel laacht hidj',
    '👩🏿‍❤‍💋‍👩🏽' => 'süüse: wüf, wüf, jonk hidj an madel hidj',
    '👩🏿‍❤‍💋‍👩🏾' => 'süüse: wüf, wüf, jonk hidj an madel jonk hidj',
    '👩🏿‍❤‍💋‍👩🏿' => 'süüse: wüf, wüf an jonk hidj',
    '🧑🏻‍🫯‍🧑🏼' => 'persuunen kemfe: laacht hidjet an madel laacht hidj',
    '🧑🏻‍🫯‍🧑🏽' => 'persuunen kemfe: laacht hidjet an madel hidj',
    '🧑🏻‍🫯‍🧑🏾' => 'persuunen kemfe: laacht hidjet an madel jonk hidj',
    '🧑🏻‍🫯‍🧑🏿' => 'persuunen kemfe: laacht hidjet an jonk hidj',
    '🧑🏼‍🫯‍🧑🏻' => 'persuunen kemfe: madel laacht hidj an laacht hidjet',
    '🧑🏼‍🫯‍🧑🏽' => 'persuunen kemfe: madel laacht hidj an madel hidj',
    '🧑🏼‍🫯‍🧑🏾' => 'persuunen kemfe: madel laacht hidj an madel jonk hidj',
    '🧑🏼‍🫯‍🧑🏿' => 'persuunen kemfe: madel laacht hidj an jonk hidj',
    '🧑🏽‍🫯‍🧑🏻' => 'persuunen kemfe: madel hidj an laacht hidjet',
    '🧑🏽‍🫯‍🧑🏼' => 'persuunen kemfe: madel hidj an madel laacht hidj',
    '🧑🏽‍🫯‍🧑🏾' => 'persuunen kemfe: madel hidj an madel jonk hidj',
    '🧑🏽‍🫯‍🧑🏿' => 'persuunen kemfe: madel hidj an jonk hidj',
    '🧑🏾‍🫯‍🧑🏻' => 'persuunen kemfe: madel jonk hidj an laacht hidjet',
    '🧑🏾‍🫯‍🧑🏼' => 'persuunen kemfe: madel jonk hidj an madel laacht hidj',
    '🧑🏾‍🫯‍🧑🏽' => 'persuunen kemfe: madel jonk hidj an madel hidj',
    '🧑🏾‍🫯‍🧑🏿' => 'persuunen kemfe: madel jonk hidj an jonk hidj',
    '🧑🏿‍🫯‍🧑🏻' => 'persuunen kemfe: jonk hidj an laacht hidjet',
    '🧑🏿‍🫯‍🧑🏼' => 'persuunen kemfe: jonk hidj an madel laacht hidj',
    '🧑🏿‍🫯‍🧑🏽' => 'persuunen kemfe: jonk hidj an madel hidj',
    '🧑🏿‍🫯‍🧑🏾' => 'persuunen kemfe: jonk hidj an madel jonk hidj',
    '🧑🏻‍❤‍🧑🏼' => 'paar mä hart: persuun, persuun, laacht hidjet an madel laacht hidj',
    '🧑🏻‍❤‍🧑🏽' => 'paar mä hart: persuun, persuun, laacht hidjet an madel hidj',
    '🧑🏻‍❤‍🧑🏾' => 'paar mä hart: persuun, persuun, laacht hidjet an madel jonk hidj',
    '🧑🏻‍❤‍🧑🏿' => 'paar mä hart: persuun, persuun, laacht hidjet an jonk hidj',
    '🧑🏼‍❤‍🧑🏻' => 'paar mä hart: persuun, persuun, madel laacht hidj an laacht hidjet',
    '🧑🏼‍❤‍🧑🏽' => 'paar mä hart: persuun, persuun, madel laacht hidj an madel hidj',
    '🧑🏼‍❤‍🧑🏾' => 'paar mä hart: persuun, persuun, madel laacht hidj an madel jonk hidj',
    '🧑🏼‍❤‍🧑🏿' => 'paar mä hart: persuun, persuun, madel laacht hidj an jonk hidj',
    '🧑🏽‍❤‍🧑🏻' => 'paar mä hart: persuun, persuun, madel hidj an laacht hidjet',
    '🧑🏽‍❤‍🧑🏼' => 'paar mä hart: persuun, persuun, madel hidj an madel laacht hidj',
    '🧑🏽‍❤‍🧑🏾' => 'paar mä hart: persuun, persuun, madel hidj an madel jonk hidj',
    '🧑🏽‍❤‍🧑🏿' => 'paar mä hart: persuun, persuun, madel hidj an jonk hidj',
    '🧑🏾‍❤‍🧑🏻' => 'paar mä hart: persuun, persuun, madel jonk hidj an laacht hidjet',
    '🧑🏾‍❤‍🧑🏼' => 'paar mä hart: persuun, persuun, madel jonk hidj an madel laacht hidj',
    '🧑🏾‍❤‍🧑🏽' => 'paar mä hart: persuun, persuun, madel jonk hidj an madel hidj',
    '🧑🏾‍❤‍🧑🏿' => 'paar mä hart: persuun, persuun, madel jonk hidj an jonk hidj',
    '🧑🏿‍❤‍🧑🏻' => 'paar mä hart: persuun, persuun, jonk hidj an laacht hidjet',
    '🧑🏿‍❤‍🧑🏼' => 'paar mä hart: persuun, persuun, jonk hidj an madel laacht hidj',
    '🧑🏿‍❤‍🧑🏽' => 'paar mä hart: persuun, persuun, jonk hidj an madel hidj',
    '🧑🏿‍❤‍🧑🏾' => 'paar mä hart: persuun, persuun, jonk hidj an madel jonk hidj',
    '🧑🏻‍🐰‍🧑🏼' => 'lidj mä haasuaren: laacht hidjet an madel laacht hidj',
    '🧑🏻‍🐰‍🧑🏽' => 'lidj mä haasuaren: laacht hidjet an madel hidj',
    '🧑🏻‍🐰‍🧑🏾' => 'lidj mä haasuaren: laacht hidjet an madel jonk hidj',
    '🧑🏻‍🐰‍🧑🏿' => 'lidj mä haasuaren: laacht hidjet an jonk hidj',
    '🧑🏼‍🐰‍🧑🏻' => 'lidj mä haasuaren: madel laacht hidj an laacht hidjet',
    '🧑🏼‍🐰‍🧑🏽' => 'lidj mä haasuaren: madel laacht hidj an madel hidj',
    '🧑🏼‍🐰‍🧑🏾' => 'lidj mä haasuaren: madel laacht hidj an madel jonk hidj',
    '🧑🏼‍🐰‍🧑🏿' => 'lidj mä haasuaren: madel laacht hidj an jonk hidj',
    '🧑🏽‍🐰‍🧑🏻' => 'lidj mä haasuaren: madel hidj an laacht hidjet',
    '🧑🏽‍🐰‍🧑🏼' => 'lidj mä haasuaren: madel hidj an madel laacht hidj',
    '🧑🏽‍🐰‍🧑🏾' => 'lidj mä haasuaren: madel hidj an madel jonk hidj',
    '🧑🏽‍🐰‍🧑🏿' => 'lidj mä haasuaren: madel hidj an jonk hidj',
    '🧑🏾‍🐰‍🧑🏻' => 'lidj mä haasuaren: madel jonk hidj an laacht hidjet',
    '🧑🏾‍🐰‍🧑🏼' => 'lidj mä haasuaren: madel jonk hidj an madel laacht hidj',
    '🧑🏾‍🐰‍🧑🏽' => 'lidj mä haasuaren: madel jonk hidj an madel hidj',
    '🧑🏾‍🐰‍🧑🏿' => 'lidj mä haasuaren: madel jonk hidj an jonk hidj',
    '🧑🏿‍🐰‍🧑🏻' => 'lidj mä haasuaren: jonk hidj an laacht hidjet',
    '🧑🏿‍🐰‍🧑🏼' => 'lidj mä haasuaren: jonk hidj an madel laacht hidj',
    '🧑🏿‍🐰‍🧑🏽' => 'lidj mä haasuaren: jonk hidj an madel hidj',
    '🧑🏿‍🐰‍🧑🏾' => 'lidj mä haasuaren: jonk hidj an madel jonk hidj',
    '👨🏻‍🫯‍👨🏼' => 'maaner kemfe: laacht hidjet an madel laacht hidj',
    '👨🏻‍🫯‍👨🏽' => 'maaner kemfe: laacht hidjet an madel hidj',
    '👨🏻‍🫯‍👨🏾' => 'maaner kemfe: laacht hidjet an madel jonk hidj',
    '👨🏻‍🫯‍👨🏿' => 'maaner kemfe: laacht hidjet an jonk hidj',
    '👨🏼‍🫯‍👨🏻' => 'maaner kemfe: madel laacht hidj an laacht hidjet',
    '👨🏼‍🫯‍👨🏽' => 'maaner kemfe: madel laacht hidj an madel hidj',
    '👨🏼‍🫯‍👨🏾' => 'maaner kemfe: madel laacht hidj an madel jonk hidj',
    '👨🏼‍🫯‍👨🏿' => 'maaner kemfe: madel laacht hidj an jonk hidj',
    '👨🏽‍🫯‍👨🏻' => 'maaner kemfe: madel hidj an laacht hidjet',
    '👨🏽‍🫯‍👨🏼' => 'maaner kemfe: madel hidj an madel laacht hidj',
    '👨🏽‍🫯‍👨🏾' => 'maaner kemfe: madel hidj an madel jonk hidj',
    '👨🏽‍🫯‍👨🏿' => 'maaner kemfe: madel hidj an jonk hidj',
    '👨🏾‍🫯‍👨🏻' => 'maaner kemfe: madel jonk hidj an laacht hidjet',
    '👨🏾‍🫯‍👨🏼' => 'maaner kemfe: madel jonk hidj an madel laacht hidj',
    '👨🏾‍🫯‍👨🏽' => 'maaner kemfe: madel jonk hidj an madel hidj',
    '👨🏾‍🫯‍👨🏿' => 'maaner kemfe: madel jonk hidj an jonk hidj',
    '👨🏿‍🫯‍👨🏻' => 'maaner kemfe: jonk hidj an laacht hidjet',
    '👨🏿‍🫯‍👨🏼' => 'maaner kemfe: jonk hidj an madel laacht hidj',
    '👨🏿‍🫯‍👨🏽' => 'maaner kemfe: jonk hidj an madel hidj',
    '👨🏿‍🫯‍👨🏾' => 'maaner kemfe: jonk hidj an madel jonk hidj',
    '👨🏻‍❤‍👨🏻' => 'paar mä hart: maan, maan an laacht hidjet',
    '👨🏻‍❤‍👨🏼' => 'paar mä hart: maan, maan, laacht hidjet an madel laacht hidj',
    '👨🏻‍❤‍👨🏽' => 'paar mä hart: maan, maan, laacht hidjet an madel hidj',
    '👨🏻‍❤‍👨🏾' => 'paar mä hart: maan, maan, laacht hidjet an madel jonk hidj',
    '👨🏻‍❤‍👨🏿' => 'paar mä hart: maan, maan, laacht hidjet an jonk hidj',
    '👨🏼‍❤‍👨🏻' => 'paar mä hart: maan, maan, madel laacht hidj an laacht hidjet',
    '👨🏼‍❤‍👨🏼' => 'paar mä hart: maan, maan an madel laacht hidj',
    '👨🏼‍❤‍👨🏽' => 'paar mä hart: maan, maan, madel laacht hidj an madel hidj',
    '👨🏼‍❤‍👨🏾' => 'paar mä hart: maan, maan, madel laacht hidj an madel jonk hidj',
    '👨🏼‍❤‍👨🏿' => 'paar mä hart: maan, maan, madel laacht hidj an jonk hidj',
    '👨🏽‍❤‍👨🏻' => 'paar mä hart: maan, maan, madel hidj an laacht hidjet',
    '👨🏽‍❤‍👨🏼' => 'paar mä hart: maan, maan, madel hidj an madel laacht hidj',
    '👨🏽‍❤‍👨🏽' => 'paar mä hart: maan, maan an madel hidj',
    '👨🏽‍❤‍👨🏾' => 'paar mä hart: maan, maan, madel hidj an madel jonk hidj',
    '👨🏽‍❤‍👨🏿' => 'paar mä hart: maan, maan, madel hidj an jonk hidj',
    '👨🏾‍❤‍👨🏻' => 'paar mä hart: maan, maan, madel jonk hidj an laacht hidjet',
    '👨🏾‍❤‍👨🏼' => 'paar mä hart: maan, maan, madel jonk hidj an madel laacht hidj',
    '👨🏾‍❤‍👨🏽' => 'paar mä hart: maan, maan, madel jonk hidj an madel hidj',
    '👨🏾‍❤‍👨🏾' => 'paar mä hart: maan, maan an madel jonk hidj',
    '👨🏾‍❤‍👨🏿' => 'paar mä hart: maan, maan, madel jonk hidj an jonk hidj',
    '👨🏿‍❤‍👨🏻' => 'paar mä hart: maan, maan, jonk hidj an laacht hidjet',
    '👨🏿‍❤‍👨🏼' => 'paar mä hart: maan, maan, jonk hidj an madel laacht hidj',
    '👨🏿‍❤‍👨🏽' => 'paar mä hart: maan, maan, jonk hidj an madel hidj',
    '👨🏿‍❤‍👨🏾' => 'paar mä hart: maan, maan, jonk hidj an madel jonk hidj',
    '👨🏿‍❤‍👨🏿' => 'paar mä hart: maan, maan an jonk hidj',
    '👨🏻‍🐰‍👨🏼' => 'maaner mä haasuaren: laacht hidjet an madel laacht hidj',
    '👨🏻‍🐰‍👨🏽' => 'maaner mä haasuaren: laacht hidjet an madel hidj',
    '👨🏻‍🐰‍👨🏾' => 'maaner mä haasuaren: laacht hidjet an madel jonk hidj',
    '👨🏻‍🐰‍👨🏿' => 'maaner mä haasuaren: laacht hidjet an jonk hidj',
    '👨🏼‍🐰‍👨🏻' => 'maaner mä haasuaren: madel laacht hidj an laacht hidjet',
    '👨🏼‍🐰‍👨🏽' => 'maaner mä haasuaren: madel laacht hidj an madel hidj',
    '👨🏼‍🐰‍👨🏾' => 'maaner mä haasuaren: madel laacht hidj an madel jonk hidj',
    '👨🏼‍🐰‍👨🏿' => 'maaner mä haasuaren: madel laacht hidj an jonk hidj',
    '👨🏽‍🐰‍👨🏻' => 'maaner mä haasuaren: madel hidj an laacht hidjet',
    '👨🏽‍🐰‍👨🏼' => 'maaner mä haasuaren: madel hidj an madel laacht hidj',
    '👨🏽‍🐰‍👨🏾' => 'maaner mä haasuaren: madel hidj an madel jonk hidj',
    '👨🏽‍🐰‍👨🏿' => 'maaner mä haasuaren: madel hidj an jonk hidj',
    '👨🏾‍🐰‍👨🏻' => 'maaner mä haasuaren: madel jonk hidj an laacht hidjet',
    '👨🏾‍🐰‍👨🏼' => 'maaner mä haasuaren: madel jonk hidj an madel laacht hidj',
    '👨🏾‍🐰‍👨🏽' => 'maaner mä haasuaren: madel jonk hidj an madel hidj',
    '👨🏾‍🐰‍👨🏿' => 'maaner mä haasuaren: madel jonk hidj an jonk hidj',
    '👨🏿‍🐰‍👨🏻' => 'maaner mä haasuaren: jonk hidj an laacht hidjet',
    '👨🏿‍🐰‍👨🏼' => 'maaner mä haasuaren: jonk hidj an madel laacht hidj',
    '👨🏿‍🐰‍👨🏽' => 'maaner mä haasuaren: jonk hidj an madel hidj',
    '👨🏿‍🐰‍👨🏾' => 'maaner mä haasuaren: jonk hidj an madel jonk hidj',
    '👩🏻‍🫯‍👩🏼' => 'wüfen kemfe: laacht hidjet an madel laacht hidj',
    '👩🏻‍🫯‍👩🏽' => 'wüfen kemfe: laacht hidjet an madel hidj',
    '👩🏻‍🫯‍👩🏾' => 'wüfen kemfe: laacht hidjet an madel jonk hidj',
    '👩🏻‍🫯‍👩🏿' => 'wüfen kemfe: laacht hidjet an jonk hidj',
    '👩🏼‍🫯‍👩🏻' => 'wüfen kemfe: madel laacht hidj an laacht hidjet',
    '👩🏼‍🫯‍👩🏽' => 'wüfen kemfe: madel laacht hidj an madel hidj',
    '👩🏼‍🫯‍👩🏾' => 'wüfen kemfe: madel laacht hidj an madel jonk hidj',
    '👩🏼‍🫯‍👩🏿' => 'wüfen kemfe: madel laacht hidj an jonk hidj',
    '👩🏽‍🫯‍👩🏻' => 'wüfen kemfe: madel hidj an laacht hidjet',
    '👩🏽‍🫯‍👩🏼' => 'wüfen kemfe: madel hidj an madel laacht hidj',
    '👩🏽‍🫯‍👩🏾' => 'wüfen kemfe: madel hidj an madel jonk hidj',
    '👩🏽‍🫯‍👩🏿' => 'wüfen kemfe: madel hidj an jonk hidj',
    '👩🏾‍🫯‍👩🏻' => 'wüfen kemfe: madel jonk hidj an laacht hidjet',
    '👩🏾‍🫯‍👩🏼' => 'wüfen kemfe: madel jonk hidj an madel laacht hidj',
    '👩🏾‍🫯‍👩🏽' => 'wüfen kemfe: madel jonk hidj an madel hidj',
    '👩🏾‍🫯‍👩🏿' => 'wüfen kemfe: madel jonk hidj an jonk hidj',
    '👩🏿‍🫯‍👩🏻' => 'wüfen kemfe: jonk hidj an laacht hidjet',
    '👩🏿‍🫯‍👩🏼' => 'wüfen kemfe: jonk hidj an madel laacht hidj',
    '👩🏿‍🫯‍👩🏽' => 'wüfen kemfe: jonk hidj an madel hidj',
    '👩🏿‍🫯‍👩🏾' => 'wüfen kemfe: jonk hidj an madel jonk hidj',
    '👩🏻‍❤‍👨🏻' => 'paar mä hart: wüf, maan an laacht hidjet',
    '👩🏻‍❤‍👨🏼' => 'paar mä hart: wüf, maan, laacht hidjet an madel laacht hidj',
    '👩🏻‍❤‍👨🏽' => 'paar mä hart: wüf, maan, laacht hidjet an madel hidj',
    '👩🏻‍❤‍👨🏾' => 'paar mä hart: wüf, maan, laacht hidjet an madel jonk hidj',
    '👩🏻‍❤‍👨🏿' => 'paar mä hart: wüf, maan, laacht hidjet an jonk hidj',
    '👩🏼‍❤‍👨🏻' => 'paar mä hart: wüf, maan, madel laacht hidj an laacht hidjet',
    '👩🏼‍❤‍👨🏼' => 'paar mä hart: wüf, maan an madel laacht hidj',
    '👩🏼‍❤‍👨🏽' => 'paar mä hart: wüf, maan, madel laacht hidj an madel hidj',
    '👩🏼‍❤‍👨🏾' => 'paar mä hart: wüf, maan, madel laacht hidj an madel jonk hidj',
    '👩🏼‍❤‍👨🏿' => 'paar mä hart: wüf, maan, madel laacht hidj an jonk hidj',
    '👩🏽‍❤‍👨🏻' => 'paar mä hart: wüf, maan, madel hidj an laacht hidjet',
    '👩🏽‍❤‍👨🏼' => 'paar mä hart: wüf, maan, madel hidj an madel laacht hidj',
    '👩🏽‍❤‍👨🏽' => 'paar mä hart: wüf, maan an madel hidj',
    '👩🏽‍❤‍👨🏾' => 'paar mä hart: wüf, maan, madel hidj an madel jonk hidj',
    '👩🏽‍❤‍👨🏿' => 'paar mä hart: wüf, maan, madel hidj an jonk hidj',
    '👩🏾‍❤‍👨🏻' => 'paar mä hart: wüf, maan, madel jonk hidj an laacht hidjet',
    '👩🏾‍❤‍👨🏼' => 'paar mä hart: wüf, maan, madel jonk hidj an madel laacht hidj',
    '👩🏾‍❤‍👨🏽' => 'paar mä hart: wüf, maan, madel jonk hidj an madel hidj',
    '👩🏾‍❤‍👨🏾' => 'paar mä hart: wüf, maan an madel jonk hidj',
    '👩🏾‍❤‍👨🏿' => 'paar mä hart: wüf, maan, madel jonk hidj an jonk hidj',
    '👩🏿‍❤‍👨🏻' => 'paar mä hart: wüf, maan, jonk hidj an laacht hidjet',
    '👩🏿‍❤‍👨🏼' => 'paar mä hart: wüf, maan, jonk hidj an madel laacht hidj',
    '👩🏿‍❤‍👨🏽' => 'paar mä hart: wüf, maan, jonk hidj an madel hidj',
    '👩🏿‍❤‍👨🏾' => 'paar mä hart: wüf, maan, jonk hidj an madel jonk hidj',
    '👩🏿‍❤‍👨🏿' => 'paar mä hart: wüf, maan an jonk hidj',
    '👩🏻‍❤‍👩🏻' => 'paar mä hart: wüf, wüf an laacht hidjet',
    '👩🏻‍❤‍👩🏼' => 'paar mä hart: wüf, wüf, laacht hidjet an madel laacht hidj',
    '👩🏻‍❤‍👩🏽' => 'paar mä hart: wüf, wüf, laacht hidjet an madel hidj',
    '👩🏻‍❤‍👩🏾' => 'paar mä hart: wüf, wüf, laacht hidjet an madel jonk hidj',
    '👩🏻‍❤‍👩🏿' => 'paar mä hart: wüf, wüf, laacht hidjet an jonk hidj',
    '👩🏼‍❤‍👩🏻' => 'paar mä hart: wüf, wüf, madel laacht hidj an laacht hidjet',
    '👩🏼‍❤‍👩🏼' => 'paar mä hart: wüf, wüf an madel laacht hidj',
    '👩🏼‍❤‍👩🏽' => 'paar mä hart: wüf, wüf, madel laacht hidj an madel hidj',
    '👩🏼‍❤‍👩🏾' => 'paar mä hart: wüf, wüf, madel laacht hidj an madel jonk hidj',
    '👩🏼‍❤‍👩🏿' => 'paar mä hart: wüf, wüf, madel laacht hidj an jonk hidj',
    '👩🏽‍❤‍👩🏻' => 'paar mä hart: wüf, wüf, madel hidj an laacht hidjet',
    '👩🏽‍❤‍👩🏼' => 'paar mä hart: wüf, wüf, madel hidj an madel laacht hidj',
    '👩🏽‍❤‍👩🏽' => 'paar mä hart: wüf, wüf an madel hidj',
    '👩🏽‍❤‍👩🏾' => 'paar mä hart: wüf, wüf, madel hidj an madel jonk hidj',
    '👩🏽‍❤‍👩🏿' => 'paar mä hart: wüf, wüf, madel hidj an jonk hidj',
    '👩🏾‍❤‍👩🏻' => 'paar mä hart: wüf, wüf, madel jonk hidj an laacht hidjet',
    '👩🏾‍❤‍👩🏼' => 'paar mä hart: wüf, wüf, madel jonk hidj an madel laacht hidj',
    '👩🏾‍❤‍👩🏽' => 'paar mä hart: wüf, wüf, madel jonk hidj an madel hidj',
    '👩🏾‍❤‍👩🏾' => 'paar mä hart: wüf, wüf an madel jonk hidj',
    '👩🏾‍❤‍👩🏿' => 'paar mä hart: wüf, wüf, madel jonk hidj an jonk hidj',
    '👩🏿‍❤‍👩🏻' => 'paar mä hart: wüf, wüf, jonk hidj an laacht hidjet',
    '👩🏿‍❤‍👩🏼' => 'paar mä hart: wüf, wüf, jonk hidj an madel laacht hidj',
    '👩🏿‍❤‍👩🏽' => 'paar mä hart: wüf, wüf, jonk hidj an madel hidj',
    '👩🏿‍❤‍👩🏾' => 'paar mä hart: wüf, wüf, jonk hidj an madel jonk hidj',
    '👩🏿‍❤‍👩🏿' => 'paar mä hart: wüf, wüf an jonk hidj',
    '👩🏻‍🐰‍👩🏼' => 'wüfen mä haasuaren: laacht hidjet an madel laacht hidj',
    '👩🏻‍🐰‍👩🏽' => 'wüfen mä haasuaren: laacht hidjet an madel hidj',
    '👩🏻‍🐰‍👩🏾' => 'wüfen mä haasuaren: laacht hidjet an madel jonk hidj',
    '👩🏻‍🐰‍👩🏿' => 'wüfen mä haasuaren: laacht hidjet an jonk hidj',
    '👩🏼‍🐰‍👩🏻' => 'wüfen mä haasuaren: madel laacht hidj an laacht hidjet',
    '👩🏼‍🐰‍👩🏽' => 'wüfen mä haasuaren: madel laacht hidj an madel hidj',
    '👩🏼‍🐰‍👩🏾' => 'wüfen mä haasuaren: madel laacht hidj an madel jonk hidj',
    '👩🏼‍🐰‍👩🏿' => 'wüfen mä haasuaren: madel laacht hidj an jonk hidj',
    '👩🏽‍🐰‍👩🏻' => 'wüfen mä haasuaren: madel hidj an laacht hidjet',
    '👩🏽‍🐰‍👩🏼' => 'wüfen mä haasuaren: madel hidj an madel laacht hidj',
    '👩🏽‍🐰‍👩🏾' => 'wüfen mä haasuaren: madel hidj an madel jonk hidj',
    '👩🏽‍🐰‍👩🏿' => 'wüfen mä haasuaren: madel hidj an jonk hidj',
    '👩🏾‍🐰‍👩🏻' => 'wüfen mä haasuaren: madel jonk hidj an laacht hidjet',
    '👩🏾‍🐰‍👩🏼' => 'wüfen mä haasuaren: madel jonk hidj an madel laacht hidj',
    '👩🏾‍🐰‍👩🏽' => 'wüfen mä haasuaren: madel jonk hidj an madel hidj',
    '👩🏾‍🐰‍👩🏿' => 'wüfen mä haasuaren: madel jonk hidj an jonk hidj',
    '👩🏿‍🐰‍👩🏻' => 'wüfen mä haasuaren: jonk hidj an laacht hidjet',
    '👩🏿‍🐰‍👩🏼' => 'wüfen mä haasuaren: jonk hidj an madel laacht hidj',
    '👩🏿‍🐰‍👩🏽' => 'wüfen mä haasuaren: jonk hidj an madel hidj',
    '👩🏿‍🐰‍👩🏾' => 'wüfen mä haasuaren: jonk hidj an madel jonk hidj',
    '🧑🏻‍🤝‍🧑🏻' => 'persunen hual hunen: laacht hidjet',
    '🧑🏻‍🤝‍🧑🏼' => 'persunen hual hunen: laacht hidjet an madel laacht hidj',
    '🧑🏻‍🤝‍🧑🏽' => 'persunen hual hunen: laacht hidjet an madel hidj',
    '🧑🏻‍🤝‍🧑🏾' => 'persunen hual hunen: laacht hidjet an madel jonk hidj',
    '🧑🏻‍🤝‍🧑🏿' => 'persunen hual hunen: laacht hidjet an jonk hidj',
    '🧑🏼‍🤝‍🧑🏻' => 'persunen hual hunen: madel laacht hidj an laacht hidjet',
    '🧑🏼‍🤝‍🧑🏼' => 'persunen hual hunen: madel laacht hidj',
    '🧑🏼‍🤝‍🧑🏽' => 'persunen hual hunen: madel laacht hidj an madel hidj',
    '🧑🏼‍🤝‍🧑🏾' => 'persunen hual hunen: madel laacht hidj an madel jonk hidj',
    '🧑🏼‍🤝‍🧑🏿' => 'persunen hual hunen: madel laacht hidj an jonk hidj',
    '🧑🏽‍🤝‍🧑🏻' => 'persunen hual hunen: madel hidj an laacht hidjet',
    '🧑🏽‍🤝‍🧑🏼' => 'persunen hual hunen: madel hidj an madel laacht hidj',
    '🧑🏽‍🤝‍🧑🏽' => 'persunen hual hunen: madel hidj',
    '🧑🏽‍🤝‍🧑🏾' => 'persunen hual hunen: madel hidj an madel jonk hidj',
    '🧑🏽‍🤝‍🧑🏿' => 'persunen hual hunen: madel hidj an jonk hidj',
    '🧑🏾‍🤝‍🧑🏻' => 'persunen hual hunen: madel jonk hidj an laacht hidjet',
    '🧑🏾‍🤝‍🧑🏼' => 'persunen hual hunen: madel jonk hidj an madel laacht hidj',
    '🧑🏾‍🤝‍🧑🏽' => 'persunen hual hunen: madel jonk hidj an madel hidj',
    '🧑🏾‍🤝‍🧑🏾' => 'persunen hual hunen: madel jonk hidj',
    '🧑🏾‍🤝‍🧑🏿' => 'persunen hual hunen: madel jonk hidj an jonk hidj',
    '🧑🏿‍🤝‍🧑🏻' => 'persunen hual hunen: jonk hidj an laacht hidjet',
    '🧑🏿‍🤝‍🧑🏼' => 'persunen hual hunen: jonk hidj an madel laacht hidj',
    '🧑🏿‍🤝‍🧑🏽' => 'persunen hual hunen: jonk hidj an madel hidj',
    '🧑🏿‍🤝‍🧑🏾' => 'persunen hual hunen: jonk hidj an madel jonk hidj',
    '🧑🏿‍🤝‍🧑🏿' => 'persunen hual hunen: jonk hidj',
    '👩🏻‍🤝‍👩🏼' => 'wüfen hual hunen: laacht hidjet an madel laacht hidj',
    '👩🏻‍🤝‍👩🏽' => 'wüfen hual hunen: laacht hidjet an madel hidj',
    '👩🏻‍🤝‍👩🏾' => 'wüfen hual hunen: laacht hidjet an madel jonk hidj',
    '👩🏻‍🤝‍👩🏿' => 'wüfen hual hunen: laacht hidjet an jonk hidj',
    '👩🏼‍🤝‍👩🏻' => 'wüfen hual hunen: madel laacht hidj an laacht hidjet',
    '👩🏼‍🤝‍👩🏽' => 'wüfen hual hunen: madel laacht hidj an madel hidj',
    '👩🏼‍🤝‍👩🏾' => 'wüfen hual hunen: madel laacht hidj an madel jonk hidj',
    '👩🏼‍🤝‍👩🏿' => 'wüfen hual hunen: madel laacht hidj an jonk hidj',
    '👩🏽‍🤝‍👩🏻' => 'wüfen hual hunen: madel hidj an laacht hidjet',
    '👩🏽‍🤝‍👩🏼' => 'wüfen hual hunen: madel hidj an madel laacht hidj',
    '👩🏽‍🤝‍👩🏾' => 'wüfen hual hunen: madel hidj an madel jonk hidj',
    '👩🏽‍🤝‍👩🏿' => 'wüfen hual hunen: madel hidj an jonk hidj',
    '👩🏾‍🤝‍👩🏻' => 'wüfen hual hunen: madel jonk hidj an laacht hidjet',
    '👩🏾‍🤝‍👩🏼' => 'wüfen hual hunen: madel jonk hidj an madel laacht hidj',
    '👩🏾‍🤝‍👩🏽' => 'wüfen hual hunen: madel jonk hidj an madel hidj',
    '👩🏾‍🤝‍👩🏿' => 'wüfen hual hunen: madel jonk hidj an jonk hidj',
    '👩🏿‍🤝‍👩🏻' => 'wüfen hual hunen: jonk hidj an laacht hidjet',
    '👩🏿‍🤝‍👩🏼' => 'wüfen hual hunen: jonk hidj an madel laacht hidj',
    '👩🏿‍🤝‍👩🏽' => 'wüfen hual hunen: jonk hidj an madel hidj',
    '👩🏿‍🤝‍👩🏾' => 'wüfen hual hunen: jonk hidj an madel jonk hidj',
    '👩🏻‍🤝‍👨🏼' => 'maan an wüf hual hunen: laacht hidjet an madel laacht hidj',
    '👩🏻‍🤝‍👨🏽' => 'maan an wüf hual hunen: laacht hidjet an madel hidj',
    '👩🏻‍🤝‍👨🏾' => 'maan an wüf hual hunen: laacht hidjet an madel jonk hidj',
    '👩🏻‍🤝‍👨🏿' => 'maan an wüf hual hunen: laacht hidjet an jonk hidj',
    '👩🏼‍🤝‍👨🏻' => 'maan an wüf hual hunen: madel laacht hidj an laacht hidjet',
    '👩🏼‍🤝‍👨🏽' => 'maan an wüf hual hunen: madel laacht hidj an madel hidj',
    '👩🏼‍🤝‍👨🏾' => 'maan an wüf hual hunen: madel laacht hidj an madel jonk hidj',
    '👩🏼‍🤝‍👨🏿' => 'maan an wüf hual hunen: madel laacht hidj an jonk hidj',
    '👩🏽‍🤝‍👨🏻' => 'maan an wüf hual hunen: madel hidj an laacht hidjet',
    '👩🏽‍🤝‍👨🏼' => 'maan an wüf hual hunen: madel hidj an madel laacht hidj',
    '👩🏽‍🤝‍👨🏾' => 'maan an wüf hual hunen: madel hidj an madel jonk hidj',
    '👩🏽‍🤝‍👨🏿' => 'maan an wüf hual hunen: madel hidj an jonk hidj',
    '👩🏾‍🤝‍👨🏻' => 'maan an wüf hual hunen: madel jonk hidj an laacht hidjet',
    '👩🏾‍🤝‍👨🏼' => 'maan an wüf hual hunen: madel jonk hidj an madel laacht hidj',
    '👩🏾‍🤝‍👨🏽' => 'maan an wüf hual hunen: madel jonk hidj an madel hidj',
    '👩🏾‍🤝‍👨🏿' => 'maan an wüf hual hunen: madel jonk hidj an jonk hidj',
    '👩🏿‍🤝‍👨🏻' => 'maan an wüf hual hunen: jonk hidj an laacht hidjet',
    '👩🏿‍🤝‍👨🏼' => 'maan an wüf hual hunen: jonk hidj an madel laacht hidj',
    '👩🏿‍🤝‍👨🏽' => 'maan an wüf hual hunen: jonk hidj an madel hidj',
    '👩🏿‍🤝‍👨🏾' => 'maan an wüf hual hunen: jonk hidj an madel jonk hidj',
    '👨🏻‍🤝‍👨🏼' => 'maaner hual hunen: laacht hidjet an madel laacht hidj',
    '👨🏻‍🤝‍👨🏽' => 'maaner hual hunen: laacht hidjet an madel hidj',
    '👨🏻‍🤝‍👨🏾' => 'maaner hual hunen: laacht hidjet an madel jonk hidj',
    '👨🏻‍🤝‍👨🏿' => 'maaner hual hunen: laacht hidjet an jonk hidj',
    '👨🏼‍🤝‍👨🏻' => 'maaner hual hunen: madel laacht hidj an laacht hidjet',
    '👨🏼‍🤝‍👨🏽' => 'maaner hual hunen: madel laacht hidj an madel hidj',
    '👨🏼‍🤝‍👨🏾' => 'maaner hual hunen: madel laacht hidj an madel jonk hidj',
    '👨🏼‍🤝‍👨🏿' => 'maaner hual hunen: madel laacht hidj an jonk hidj',
    '👨🏽‍🤝‍👨🏻' => 'maaner hual hunen: madel hidj an laacht hidjet',
    '👨🏽‍🤝‍👨🏼' => 'maaner hual hunen: madel hidj an madel laacht hidj',
    '👨🏽‍🤝‍👨🏾' => 'maaner hual hunen: madel hidj an madel jonk hidj',
    '👨🏽‍🤝‍👨🏿' => 'maaner hual hunen: madel hidj an jonk hidj',
    '👨🏾‍🤝‍👨🏻' => 'maaner hual hunen: madel jonk hidj an laacht hidjet',
    '👨🏾‍🤝‍👨🏼' => 'maaner hual hunen: madel jonk hidj an madel laacht hidj',
    '👨🏾‍🤝‍👨🏽' => 'maaner hual hunen: madel jonk hidj an madel hidj',
    '👨🏾‍🤝‍👨🏿' => 'maaner hual hunen: madel jonk hidj an jonk hidj',
    '👨🏿‍🤝‍👨🏻' => 'maaner hual hunen: jonk hidj an laacht hidjet',
    '👨🏿‍🤝‍👨🏼' => 'maaner hual hunen: jonk hidj an madel laacht hidj',
    '👨🏿‍🤝‍👨🏽' => 'maaner hual hunen: jonk hidj an madel hidj',
    '👨🏿‍🤝‍👨🏾' => 'maaner hual hunen: jonk hidj an madel jonk hidj',
    '👩‍❤‍💋‍👨' => 'süüse: wüf an maan',
    '👨‍❤‍💋‍👨' => 'süüse: maan an maan',
    '👩‍❤‍💋‍👩' => 'süüse: wüf an wüf',
    '👨‍👩‍👧‍👦' => 'famile: maan, wüf, foomen an dring',
    '👨‍👩‍👦‍👦' => 'famile: maan, wüf, dring an dring',
    '👨‍👩‍👧‍👧' => 'famile: maan, wüf, foomen an foomen',
    '👨‍👨‍👧‍👦' => 'famile: maan, maan, foomen an dring',
    '👨‍👨‍👦‍👦' => 'famile: maan, maan, dring an dring',
    '👨‍👨‍👧‍👧' => 'famile: maan, maan, foomen an foomen',
    '👩‍👩‍👧‍👦' => 'famile: wüf, wüf, foomen an dring',
    '👩‍👩‍👦‍👦' => 'famile: wüf, wüf, dring an dring',
    '👩‍👩‍👧‍👧' => 'famile: wüf, wüf, foomen an foomen',
    '🧑‍🧑‍🧒‍🧒' => 'tau woksenen, tau jongen',
    '🚶🏻‍♀‍➡' => 'wüf lääpt: laacht hidjet an rochts am',
    '🚶🏼‍♀‍➡' => 'wüf lääpt: madel laacht hidj an rochts am',
    '🚶🏽‍♀‍➡' => 'wüf lääpt: madel hidj an rochts am',
    '🚶🏾‍♀‍➡' => 'wüf lääpt: madel jonk hidj an rochts am',
    '🚶🏿‍♀‍➡' => 'wüf lääpt: jonk hidj an rochts am',
    '🚶🏻‍♂‍➡' => 'maan lääpt: laacht hidjet an rochts am',
    '🚶🏼‍♂‍➡' => 'maan lääpt: madel laacht hidj an rochts am',
    '🚶🏽‍♂‍➡' => 'maan lääpt: madel hidj an rochts am',
    '🚶🏾‍♂‍➡' => 'maan lääpt: madel jonk hidj an rochts am',
    '🚶🏿‍♂‍➡' => 'maan lääpt: jonk hidj an rochts am',
    '🧎🏻‍♀‍➡' => 'wüf üüb knöbian: laacht hidjet an rochts am',
    '🧎🏼‍♀‍➡' => 'wüf üüb knöbian: madel laacht hidj an rochts am',
    '🧎🏽‍♀‍➡' => 'wüf üüb knöbian: madel hidj an rochts am',
    '🧎🏾‍♀‍➡' => 'wüf üüb knöbian: madel jonk hidj an rochts am',
    '🧎🏿‍♀‍➡' => 'wüf üüb knöbian: jonk hidj an rochts am',
    '🧎🏻‍♂‍➡' => 'man üüb knöbian: laacht hidjet an rochts am',
    '🧎🏼‍♂‍➡' => 'man üüb knöbian: madel laacht hidj an rochts am',
    '🧎🏽‍♂‍➡' => 'man üüb knöbian: madel hidj an rochts am',
    '🧎🏾‍♂‍➡' => 'man üüb knöbian: madel jonk hidj an rochts am',
    '🧎🏿‍♂‍➡' => 'man üüb knöbian: jonk hidj an rochts am',
    '🧑🏻‍🦯‍➡' => 'persuun mä blinjenstook: laacht hidjet an rochts am',
    '🧑🏼‍🦯‍➡' => 'persuun mä blinjenstook: madel laacht hidj an rochts am',
    '🧑🏽‍🦯‍➡' => 'persuun mä blinjenstook: madel hidj an rochts am',
    '🧑🏾‍🦯‍➡' => 'persuun mä blinjenstook: madel jonk hidj an rochts am',
    '🧑🏿‍🦯‍➡' => 'persuun mä blinjenstook: jonk hidj an rochts am',
    '👨🏻‍🦯‍➡' => 'maan mä blinjenstook: laacht hidjet an rochts am',
    '👨🏼‍🦯‍➡' => 'maan mä blinjenstook: madel laacht hidj an rochts am',
    '👨🏽‍🦯‍➡' => 'maan mä blinjenstook: madel hidj an rochts am',
    '👨🏾‍🦯‍➡' => 'maan mä blinjenstook: madel jonk hidj an rochts am',
    '👨🏿‍🦯‍➡' => 'maan mä blinjenstook: jonk hidj an rochts am',
    '👩🏻‍🦯‍➡' => 'wüf mä blinjenstook: laacht hidjet an rochts am',
    '👩🏼‍🦯‍➡' => 'wüf mä blinjenstook: madel laacht hidj an rochts am',
    '👩🏽‍🦯‍➡' => 'wüf mä blinjenstook: madel hidj an rochts am',
    '👩🏾‍🦯‍➡' => 'wüf mä blinjenstook: madel jonk hidj an rochts am',
    '👩🏿‍🦯‍➡' => 'wüf mä blinjenstook: jonk hidj an rochts am',
    '🧑🏻‍🦼‍➡' => 'persuun üüb elektro rolstuul: laacht hidjet an rochts am',
    '🧑🏼‍🦼‍➡' => 'persuun üüb elektro rolstuul: madel laacht hidj an rochts am',
    '🧑🏽‍🦼‍➡' => 'persuun üüb elektro rolstuul: madel hidj an rochts am',
    '🧑🏾‍🦼‍➡' => 'persuun üüb elektro rolstuul: madel jonk hidj an rochts am',
    '🧑🏿‍🦼‍➡' => 'persuun üüb elektro rolstuul: jonk hidj an rochts am',
    '👨🏻‍🦼‍➡' => 'maan üüb elektro rolstuul: laacht hidjet an rochts am',
    '👨🏼‍🦼‍➡' => 'maan üüb elektro rolstuul: madel laacht hidj an rochts am',
    '👨🏽‍🦼‍➡' => 'maan üüb elektro rolstuul: madel hidj an rochts am',
    '👨🏾‍🦼‍➡' => 'maan üüb elektro rolstuul: madel jonk hidj an rochts am',
    '👨🏿‍🦼‍➡' => 'maan üüb elektro rolstuul: jonk hidj an rochts am',
    '👩🏻‍🦼‍➡' => 'wüf üüb elektro rolstuul: laacht hidjet an rochts am',
    '👩🏼‍🦼‍➡' => 'wüf üüb elektro rolstuul: madel laacht hidj an rochts am',
    '👩🏽‍🦼‍➡' => 'wüf üüb elektro rolstuul: madel hidj an rochts am',
    '👩🏾‍🦼‍➡' => 'wüf üüb elektro rolstuul: madel jonk hidj an rochts am',
    '👩🏿‍🦼‍➡' => 'wüf üüb elektro rolstuul: jonk hidj an rochts am',
    '🧑🏻‍🦽‍➡' => 'persuun üüb rolstuul: laacht hidjet an rochts am',
    '🧑🏼‍🦽‍➡' => 'persuun üüb rolstuul: madel laacht hidj an rochts am',
    '🧑🏽‍🦽‍➡' => 'persuun üüb rolstuul: madel hidj an rochts am',
    '🧑🏾‍🦽‍➡' => 'persuun üüb rolstuul: madel jonk hidj an rochts am',
    '🧑🏿‍🦽‍➡' => 'persuun üüb rolstuul: jonk hidj an rochts am',
    '👨🏻‍🦽‍➡' => 'maan üüb rolstuul: laacht hidjet an rochts am',
    '👨🏼‍🦽‍➡' => 'maan üüb rolstuul: madel laacht hidj an rochts am',
    '👨🏽‍🦽‍➡' => 'maan üüb rolstuul: madel hidj an rochts am',
    '👨🏾‍🦽‍➡' => 'maan üüb rolstuul: madel jonk hidj an rochts am',
    '👨🏿‍🦽‍➡' => 'maan üüb rolstuul: jonk hidj an rochts am',
    '👩🏻‍🦽‍➡' => 'wüf üüb rolstuul: laacht hidjet an rochts am',
    '👩🏼‍🦽‍➡' => 'wüf üüb rolstuul: madel laacht hidj an rochts am',
    '👩🏽‍🦽‍➡' => 'wüf üüb rolstuul: madel hidj an rochts am',
    '👩🏾‍🦽‍➡' => 'wüf üüb rolstuul: madel jonk hidj an rochts am',
    '👩🏿‍🦽‍➡' => 'wüf üüb rolstuul: jonk hidj an rochts am',
    '🏃🏻‍♀‍➡' => 'wüf räänt: laacht hidjet an rochts am',
    '🏃🏼‍♀‍➡' => 'wüf räänt: madel laacht hidj an rochts am',
    '🏃🏽‍♀‍➡' => 'wüf räänt: madel hidj an rochts am',
    '🏃🏾‍♀‍➡' => 'wüf räänt: madel jonk hidj an rochts am',
    '🏃🏿‍♀‍➡' => 'wüf räänt: jonk hidj an rochts am',
    '🏃🏻‍♂‍➡' => 'maan räänt: laacht hidjet an rochts am',
    '🏃🏼‍♂‍➡' => 'maan räänt: madel laacht hidj an rochts am',
    '🏃🏽‍♂‍➡' => 'maan räänt: madel hidj an rochts am',
    '🏃🏾‍♂‍➡' => 'maan räänt: madel jonk hidj an rochts am',
    '🏃🏿‍♂‍➡' => 'maan räänt: jonk hidj an rochts am',
    '🫱🏻‍🫲🏼' => 'hunen sködle: laacht hidjet an madel laacht hidj',
    '🫱🏻‍🫲🏽' => 'hunen sködle: laacht hidjet an madel hidj',
    '🫱🏻‍🫲🏾' => 'hunen sködle: laacht hidjet an madel jonk hidj',
    '🫱🏻‍🫲🏿' => 'hunen sködle: laacht hidjet an jonk hidj',
    '🫱🏼‍🫲🏻' => 'hunen sködle: madel laacht hidj an laacht hidjet',
    '🫱🏼‍🫲🏽' => 'hunen sködle: madel laacht hidj an madel hidj',
    '🫱🏼‍🫲🏾' => 'hunen sködle: madel laacht hidj an madel jonk hidj',
    '🫱🏼‍🫲🏿' => 'hunen sködle: madel laacht hidj an jonk hidj',
    '🫱🏽‍🫲🏻' => 'hunen sködle: madel hidj an laacht hidjet',
    '🫱🏽‍🫲🏼' => 'hunen sködle: madel hidj an madel laacht hidj',
    '🫱🏽‍🫲🏾' => 'hunen sködle: madel hidj an madel jonk hidj',
    '🫱🏽‍🫲🏿' => 'hunen sködle: madel hidj an jonk hidj',
    '🫱🏾‍🫲🏻' => 'hunen sködle: madel jonk hidj an laacht hidjet',
    '🫱🏾‍🫲🏼' => 'hunen sködle: madel jonk hidj an madel laacht hidj',
    '🫱🏾‍🫲🏽' => 'hunen sködle: madel jonk hidj an madel hidj',
    '🫱🏾‍🫲🏿' => 'hunen sködle: madel jonk hidj an jonk hidj',
    '🫱🏿‍🫲🏻' => 'hunen sködle: jonk hidj an laacht hidjet',
    '🫱🏿‍🫲🏼' => 'hunen sködle: jonk hidj an madel laacht hidj',
    '🫱🏿‍🫲🏽' => 'hunen sködle: jonk hidj an madel hidj',
    '🫱🏿‍🫲🏾' => 'hunen sködle: jonk hidj an madel jonk hidj',
    '🚶‍♀‍➡' => 'wüf lääpt: rochts am',
    '🚶‍♂‍➡' => 'maan lääpt: rochts am',
    '🧎‍♀‍➡' => 'wüf üüb knöbian: rochts am',
    '🧎‍♂‍➡' => 'man üüb knöbian: rochts am',
    '🧑‍🦯‍➡' => 'persuun mä blinjenstook: rochts am',
    '👨‍🦯‍➡' => 'maan mä blinjenstook: rochts am',
    '👩‍🦯‍➡' => 'wüf mä blinjenstook: rochts am',
    '🧑‍🦼‍➡' => 'persuun üüb elektro rolstuul: rochts am',
    '👨‍🦼‍➡' => 'maan üüb elektro rolstuul: rochts am',
    '👩‍🦼‍➡' => 'wüf üüb elektro rolstuul: rochts am',
    '🧑‍🦽‍➡' => 'persuun üüb rolstuul: rochts am',
    '👨‍🦽‍➡' => 'maan üüb rolstuul: rochts am',
    '👩‍🦽‍➡' => 'wüf üüb rolstuul: rochts am',
    '🏃‍♀‍➡' => 'wüf räänt: rochts am',
    '🏃‍♂‍➡' => 'maan räänt: rochts am',
    '👩‍❤‍👨' => 'paar mä hart: wüf an maan',
    '👨‍❤‍👨' => 'paar mä hart: maan an maan',
    '👩‍❤‍👩' => 'paar mä hart: wüf an wüf',
    '👨‍👩‍👦' => 'famile: maan, wüf an dring',
    '👨‍👩‍👧' => 'famile: maan, wüf an foomen',
    '👨‍👨‍👦' => 'famile: maan, maan an dring',
    '👨‍👨‍👧' => 'famile: maan, maan an foomen',
    '👩‍👩‍👦' => 'famile: wüf, wüf an dring',
    '👩‍👩‍👧' => 'famile: wüf, wüf an foomen',
    '👨‍👦‍👦' => 'famile: maan, dring an dring',
    '👨‍👧‍👦' => 'famile: maan, foomen an dring',
    '👨‍👧‍👧' => 'famile: maan, foomen an foomen',
    '👩‍👦‍👦' => 'famile: wüf, dring an dring',
    '👩‍👧‍👦' => 'famile: wüf, foomen an dring',
    '👩‍👧‍👧' => 'famile: wüf, foomen an foomen',
    '🧑‍🤝‍🧑' => 'persunen hual hunen',
    '🧑‍🧑‍🧒' => 'tau woksenen, ian kint',
    '🧑‍🧒‍🧒' => 'ään woksenen, tau jongen',
    '🧑🏻‍🦰' => 'persuun: laacht hidjet an ruad hiar',
    '🧑🏼‍🦰' => 'persuun: madel laacht hidj an ruad hiar',
    '🧑🏽‍🦰' => 'persuun: madel hidj an ruad hiar',
    '🧑🏾‍🦰' => 'persuun: madel jonk hidj an ruad hiar',
    '🧑🏿‍🦰' => 'persuun: jonk hidj an ruad hiar',
    '🧑🏻‍🦱' => 'persuun: laacht hidjet an krüüsag hiar',
    '🧑🏼‍🦱' => 'persuun: madel laacht hidj an krüüsag hiar',
    '🧑🏽‍🦱' => 'persuun: madel hidj an krüüsag hiar',
    '🧑🏾‍🦱' => 'persuun: madel jonk hidj an krüüsag hiar',
    '🧑🏿‍🦱' => 'persuun: jonk hidj an krüüsag hiar',
    '🧑🏻‍🦳' => 'persuun: laacht hidjet an witj hiar',
    '🧑🏼‍🦳' => 'persuun: madel laacht hidj an witj hiar',
    '🧑🏽‍🦳' => 'persuun: madel hidj an witj hiar',
    '🧑🏾‍🦳' => 'persuun: madel jonk hidj an witj hiar',
    '🧑🏿‍🦳' => 'persuun: jonk hidj an witj hiar',
    '🧑🏻‍🦲' => 'persuun: laacht hidjet an nian hiar',
    '🧑🏼‍🦲' => 'persuun: madel laacht hidj an nian hiar',
    '🧑🏽‍🦲' => 'persuun: madel hidj an nian hiar',
    '🧑🏾‍🦲' => 'persuun: madel jonk hidj an nian hiar',
    '🧑🏿‍🦲' => 'persuun: jonk hidj an nian hiar',
    '🧑🏻‍🩰' => 'balet daanser: laacht hidjet',
    '🧑🏼‍🩰' => 'balet daanser: madel laacht hidj',
    '🧑🏽‍🩰' => 'balet daanser: madel hidj',
    '🧑🏾‍🩰' => 'balet daanser: madel jonk hidj',
    '🧑🏿‍🩰' => 'balet daanser: jonk hidj',
    '🧔🏻‍♂' => 'maan mä biard: laacht hidjet',
    '🧔🏼‍♂' => 'maan mä biard: madel laacht hidj',
    '🧔🏽‍♂' => 'maan mä biard: madel hidj',
    '🧔🏾‍♂' => 'maan mä biard: madel jonk hidj',
    '🧔🏿‍♂' => 'maan mä biard: jonk hidj',
    '👱🏻‍♂' => 'blond maan: laacht hidjet',
    '👱🏼‍♂' => 'blond maan: madel laacht hidj',
    '👱🏽‍♂' => 'blond maan: madel hidj',
    '👱🏾‍♂' => 'blond maan: madel jonk hidj',
    '👱🏿‍♂' => 'blond maan: jonk hidj',
    '👨🏻‍🦰' => 'maan: laacht hidjet an ruad hiar',
    '👨🏼‍🦰' => 'maan: madel laacht hidj an ruad hiar',
    '👨🏽‍🦰' => 'maan: madel hidj an ruad hiar',
    '👨🏾‍🦰' => 'maan: madel jonk hidj an ruad hiar',
    '👨🏿‍🦰' => 'maan: jonk hidj an ruad hiar',
    '👨🏻‍🦱' => 'maan: laacht hidjet an krüüsag hiar',
    '👨🏼‍🦱' => 'maan: madel laacht hidj an krüüsag hiar',
    '👨🏽‍🦱' => 'maan: madel hidj an krüüsag hiar',
    '👨🏾‍🦱' => 'maan: madel jonk hidj an krüüsag hiar',
    '👨🏿‍🦱' => 'maan: jonk hidj an krüüsag hiar',
    '👨🏻‍🦳' => 'maan: laacht hidjet an witj hiar',
    '👨🏼‍🦳' => 'maan: madel laacht hidj an witj hiar',
    '👨🏽‍🦳' => 'maan: madel hidj an witj hiar',
    '👨🏾‍🦳' => 'maan: madel jonk hidj an witj hiar',
    '👨🏿‍🦳' => 'maan: jonk hidj an witj hiar',
    '👨🏻‍🦲' => 'maan: laacht hidjet an nian hiar',
    '👨🏼‍🦲' => 'maan: madel laacht hidj an nian hiar',
    '👨🏽‍🦲' => 'maan: madel hidj an nian hiar',
    '👨🏾‍🦲' => 'maan: madel jonk hidj an nian hiar',
    '👨🏿‍🦲' => 'maan: jonk hidj an nian hiar',
    '🧔🏻‍♀' => 'wüf mä biard: laacht hidjet',
    '🧔🏼‍♀' => 'wüf mä biard: madel laacht hidj',
    '🧔🏽‍♀' => 'wüf mä biard: madel hidj',
    '🧔🏾‍♀' => 'wüf mä biard: madel jonk hidj',
    '🧔🏿‍♀' => 'wüf mä biard: jonk hidj',
    '👱🏻‍♀' => 'blond wüf: laacht hidjet',
    '👱🏼‍♀' => 'blond wüf: madel laacht hidj',
    '👱🏽‍♀' => 'blond wüf: madel hidj',
    '👱🏾‍♀' => 'blond wüf: madel jonk hidj',
    '👱🏿‍♀' => 'blond wüf: jonk hidj',
    '👩🏻‍🦰' => 'wüf: laacht hidjet an ruad hiar',
    '👩🏼‍🦰' => 'wüf: madel laacht hidj an ruad hiar',
    '👩🏽‍🦰' => 'wüf: madel hidj an ruad hiar',
    '👩🏾‍🦰' => 'wüf: madel jonk hidj an ruad hiar',
    '👩🏿‍🦰' => 'wüf: jonk hidj an ruad hiar',
    '👩🏻‍🦱' => 'wüf: laacht hidjet an krüüsag hiar',
    '👩🏼‍🦱' => 'wüf: madel laacht hidj an krüüsag hiar',
    '👩🏽‍🦱' => 'wüf: madel hidj an krüüsag hiar',
    '👩🏾‍🦱' => 'wüf: madel jonk hidj an krüüsag hiar',
    '👩🏿‍🦱' => 'wüf: jonk hidj an krüüsag hiar',
    '👩🏻‍🦳' => 'wüf: laacht hidjet an witj hiar',
    '👩🏼‍🦳' => 'wüf: madel laacht hidj an witj hiar',
    '👩🏽‍🦳' => 'wüf: madel hidj an witj hiar',
    '👩🏾‍🦳' => 'wüf: madel jonk hidj an witj hiar',
    '👩🏿‍🦳' => 'wüf: jonk hidj an witj hiar',
    '👩🏻‍🦲' => 'wüf: laacht hidjet an nian hiar',
    '👩🏼‍🦲' => 'wüf: madel laacht hidj an nian hiar',
    '👩🏽‍🦲' => 'wüf: madel hidj an nian hiar',
    '👩🏾‍🦲' => 'wüf: madel jonk hidj an nian hiar',
    '👩🏿‍🦲' => 'wüf: jonk hidj an nian hiar',
    '🙍🏻‍♂' => 'maan bedrüüwet: laacht hidjet',
    '🙍🏼‍♂' => 'maan bedrüüwet: madel laacht hidj',
    '🙍🏽‍♂' => 'maan bedrüüwet: madel hidj',
    '🙍🏾‍♂' => 'maan bedrüüwet: madel jonk hidj',
    '🙍🏿‍♂' => 'maan bedrüüwet: jonk hidj',
    '🙍🏻‍♀' => 'wüf bedrüüwet: laacht hidjet',
    '🙍🏼‍♀' => 'wüf bedrüüwet: madel laacht hidj',
    '🙍🏽‍♀' => 'wüf bedrüüwet: madel hidj',
    '🙍🏾‍♀' => 'wüf bedrüüwet: madel jonk hidj',
    '🙍🏿‍♀' => 'wüf bedrüüwet: jonk hidj',
    '🙎🏻‍♂' => 'maan flap: laacht hidjet',
    '🙎🏼‍♂' => 'maan flap: madel laacht hidj',
    '🙎🏽‍♂' => 'maan flap: madel hidj',
    '🙎🏾‍♂' => 'maan flap: madel jonk hidj',
    '🙎🏿‍♂' => 'maan flap: jonk hidj',
    '🙎🏻‍♀' => 'wüf flap: laacht hidjet',
    '🙎🏼‍♀' => 'wüf flap: madel laacht hidj',
    '🙎🏽‍♀' => 'wüf flap: madel hidj',
    '🙎🏾‍♀' => 'wüf flap: madel jonk hidj',
    '🙎🏿‍♀' => 'wüf flap: jonk hidj',
    '🙅🏻‍♂' => 'maan naan: laacht hidjet',
    '🙅🏼‍♂' => 'maan naan: madel laacht hidj',
    '🙅🏽‍♂' => 'maan naan: madel hidj',
    '🙅🏾‍♂' => 'maan naan: madel jonk hidj',
    '🙅🏿‍♂' => 'maan naan: jonk hidj',
    '🙅🏻‍♀' => 'wüf naan: laacht hidjet',
    '🙅🏼‍♀' => 'wüf naan: madel laacht hidj',
    '🙅🏽‍♀' => 'wüf naan: madel hidj',
    '🙅🏾‍♀' => 'wüf naan: madel jonk hidj',
    '🙅🏿‍♀' => 'wüf naan: jonk hidj',
    '🙆🏻‍♂' => 'maan bliis: laacht hidjet',
    '🙆🏼‍♂' => 'maan bliis: madel laacht hidj',
    '🙆🏽‍♂' => 'maan bliis: madel hidj',
    '🙆🏾‍♂' => 'maan bliis: madel jonk hidj',
    '🙆🏿‍♂' => 'maan bliis: jonk hidj',
    '🙆🏻‍♀' => 'wüf bliis: laacht hidjet',
    '🙆🏼‍♀' => 'wüf bliis: madel laacht hidj',
    '🙆🏽‍♀' => 'wüf bliis: madel hidj',
    '🙆🏾‍♀' => 'wüf bliis: madel jonk hidj',
    '🙆🏿‍♀' => 'wüf bliis: jonk hidj',
    '💁🏻‍♂' => 'maan wiset hun: laacht hidjet',
    '💁🏼‍♂' => 'maan wiset hun: madel laacht hidj',
    '💁🏽‍♂' => 'maan wiset hun: madel hidj',
    '💁🏾‍♂' => 'maan wiset hun: madel jonk hidj',
    '💁🏿‍♂' => 'maan wiset hun: jonk hidj',
    '💁🏻‍♀' => 'wüf wiset hun: laacht hidjet',
    '💁🏼‍♀' => 'wüf wiset hun: madel laacht hidj',
    '💁🏽‍♀' => 'wüf wiset hun: madel hidj',
    '💁🏾‍♀' => 'wüf wiset hun: madel jonk hidj',
    '💁🏿‍♀' => 'wüf wiset hun: jonk hidj',
    '🙋🏻‍♂' => 'maan gröötet: laacht hidjet',
    '🙋🏼‍♂' => 'maan gröötet: madel laacht hidj',
    '🙋🏽‍♂' => 'maan gröötet: madel hidj',
    '🙋🏾‍♂' => 'maan gröötet: madel jonk hidj',
    '🙋🏿‍♂' => 'maan gröötet: jonk hidj',
    '🙋🏻‍♀' => 'wüf gröötet: laacht hidjet',
    '🙋🏼‍♀' => 'wüf gröötet: madel laacht hidj',
    '🙋🏽‍♀' => 'wüf gröötet: madel hidj',
    '🙋🏾‍♀' => 'wüf gröötet: madel jonk hidj',
    '🙋🏿‍♀' => 'wüf gröötet: jonk hidj',
    '🧏🏻‍♂' => 'duuf maan: laacht hidjet',
    '🧏🏼‍♂' => 'duuf maan: madel laacht hidj',
    '🧏🏽‍♂' => 'duuf maan: madel hidj',
    '🧏🏾‍♂' => 'duuf maan: madel jonk hidj',
    '🧏🏿‍♂' => 'duuf maan: jonk hidj',
    '🧏🏻‍♀' => 'duuf wüf: laacht hidjet',
    '🧏🏼‍♀' => 'duuf wüf: madel laacht hidj',
    '🧏🏽‍♀' => 'duuf wüf: madel hidj',
    '🧏🏾‍♀' => 'duuf wüf: madel jonk hidj',
    '🧏🏿‍♀' => 'duuf wüf: jonk hidj',
    '🙇🏻‍♂' => 'maan bocht föör: laacht hidjet',
    '🙇🏼‍♂' => 'maan bocht föör: madel laacht hidj',
    '🙇🏽‍♂' => 'maan bocht föör: madel hidj',
    '🙇🏾‍♂' => 'maan bocht föör: madel jonk hidj',
    '🙇🏿‍♂' => 'maan bocht föör: jonk hidj',
    '🙇🏻‍♀' => 'wüf bocht föör: laacht hidjet',
    '🙇🏼‍♀' => 'wüf bocht föör: madel laacht hidj',
    '🙇🏽‍♀' => 'wüf bocht föör: madel hidj',
    '🙇🏾‍♀' => 'wüf bocht föör: madel jonk hidj',
    '🙇🏿‍♀' => 'wüf bocht föör: jonk hidj',
    '🤦🏻‍♂' => 'maan palem gesicht: laacht hidjet',
    '🤦🏼‍♂' => 'maan palem gesicht: madel laacht hidj',
    '🤦🏽‍♂' => 'maan palem gesicht: madel hidj',
    '🤦🏾‍♂' => 'maan palem gesicht: madel jonk hidj',
    '🤦🏿‍♂' => 'maan palem gesicht: jonk hidj',
    '🤦🏻‍♀' => 'wüf palem gesicht: laacht hidjet',
    '🤦🏼‍♀' => 'wüf palem gesicht: madel laacht hidj',
    '🤦🏽‍♀' => 'wüf palem gesicht: madel hidj',
    '🤦🏾‍♀' => 'wüf palem gesicht: madel jonk hidj',
    '🤦🏿‍♀' => 'wüf palem gesicht: jonk hidj',
    '🤷🏻‍♂' => 'maan skolern tak: laacht hidjet',
    '🤷🏼‍♂' => 'maan skolern tak: madel laacht hidj',
    '🤷🏽‍♂' => 'maan skolern tak: madel hidj',
    '🤷🏾‍♂' => 'maan skolern tak: madel jonk hidj',
    '🤷🏿‍♂' => 'maan skolern tak: jonk hidj',
    '🤷🏻‍♀' => 'wüf skolern tak: laacht hidjet',
    '🤷🏼‍♀' => 'wüf skolern tak: madel laacht hidj',
    '🤷🏽‍♀' => 'wüf skolern tak: madel hidj',
    '🤷🏾‍♀' => 'wüf skolern tak: madel jonk hidj',
    '🤷🏿‍♀' => 'wüf skolern tak: jonk hidj',
    '🧑🏻‍⚕' => 'dochter: laacht hidjet',
    '🧑🏼‍⚕' => 'dochter: madel laacht hidj',
    '🧑🏽‍⚕' => 'dochter: madel hidj',
    '🧑🏾‍⚕' => 'dochter: madel jonk hidj',
    '🧑🏿‍⚕' => 'dochter: jonk hidj',
    '👨🏻‍⚕' => 'a dochter: laacht hidjet',
    '👨🏼‍⚕' => 'a dochter: madel laacht hidj',
    '👨🏽‍⚕' => 'a dochter: madel hidj',
    '👨🏾‍⚕' => 'a dochter: madel jonk hidj',
    '👨🏿‍⚕' => 'a dochter: jonk hidj',
    '👩🏻‍⚕' => 'at dochter: laacht hidjet',
    '👩🏼‍⚕' => 'at dochter: madel laacht hidj',
    '👩🏽‍⚕' => 'at dochter: madel hidj',
    '👩🏾‍⚕' => 'at dochter: madel jonk hidj',
    '👩🏿‍⚕' => 'at dochter: jonk hidj',
    '🧑🏻‍🎓' => 'student: laacht hidjet',
    '🧑🏼‍🎓' => 'student: madel laacht hidj',
    '🧑🏽‍🎓' => 'student: madel hidj',
    '🧑🏾‍🎓' => 'student: madel jonk hidj',
    '🧑🏿‍🎓' => 'student: jonk hidj',
    '👨🏻‍🎓' => 'a student: laacht hidjet',
    '👨🏼‍🎓' => 'a student: madel laacht hidj',
    '👨🏽‍🎓' => 'a student: madel hidj',
    '👨🏾‍🎓' => 'a student: madel jonk hidj',
    '👨🏿‍🎓' => 'a student: jonk hidj',
    '👩🏻‍🎓' => 'at student: laacht hidjet',
    '👩🏼‍🎓' => 'at student: madel laacht hidj',
    '👩🏽‍🎓' => 'at student: madel hidj',
    '👩🏾‍🎓' => 'at student: madel jonk hidj',
    '👩🏿‍🎓' => 'at student: jonk hidj',
    '🧑🏻‍🏫' => 'skuulmääster: laacht hidjet',
    '🧑🏼‍🏫' => 'skuulmääster: madel laacht hidj',
    '🧑🏽‍🏫' => 'skuulmääster: madel hidj',
    '🧑🏾‍🏫' => 'skuulmääster: madel jonk hidj',
    '🧑🏿‍🏫' => 'skuulmääster: jonk hidj',
    '👨🏻‍🏫' => 'a skuulmääster: laacht hidjet',
    '👨🏼‍🏫' => 'a skuulmääster: madel laacht hidj',
    '👨🏽‍🏫' => 'a skuulmääster: madel hidj',
    '👨🏾‍🏫' => 'a skuulmääster: madel jonk hidj',
    '👨🏿‍🏫' => 'a skuulmääster: jonk hidj',
    '👩🏻‍🏫' => 'at skuulmääster: laacht hidjet',
    '👩🏼‍🏫' => 'at skuulmääster: madel laacht hidj',
    '👩🏽‍🏫' => 'at skuulmääster: madel hidj',
    '👩🏾‍🏫' => 'at skuulmääster: madel jonk hidj',
    '👩🏿‍🏫' => 'at skuulmääster: jonk hidj',
    '🧑🏻‍⚖' => 'rachter: laacht hidjet',
    '🧑🏼‍⚖' => 'rachter: madel laacht hidj',
    '🧑🏽‍⚖' => 'rachter: madel hidj',
    '🧑🏾‍⚖' => 'rachter: madel jonk hidj',
    '🧑🏿‍⚖' => 'rachter: jonk hidj',
    '👨🏻‍⚖' => 'a rachter: laacht hidjet',
    '👨🏼‍⚖' => 'a rachter: madel laacht hidj',
    '👨🏽‍⚖' => 'a rachter: madel hidj',
    '👨🏾‍⚖' => 'a rachter: madel jonk hidj',
    '👨🏿‍⚖' => 'a rachter: jonk hidj',
    '👩🏻‍⚖' => 'at rachter: laacht hidjet',
    '👩🏼‍⚖' => 'at rachter: madel laacht hidj',
    '👩🏽‍⚖' => 'at rachter: madel hidj',
    '👩🏾‍⚖' => 'at rachter: madel jonk hidj',
    '👩🏿‍⚖' => 'at rachter: jonk hidj',
    '🧑🏻‍🌾' => 'büür: laacht hidjet',
    '🧑🏼‍🌾' => 'büür: madel laacht hidj',
    '🧑🏽‍🌾' => 'büür: madel hidj',
    '🧑🏾‍🌾' => 'büür: madel jonk hidj',
    '🧑🏿‍🌾' => 'büür: jonk hidj',
    '👨🏻‍🌾' => 'a büür: laacht hidjet',
    '👨🏼‍🌾' => 'a büür: madel laacht hidj',
    '👨🏽‍🌾' => 'a büür: madel hidj',
    '👨🏾‍🌾' => 'a büür: madel jonk hidj',
    '👨🏿‍🌾' => 'a büür: jonk hidj',
    '👩🏻‍🌾' => 'at büür: laacht hidjet',
    '👩🏼‍🌾' => 'at büür: madel laacht hidj',
    '👩🏽‍🌾' => 'at büür: madel hidj',
    '👩🏾‍🌾' => 'at büür: madel jonk hidj',
    '👩🏿‍🌾' => 'at büür: jonk hidj',
    '🧑🏻‍🍳' => 'kook: laacht hidjet',
    '🧑🏼‍🍳' => 'kook: madel laacht hidj',
    '🧑🏽‍🍳' => 'kook: madel hidj',
    '🧑🏾‍🍳' => 'kook: madel jonk hidj',
    '🧑🏿‍🍳' => 'kook: jonk hidj',
    '👨🏻‍🍳' => 'a kook: laacht hidjet',
    '👨🏼‍🍳' => 'a kook: madel laacht hidj',
    '👨🏽‍🍳' => 'a kook: madel hidj',
    '👨🏾‍🍳' => 'a kook: madel jonk hidj',
    '👨🏿‍🍳' => 'a kook: jonk hidj',
    '👩🏻‍🍳' => 'at kook: laacht hidjet',
    '👩🏼‍🍳' => 'at kook: madel laacht hidj',
    '👩🏽‍🍳' => 'at kook: madel hidj',
    '👩🏾‍🍳' => 'at kook: madel jonk hidj',
    '👩🏿‍🍳' => 'at kook: jonk hidj',
    '🧑🏻‍🔧' => 'hoonwerker: laacht hidjet',
    '🧑🏼‍🔧' => 'hoonwerker: madel laacht hidj',
    '🧑🏽‍🔧' => 'hoonwerker: madel hidj',
    '🧑🏾‍🔧' => 'hoonwerker: madel jonk hidj',
    '🧑🏿‍🔧' => 'hoonwerker: jonk hidj',
    '👨🏻‍🔧' => 'a hoonwerker: laacht hidjet',
    '👨🏼‍🔧' => 'a hoonwerker: madel laacht hidj',
    '👨🏽‍🔧' => 'a hoonwerker: madel hidj',
    '👨🏾‍🔧' => 'a hoonwerker: madel jonk hidj',
    '👨🏿‍🔧' => 'a hoonwerker: jonk hidj',
    '👩🏻‍🔧' => 'at hoonwerker: laacht hidjet',
    '👩🏼‍🔧' => 'at hoonwerker: madel laacht hidj',
    '👩🏽‍🔧' => 'at hoonwerker: madel hidj',
    '👩🏾‍🔧' => 'at hoonwerker: madel jonk hidj',
    '👩🏿‍🔧' => 'at hoonwerker: jonk hidj',
    '🧑🏻‍🏭' => 'fabrik werker: laacht hidjet',
    '🧑🏼‍🏭' => 'fabrik werker: madel laacht hidj',
    '🧑🏽‍🏭' => 'fabrik werker: madel hidj',
    '🧑🏾‍🏭' => 'fabrik werker: madel jonk hidj',
    '🧑🏿‍🏭' => 'fabrik werker: jonk hidj',
    '👨🏻‍🏭' => 'a fabrik werker: laacht hidjet',
    '👨🏼‍🏭' => 'a fabrik werker: madel laacht hidj',
    '👨🏽‍🏭' => 'a fabrik werker: madel hidj',
    '👨🏾‍🏭' => 'a fabrik werker: madel jonk hidj',
    '👨🏿‍🏭' => 'a fabrik werker: jonk hidj',
    '👩🏻‍🏭' => 'at fabrik werker: laacht hidjet',
    '👩🏼‍🏭' => 'at fabrik werker: madel laacht hidj',
    '👩🏽‍🏭' => 'at fabrik werker: madel hidj',
    '👩🏾‍🏭' => 'at fabrik werker: madel jonk hidj',
    '👩🏿‍🏭' => 'at fabrik werker: jonk hidj',
    '🧑🏻‍💼' => 'uunstelden: laacht hidjet',
    '🧑🏼‍💼' => 'uunstelden: madel laacht hidj',
    '🧑🏽‍💼' => 'uunstelden: madel hidj',
    '🧑🏾‍💼' => 'uunstelden: madel jonk hidj',
    '🧑🏿‍💼' => 'uunstelden: jonk hidj',
    '👨🏻‍💼' => 'a uunsteld: laacht hidjet',
    '👨🏼‍💼' => 'a uunsteld: madel laacht hidj',
    '👨🏽‍💼' => 'a uunsteld: madel hidj',
    '👨🏾‍💼' => 'a uunsteld: madel jonk hidj',
    '👨🏿‍💼' => 'a uunsteld: jonk hidj',
    '👩🏻‍💼' => 'at uunsteld: laacht hidjet',
    '👩🏼‍💼' => 'at uunsteld: madel laacht hidj',
    '👩🏽‍💼' => 'at uunsteld: madel hidj',
    '👩🏾‍💼' => 'at uunsteld: madel jonk hidj',
    '👩🏿‍💼' => 'at uunsteld: jonk hidj',
    '🧑🏻‍🔬' => 'wedenskapler: laacht hidjet',
    '🧑🏼‍🔬' => 'wedenskapler: madel laacht hidj',
    '🧑🏽‍🔬' => 'wedenskapler: madel hidj',
    '🧑🏾‍🔬' => 'wedenskapler: madel jonk hidj',
    '🧑🏿‍🔬' => 'wedenskapler: jonk hidj',
    '👨🏻‍🔬' => 'wedenskapsmaan: laacht hidjet',
    '👨🏼‍🔬' => 'wedenskapsmaan: madel laacht hidj',
    '👨🏽‍🔬' => 'wedenskapsmaan: madel hidj',
    '👨🏾‍🔬' => 'wedenskapsmaan: madel jonk hidj',
    '👨🏿‍🔬' => 'wedenskapsmaan: jonk hidj',
    '👩🏻‍🔬' => 'wedenskapswüf: laacht hidjet',
    '👩🏼‍🔬' => 'wedenskapswüf: madel laacht hidj',
    '👩🏽‍🔬' => 'wedenskapswüf: madel hidj',
    '👩🏾‍🔬' => 'wedenskapswüf: madel jonk hidj',
    '👩🏿‍🔬' => 'wedenskapswüf: jonk hidj',
    '🧑🏻‍💻' => 'IT persuun: laacht hidjet',
    '🧑🏼‍💻' => 'IT persuun: madel laacht hidj',
    '🧑🏽‍💻' => 'IT persuun: madel hidj',
    '🧑🏾‍💻' => 'IT persuun: madel jonk hidj',
    '🧑🏿‍💻' => 'IT persuun: jonk hidj',
    '👨🏻‍💻' => 'IT maan: laacht hidjet',
    '👨🏼‍💻' => 'IT maan: madel laacht hidj',
    '👨🏽‍💻' => 'IT maan: madel hidj',
    '👨🏾‍💻' => 'IT maan: madel jonk hidj',
    '👨🏿‍💻' => 'IT maan: jonk hidj',
    '👩🏻‍💻' => 'IT wüf: laacht hidjet',
    '👩🏼‍💻' => 'IT wüf: madel laacht hidj',
    '👩🏽‍💻' => 'IT wüf: madel hidj',
    '👩🏾‍💻' => 'IT wüf: madel jonk hidj',
    '👩🏿‍💻' => 'IT wüf: jonk hidj',
    '🧑🏻‍🎤' => 'sjonger: laacht hidjet',
    '🧑🏼‍🎤' => 'sjonger: madel laacht hidj',
    '🧑🏽‍🎤' => 'sjonger: madel hidj',
    '🧑🏾‍🎤' => 'sjonger: madel jonk hidj',
    '🧑🏿‍🎤' => 'sjonger: jonk hidj',
    '👨🏻‍🎤' => 'a sjonger: laacht hidjet',
    '👨🏼‍🎤' => 'a sjonger: madel laacht hidj',
    '👨🏽‍🎤' => 'a sjonger: madel hidj',
    '👨🏾‍🎤' => 'a sjonger: madel jonk hidj',
    '👨🏿‍🎤' => 'a sjonger: jonk hidj',
    '👩🏻‍🎤' => 'at sjongster: laacht hidjet',
    '👩🏼‍🎤' => 'at sjongster: madel laacht hidj',
    '👩🏽‍🎤' => 'at sjongster: madel hidj',
    '👩🏾‍🎤' => 'at sjongster: madel jonk hidj',
    '👩🏿‍🎤' => 'at sjongster: jonk hidj',
    '🧑🏻‍🎨' => 'konstler: laacht hidjet',
    '🧑🏼‍🎨' => 'konstler: madel laacht hidj',
    '🧑🏽‍🎨' => 'konstler: madel hidj',
    '🧑🏾‍🎨' => 'konstler: madel jonk hidj',
    '🧑🏿‍🎨' => 'konstler: jonk hidj',
    '👨🏻‍🎨' => 'a konstler: laacht hidjet',
    '👨🏼‍🎨' => 'a konstler: madel laacht hidj',
    '👨🏽‍🎨' => 'a konstler: madel hidj',
    '👨🏾‍🎨' => 'a konstler: madel jonk hidj',
    '👨🏿‍🎨' => 'a konstler: jonk hidj',
    '👩🏻‍🎨' => 'at konstler: laacht hidjet',
    '👩🏼‍🎨' => 'at konstler: madel laacht hidj',
    '👩🏽‍🎨' => 'at konstler: madel hidj',
    '👩🏾‍🎨' => 'at konstler: madel jonk hidj',
    '👩🏿‍🎨' => 'at konstler: jonk hidj',
    '🧑🏻‍✈' => 'piloot: laacht hidjet',
    '🧑🏼‍✈' => 'piloot: madel laacht hidj',
    '🧑🏽‍✈' => 'piloot: madel hidj',
    '🧑🏾‍✈' => 'piloot: madel jonk hidj',
    '🧑🏿‍✈' => 'piloot: jonk hidj',
    '👨🏻‍✈' => 'a piloot: laacht hidjet',
    '👨🏼‍✈' => 'a piloot: madel laacht hidj',
    '👨🏽‍✈' => 'a piloot: madel hidj',
    '👨🏾‍✈' => 'a piloot: madel jonk hidj',
    '👨🏿‍✈' => 'a piloot: jonk hidj',
    '👩🏻‍✈' => 'at piloot: laacht hidjet',
    '👩🏼‍✈' => 'at piloot: madel laacht hidj',
    '👩🏽‍✈' => 'at piloot: madel hidj',
    '👩🏾‍✈' => 'at piloot: madel jonk hidj',
    '👩🏿‍✈' => 'at piloot: jonk hidj',
    '🧑🏻‍🚀' => 'astronaut: laacht hidjet',
    '🧑🏼‍🚀' => 'astronaut: madel laacht hidj',
    '🧑🏽‍🚀' => 'astronaut: madel hidj',
    '🧑🏾‍🚀' => 'astronaut: madel jonk hidj',
    '🧑🏿‍🚀' => 'astronaut: jonk hidj',
    '👨🏻‍🚀' => 'a astronaut: laacht hidjet',
    '👨🏼‍🚀' => 'a astronaut: madel laacht hidj',
    '👨🏽‍🚀' => 'a astronaut: madel hidj',
    '👨🏾‍🚀' => 'a astronaut: madel jonk hidj',
    '👨🏿‍🚀' => 'a astronaut: jonk hidj',
    '👩🏻‍🚀' => 'at astronaut: laacht hidjet',
    '👩🏼‍🚀' => 'at astronaut: madel laacht hidj',
    '👩🏽‍🚀' => 'at astronaut: madel hidj',
    '👩🏾‍🚀' => 'at astronaut: madel jonk hidj',
    '👩🏿‍🚀' => 'at astronaut: jonk hidj',
    '🧑🏻‍🚒' => 'feuerweer persuun: laacht hidjet',
    '🧑🏼‍🚒' => 'feuerweer persuun: madel laacht hidj',
    '🧑🏽‍🚒' => 'feuerweer persuun: madel hidj',
    '🧑🏾‍🚒' => 'feuerweer persuun: madel jonk hidj',
    '🧑🏿‍🚒' => 'feuerweer persuun: jonk hidj',
    '👨🏻‍🚒' => 'feuerweer maan: laacht hidjet',
    '👨🏼‍🚒' => 'feuerweer maan: madel laacht hidj',
    '👨🏽‍🚒' => 'feuerweer maan: madel hidj',
    '👨🏾‍🚒' => 'feuerweer maan: madel jonk hidj',
    '👨🏿‍🚒' => 'feuerweer maan: jonk hidj',
    '👩🏻‍🚒' => 'feuerweer wüf: laacht hidjet',
    '👩🏼‍🚒' => 'feuerweer wüf: madel laacht hidj',
    '👩🏽‍🚒' => 'feuerweer wüf: madel hidj',
    '👩🏾‍🚒' => 'feuerweer wüf: madel jonk hidj',
    '👩🏿‍🚒' => 'feuerweer wüf: jonk hidj',
    '👮🏻‍♂' => 'a sjandaarem: laacht hidjet',
    '👮🏼‍♂' => 'a sjandaarem: madel laacht hidj',
    '👮🏽‍♂' => 'a sjandaarem: madel hidj',
    '👮🏾‍♂' => 'a sjandaarem: madel jonk hidj',
    '👮🏿‍♂' => 'a sjandaarem: jonk hidj',
    '👮🏻‍♀' => 'at sjandaarem: laacht hidjet',
    '👮🏼‍♀' => 'at sjandaarem: madel laacht hidj',
    '👮🏽‍♀' => 'at sjandaarem: madel hidj',
    '👮🏾‍♀' => 'at sjandaarem: madel jonk hidj',
    '👮🏿‍♀' => 'at sjandaarem: jonk hidj',
    '🕵🏻‍♂' => 'a detektiif: laacht hidjet',
    '🕵🏼‍♂' => 'a detektiif: madel laacht hidj',
    '🕵🏽‍♂' => 'a detektiif: madel hidj',
    '🕵🏾‍♂' => 'a detektiif: madel jonk hidj',
    '🕵🏿‍♂' => 'a detektiif: jonk hidj',
    '🕵🏻‍♀' => 'at detektiif: laacht hidjet',
    '🕵🏼‍♀' => 'at detektiif: madel laacht hidj',
    '🕵🏽‍♀' => 'at detektiif: madel hidj',
    '🕵🏾‍♀' => 'at detektiif: madel jonk hidj',
    '🕵🏿‍♀' => 'at detektiif: jonk hidj',
    '💂🏻‍♂' => 'wacht maan: laacht hidjet',
    '💂🏼‍♂' => 'wacht maan: madel laacht hidj',
    '💂🏽‍♂' => 'wacht maan: madel hidj',
    '💂🏾‍♂' => 'wacht maan: madel jonk hidj',
    '💂🏿‍♂' => 'wacht maan: jonk hidj',
    '💂🏻‍♀' => 'wacht wüf: laacht hidjet',
    '💂🏼‍♀' => 'wacht wüf: madel laacht hidj',
    '💂🏽‍♀' => 'wacht wüf: madel hidj',
    '💂🏾‍♀' => 'wacht wüf: madel jonk hidj',
    '💂🏿‍♀' => 'wacht wüf: jonk hidj',
    '👷🏻‍♂' => 'a bau hoonwerker: laacht hidjet',
    '👷🏼‍♂' => 'a bau hoonwerker: madel laacht hidj',
    '👷🏽‍♂' => 'a bau hoonwerker: madel hidj',
    '👷🏾‍♂' => 'a bau hoonwerker: madel jonk hidj',
    '👷🏿‍♂' => 'a bau hoonwerker: jonk hidj',
    '👷🏻‍♀' => 'at bau hoonwerker: laacht hidjet',
    '👷🏼‍♀' => 'at bau hoonwerker: madel laacht hidj',
    '👷🏽‍♀' => 'at bau hoonwerker: madel hidj',
    '👷🏾‍♀' => 'at bau hoonwerker: madel jonk hidj',
    '👷🏿‍♀' => 'at bau hoonwerker: jonk hidj',
    '👳🏻‍♂' => 'maan mä turbaan: laacht hidjet',
    '👳🏼‍♂' => 'maan mä turbaan: madel laacht hidj',
    '👳🏽‍♂' => 'maan mä turbaan: madel hidj',
    '👳🏾‍♂' => 'maan mä turbaan: madel jonk hidj',
    '👳🏿‍♂' => 'maan mä turbaan: jonk hidj',
    '👳🏻‍♀' => 'wüf mä turbaan: laacht hidjet',
    '👳🏼‍♀' => 'wüf mä turbaan: madel laacht hidj',
    '👳🏽‍♀' => 'wüf mä turbaan: madel hidj',
    '👳🏾‍♀' => 'wüf mä turbaan: madel jonk hidj',
    '👳🏿‍♀' => 'wüf mä turbaan: jonk hidj',
    '🤵🏻‍♂' => 'maan uun uuntooch: laacht hidjet',
    '🤵🏼‍♂' => 'maan uun uuntooch: madel laacht hidj',
    '🤵🏽‍♂' => 'maan uun uuntooch: madel hidj',
    '🤵🏾‍♂' => 'maan uun uuntooch: madel jonk hidj',
    '🤵🏿‍♂' => 'maan uun uuntooch: jonk hidj',
    '🤵🏻‍♀' => 'wüf uun uuntooch: laacht hidjet',
    '🤵🏼‍♀' => 'wüf uun uuntooch: madel laacht hidj',
    '🤵🏽‍♀' => 'wüf uun uuntooch: madel hidj',
    '🤵🏾‍♀' => 'wüf uun uuntooch: madel jonk hidj',
    '🤵🏿‍♀' => 'wüf uun uuntooch: jonk hidj',
    '👰🏻‍♂' => 'maan mä sleier: laacht hidjet',
    '👰🏼‍♂' => 'maan mä sleier: madel laacht hidj',
    '👰🏽‍♂' => 'maan mä sleier: madel hidj',
    '👰🏾‍♂' => 'maan mä sleier: madel jonk hidj',
    '👰🏿‍♂' => 'maan mä sleier: jonk hidj',
    '👰🏻‍♀' => 'wüf mä sleier: laacht hidjet',
    '👰🏼‍♀' => 'wüf mä sleier: madel laacht hidj',
    '👰🏽‍♀' => 'wüf mä sleier: madel hidj',
    '👰🏾‍♀' => 'wüf mä sleier: madel jonk hidj',
    '👰🏿‍♀' => 'wüf mä sleier: jonk hidj',
    '👩🏻‍🍼' => 'wüf tetjet letj: laacht hidjet',
    '👩🏼‍🍼' => 'wüf tetjet letj: madel laacht hidj',
    '👩🏽‍🍼' => 'wüf tetjet letj: madel hidj',
    '👩🏾‍🍼' => 'wüf tetjet letj: madel jonk hidj',
    '👩🏿‍🍼' => 'wüf tetjet letj: jonk hidj',
    '👨🏻‍🍼' => 'maan tetjet letj: laacht hidjet',
    '👨🏼‍🍼' => 'maan tetjet letj: madel laacht hidj',
    '👨🏽‍🍼' => 'maan tetjet letj: madel hidj',
    '👨🏾‍🍼' => 'maan tetjet letj: madel jonk hidj',
    '👨🏿‍🍼' => 'maan tetjet letj: jonk hidj',
    '🧑🏻‍🍼' => 'persuun tetjet letj: laacht hidjet',
    '🧑🏼‍🍼' => 'persuun tetjet letj: madel laacht hidj',
    '🧑🏽‍🍼' => 'persuun tetjet letj: madel hidj',
    '🧑🏾‍🍼' => 'persuun tetjet letj: madel jonk hidj',
    '🧑🏿‍🍼' => 'persuun tetjet letj: jonk hidj',
    '🧑🏻‍🎄' => 'jong weinachswüf: laacht hidjet',
    '🧑🏼‍🎄' => 'jong weinachswüf: madel laacht hidj',
    '🧑🏽‍🎄' => 'jong weinachswüf: madel hidj',
    '🧑🏾‍🎄' => 'jong weinachswüf: madel jonk hidj',
    '🧑🏿‍🎄' => 'jong weinachswüf: jonk hidj',
    '🦸🏻‍♂' => 'a superhelt: laacht hidjet',
    '🦸🏼‍♂' => 'a superhelt: madel laacht hidj',
    '🦸🏽‍♂' => 'a superhelt: madel hidj',
    '🦸🏾‍♂' => 'a superhelt: madel jonk hidj',
    '🦸🏿‍♂' => 'a superhelt: jonk hidj',
    '🦸🏻‍♀' => 'at superhelt: laacht hidjet',
    '🦸🏼‍♀' => 'at superhelt: madel laacht hidj',
    '🦸🏽‍♀' => 'at superhelt: madel hidj',
    '🦸🏾‍♀' => 'at superhelt: madel jonk hidj',
    '🦸🏿‍♀' => 'at superhelt: jonk hidj',
    '🦹🏻‍♂' => 'a superskork: laacht hidjet',
    '🦹🏼‍♂' => 'a superskork: madel laacht hidj',
    '🦹🏽‍♂' => 'a superskork: madel hidj',
    '🦹🏾‍♂' => 'a superskork: madel jonk hidj',
    '🦹🏿‍♂' => 'a superskork: jonk hidj',
    '🦹🏻‍♀' => 'at superskork: laacht hidjet',
    '🦹🏼‍♀' => 'at superskork: madel laacht hidj',
    '🦹🏽‍♀' => 'at superskork: madel hidj',
    '🦹🏾‍♀' => 'at superskork: madel jonk hidj',
    '🦹🏿‍♀' => 'at superskork: jonk hidj',
    '🧙🏻‍♂' => 'a trool: laacht hidjet',
    '🧙🏼‍♂' => 'a trool: madel laacht hidj',
    '🧙🏽‍♂' => 'a trool: madel hidj',
    '🧙🏾‍♂' => 'a trool: madel jonk hidj',
    '🧙🏿‍♂' => 'a trool: jonk hidj',
    '🧙🏻‍♀' => 'at heks: laacht hidjet',
    '🧙🏼‍♀' => 'at heks: madel laacht hidj',
    '🧙🏽‍♀' => 'at heks: madel hidj',
    '🧙🏾‍♀' => 'at heks: madel jonk hidj',
    '🧙🏿‍♀' => 'at heks: jonk hidj',
    '🧚🏻‍♂' => 'a fee: laacht hidjet',
    '🧚🏼‍♂' => 'a fee: madel laacht hidj',
    '🧚🏽‍♂' => 'a fee: madel hidj',
    '🧚🏾‍♂' => 'a fee: madel jonk hidj',
    '🧚🏿‍♂' => 'a fee: jonk hidj',
    '🧚🏻‍♀' => 'at fee: laacht hidjet',
    '🧚🏼‍♀' => 'at fee: madel laacht hidj',
    '🧚🏽‍♀' => 'at fee: madel hidj',
    '🧚🏾‍♀' => 'at fee: madel jonk hidj',
    '🧚🏿‍♀' => 'at fee: jonk hidj',
    '🧛🏻‍♂' => 'a wampiir: laacht hidjet',
    '🧛🏼‍♂' => 'a wampiir: madel laacht hidj',
    '🧛🏽‍♂' => 'a wampiir: madel hidj',
    '🧛🏾‍♂' => 'a wampiir: madel jonk hidj',
    '🧛🏿‍♂' => 'a wampiir: jonk hidj',
    '🧛🏻‍♀' => 'at wampiir: laacht hidjet',
    '🧛🏼‍♀' => 'at wampiir: madel laacht hidj',
    '🧛🏽‍♀' => 'at wampiir: madel hidj',
    '🧛🏾‍♀' => 'at wampiir: madel jonk hidj',
    '🧛🏿‍♀' => 'at wampiir: jonk hidj',
    '🧜🏻‍♂' => 'weedermaan: laacht hidjet',
    '🧜🏼‍♂' => 'weedermaan: madel laacht hidj',
    '🧜🏽‍♂' => 'weedermaan: madel hidj',
    '🧜🏾‍♂' => 'weedermaan: madel jonk hidj',
    '🧜🏿‍♂' => 'weedermaan: jonk hidj',
    '🧜🏻‍♀' => 'weederwüf: laacht hidjet',
    '🧜🏼‍♀' => 'weederwüf: madel laacht hidj',
    '🧜🏽‍♀' => 'weederwüf: madel hidj',
    '🧜🏾‍♀' => 'weederwüf: madel jonk hidj',
    '🧜🏿‍♀' => 'weederwüf: jonk hidj',
    '🧝🏻‍♂' => 'a elf: laacht hidjet',
    '🧝🏼‍♂' => 'a elf: madel laacht hidj',
    '🧝🏽‍♂' => 'a elf: madel hidj',
    '🧝🏾‍♂' => 'a elf: madel jonk hidj',
    '🧝🏿‍♂' => 'a elf: jonk hidj',
    '🧝🏻‍♀' => 'at elf: laacht hidjet',
    '🧝🏼‍♀' => 'at elf: madel laacht hidj',
    '🧝🏽‍♀' => 'at elf: madel hidj',
    '🧝🏾‍♀' => 'at elf: madel jonk hidj',
    '🧝🏿‍♀' => 'at elf: jonk hidj',
    '💆🏻‍♂' => 'maan masaaj: laacht hidjet',
    '💆🏼‍♂' => 'maan masaaj: madel laacht hidj',
    '💆🏽‍♂' => 'maan masaaj: madel hidj',
    '💆🏾‍♂' => 'maan masaaj: madel jonk hidj',
    '💆🏿‍♂' => 'maan masaaj: jonk hidj',
    '💆🏻‍♀' => 'wüf masaaj: laacht hidjet',
    '💆🏼‍♀' => 'wüf masaaj: madel laacht hidj',
    '💆🏽‍♀' => 'wüf masaaj: madel hidj',
    '💆🏾‍♀' => 'wüf masaaj: madel jonk hidj',
    '💆🏿‍♀' => 'wüf masaaj: jonk hidj',
    '💇🏻‍♂' => 'maan bi amklaper: laacht hidjet',
    '💇🏼‍♂' => 'maan bi amklaper: madel laacht hidj',
    '💇🏽‍♂' => 'maan bi amklaper: madel hidj',
    '💇🏾‍♂' => 'maan bi amklaper: madel jonk hidj',
    '💇🏿‍♂' => 'maan bi amklaper: jonk hidj',
    '💇🏻‍♀' => 'wüf bi amklaper: laacht hidjet',
    '💇🏼‍♀' => 'wüf bi amklaper: madel laacht hidj',
    '💇🏽‍♀' => 'wüf bi amklaper: madel hidj',
    '💇🏾‍♀' => 'wüf bi amklaper: madel jonk hidj',
    '💇🏿‍♀' => 'wüf bi amklaper: jonk hidj',
    '🚶🏻‍♂' => 'maan lääpt: laacht hidjet',
    '🚶🏼‍♂' => 'maan lääpt: madel laacht hidj',
    '🚶🏽‍♂' => 'maan lääpt: madel hidj',
    '🚶🏾‍♂' => 'maan lääpt: madel jonk hidj',
    '🚶🏿‍♂' => 'maan lääpt: jonk hidj',
    '🚶🏻‍♀' => 'wüf lääpt: laacht hidjet',
    '🚶🏼‍♀' => 'wüf lääpt: madel laacht hidj',
    '🚶🏽‍♀' => 'wüf lääpt: madel hidj',
    '🚶🏾‍♀' => 'wüf lääpt: madel jonk hidj',
    '🚶🏿‍♀' => 'wüf lääpt: jonk hidj',
    '🚶🏻‍➡' => 'persuun lääpt: laacht hidjet an rochts am',
    '🚶🏼‍➡' => 'persuun lääpt: madel laacht hidj an rochts am',
    '🚶🏽‍➡' => 'persuun lääpt: madel hidj an rochts am',
    '🚶🏾‍➡' => 'persuun lääpt: madel jonk hidj an rochts am',
    '🚶🏿‍➡' => 'persuun lääpt: jonk hidj an rochts am',
    '🧍🏻‍♂' => 'maan stäänt: laacht hidjet',
    '🧍🏼‍♂' => 'maan stäänt: madel laacht hidj',
    '🧍🏽‍♂' => 'maan stäänt: madel hidj',
    '🧍🏾‍♂' => 'maan stäänt: madel jonk hidj',
    '🧍🏿‍♂' => 'maan stäänt: jonk hidj',
    '🧍🏻‍♀' => 'wüf stäänt: laacht hidjet',
    '🧍🏼‍♀' => 'wüf stäänt: madel laacht hidj',
    '🧍🏽‍♀' => 'wüf stäänt: madel hidj',
    '🧍🏾‍♀' => 'wüf stäänt: madel jonk hidj',
    '🧍🏿‍♀' => 'wüf stäänt: jonk hidj',
    '🧎🏻‍♂' => 'man üüb knöbian: laacht hidjet',
    '🧎🏼‍♂' => 'man üüb knöbian: madel laacht hidj',
    '🧎🏽‍♂' => 'man üüb knöbian: madel hidj',
    '🧎🏾‍♂' => 'man üüb knöbian: madel jonk hidj',
    '🧎🏿‍♂' => 'man üüb knöbian: jonk hidj',
    '🧎🏻‍♀' => 'wüf üüb knöbian: laacht hidjet',
    '🧎🏼‍♀' => 'wüf üüb knöbian: madel laacht hidj',
    '🧎🏽‍♀' => 'wüf üüb knöbian: madel hidj',
    '🧎🏾‍♀' => 'wüf üüb knöbian: madel jonk hidj',
    '🧎🏿‍♀' => 'wüf üüb knöbian: jonk hidj',
    '🧎🏻‍➡' => 'persuun üüb knöbian: laacht hidjet an rochts am',
    '🧎🏼‍➡' => 'persuun üüb knöbian: madel laacht hidj an rochts am',
    '🧎🏽‍➡' => 'persuun üüb knöbian: madel hidj an rochts am',
    '🧎🏾‍➡' => 'persuun üüb knöbian: madel jonk hidj an rochts am',
    '🧎🏿‍➡' => 'persuun üüb knöbian: jonk hidj an rochts am',
    '🧑🏻‍🦯' => 'persuun mä blinjenstook: laacht hidjet',
    '🧑🏼‍🦯' => 'persuun mä blinjenstook: madel laacht hidj',
    '🧑🏽‍🦯' => 'persuun mä blinjenstook: madel hidj',
    '🧑🏾‍🦯' => 'persuun mä blinjenstook: madel jonk hidj',
    '🧑🏿‍🦯' => 'persuun mä blinjenstook: jonk hidj',
    '👨🏻‍🦯' => 'maan mä blinjenstook: laacht hidjet',
    '👨🏼‍🦯' => 'maan mä blinjenstook: madel laacht hidj',
    '👨🏽‍🦯' => 'maan mä blinjenstook: madel hidj',
    '👨🏾‍🦯' => 'maan mä blinjenstook: madel jonk hidj',
    '👨🏿‍🦯' => 'maan mä blinjenstook: jonk hidj',
    '👩🏻‍🦯' => 'wüf mä blinjenstook: laacht hidjet',
    '👩🏼‍🦯' => 'wüf mä blinjenstook: madel laacht hidj',
    '👩🏽‍🦯' => 'wüf mä blinjenstook: madel hidj',
    '👩🏾‍🦯' => 'wüf mä blinjenstook: madel jonk hidj',
    '👩🏿‍🦯' => 'wüf mä blinjenstook: jonk hidj',
    '🧑🏻‍🦼' => 'persuun üüb elektro rolstuul: laacht hidjet',
    '🧑🏼‍🦼' => 'persuun üüb elektro rolstuul: madel laacht hidj',
    '🧑🏽‍🦼' => 'persuun üüb elektro rolstuul: madel hidj',
    '🧑🏾‍🦼' => 'persuun üüb elektro rolstuul: madel jonk hidj',
    '🧑🏿‍🦼' => 'persuun üüb elektro rolstuul: jonk hidj',
    '👨🏻‍🦼' => 'maan üüb elektro rolstuul: laacht hidjet',
    '👨🏼‍🦼' => 'maan üüb elektro rolstuul: madel laacht hidj',
    '👨🏽‍🦼' => 'maan üüb elektro rolstuul: madel hidj',
    '👨🏾‍🦼' => 'maan üüb elektro rolstuul: madel jonk hidj',
    '👨🏿‍🦼' => 'maan üüb elektro rolstuul: jonk hidj',
    '👩🏻‍🦼' => 'wüf üüb elektro rolstuul: laacht hidjet',
    '👩🏼‍🦼' => 'wüf üüb elektro rolstuul: madel laacht hidj',
    '👩🏽‍🦼' => 'wüf üüb elektro rolstuul: madel hidj',
    '👩🏾‍🦼' => 'wüf üüb elektro rolstuul: madel jonk hidj',
    '👩🏿‍🦼' => 'wüf üüb elektro rolstuul: jonk hidj',
    '🧑🏻‍🦽' => 'persuun üüb rolstuul: laacht hidjet',
    '🧑🏼‍🦽' => 'persuun üüb rolstuul: madel laacht hidj',
    '🧑🏽‍🦽' => 'persuun üüb rolstuul: madel hidj',
    '🧑🏾‍🦽' => 'persuun üüb rolstuul: madel jonk hidj',
    '🧑🏿‍🦽' => 'persuun üüb rolstuul: jonk hidj',
    '👨🏻‍🦽' => 'maan üüb rolstuul: laacht hidjet',
    '👨🏼‍🦽' => 'maan üüb rolstuul: madel laacht hidj',
    '👨🏽‍🦽' => 'maan üüb rolstuul: madel hidj',
    '👨🏾‍🦽' => 'maan üüb rolstuul: madel jonk hidj',
    '👨🏿‍🦽' => 'maan üüb rolstuul: jonk hidj',
    '👩🏻‍🦽' => 'wüf üüb rolstuul: laacht hidjet',
    '👩🏼‍🦽' => 'wüf üüb rolstuul: madel laacht hidj',
    '👩🏽‍🦽' => 'wüf üüb rolstuul: madel hidj',
    '👩🏾‍🦽' => 'wüf üüb rolstuul: madel jonk hidj',
    '👩🏿‍🦽' => 'wüf üüb rolstuul: jonk hidj',
    '🏃🏻‍♂' => 'maan räänt: laacht hidjet',
    '🏃🏼‍♂' => 'maan räänt: madel laacht hidj',
    '🏃🏽‍♂' => 'maan räänt: madel hidj',
    '🏃🏾‍♂' => 'maan räänt: madel jonk hidj',
    '🏃🏿‍♂' => 'maan räänt: jonk hidj',
    '🏃🏻‍♀' => 'wüf räänt: laacht hidjet',
    '🏃🏼‍♀' => 'wüf räänt: madel laacht hidj',
    '🏃🏽‍♀' => 'wüf räänt: madel hidj',
    '🏃🏾‍♀' => 'wüf räänt: madel jonk hidj',
    '🏃🏿‍♀' => 'wüf räänt: jonk hidj',
    '🏃🏻‍➡' => 'persuun räänt: laacht hidjet an rochts am',
    '🏃🏼‍➡' => 'persuun räänt: madel laacht hidj an rochts am',
    '🏃🏽‍➡' => 'persuun räänt: madel hidj an rochts am',
    '🏃🏾‍➡' => 'persuun räänt: madel jonk hidj an rochts am',
    '🏃🏿‍➡' => 'persuun räänt: jonk hidj an rochts am',
    '👯🏻‍♀' => 'wüfen mä haasuaren: laacht hidjet',
    '👯🏼‍♀' => 'wüfen mä haasuaren: madel laacht hidj',
    '👯🏽‍♀' => 'wüfen mä haasuaren: madel hidj',
    '👯🏾‍♀' => 'wüfen mä haasuaren: madel jonk hidj',
    '👯🏿‍♀' => 'wüfen mä haasuaren: jonk hidj',
    '👯🏻‍♂' => 'maaner mä haasuaren: laacht hidjet',
    '👯🏼‍♂' => 'maaner mä haasuaren: madel laacht hidj',
    '👯🏽‍♂' => 'maaner mä haasuaren: madel hidj',
    '👯🏾‍♂' => 'maaner mä haasuaren: madel jonk hidj',
    '👯🏿‍♂' => 'maaner mä haasuaren: jonk hidj',
    '🧖🏻‍♂' => 'maan uun sauna: laacht hidjet',
    '🧖🏼‍♂' => 'maan uun sauna: madel laacht hidj',
    '🧖🏽‍♂' => 'maan uun sauna: madel hidj',
    '🧖🏾‍♂' => 'maan uun sauna: madel jonk hidj',
    '🧖🏿‍♂' => 'maan uun sauna: jonk hidj',
    '🧖🏻‍♀' => 'wüf uun sauna: laacht hidjet',
    '🧖🏼‍♀' => 'wüf uun sauna: madel laacht hidj',
    '🧖🏽‍♀' => 'wüf uun sauna: madel hidj',
    '🧖🏾‍♀' => 'wüf uun sauna: madel jonk hidj',
    '🧖🏿‍♀' => 'wüf uun sauna: jonk hidj',
    '🧗🏻‍♂' => 'maan klemert: laacht hidjet',
    '🧗🏼‍♂' => 'maan klemert: madel laacht hidj',
    '🧗🏽‍♂' => 'maan klemert: madel hidj',
    '🧗🏾‍♂' => 'maan klemert: madel jonk hidj',
    '🧗🏿‍♂' => 'maan klemert: jonk hidj',
    '🧗🏻‍♀' => 'wüf klemert: laacht hidjet',
    '🧗🏼‍♀' => 'wüf klemert: madel laacht hidj',
    '🧗🏽‍♀' => 'wüf klemert: madel hidj',
    '🧗🏾‍♀' => 'wüf klemert: madel jonk hidj',
    '🧗🏿‍♀' => 'wüf klemert: jonk hidj',
    '🏌🏻‍♂' => 'a golfspeler: laacht hidjet',
    '🏌🏼‍♂' => 'a golfspeler: madel laacht hidj',
    '🏌🏽‍♂' => 'a golfspeler: madel hidj',
    '🏌🏾‍♂' => 'a golfspeler: madel jonk hidj',
    '🏌🏿‍♂' => 'a golfspeler: jonk hidj',
    '🏌🏻‍♀' => 'at golfspeler: laacht hidjet',
    '🏌🏼‍♀' => 'at golfspeler: madel laacht hidj',
    '🏌🏽‍♀' => 'at golfspeler: madel hidj',
    '🏌🏾‍♀' => 'at golfspeler: madel jonk hidj',
    '🏌🏿‍♀' => 'at golfspeler: jonk hidj',
    '🏄🏻‍♂' => 'a surfer: laacht hidjet',
    '🏄🏼‍♂' => 'a surfer: madel laacht hidj',
    '🏄🏽‍♂' => 'a surfer: madel hidj',
    '🏄🏾‍♂' => 'a surfer: madel jonk hidj',
    '🏄🏿‍♂' => 'a surfer: jonk hidj',
    '🏄🏻‍♀' => 'at surfer: laacht hidjet',
    '🏄🏼‍♀' => 'at surfer: madel laacht hidj',
    '🏄🏽‍♀' => 'at surfer: madel hidj',
    '🏄🏾‍♀' => 'at surfer: madel jonk hidj',
    '🏄🏿‍♀' => 'at surfer: jonk hidj',
    '🚣🏻‍♂' => 'maan ruit buat: laacht hidjet',
    '🚣🏼‍♂' => 'maan ruit buat: madel laacht hidj',
    '🚣🏽‍♂' => 'maan ruit buat: madel hidj',
    '🚣🏾‍♂' => 'maan ruit buat: madel jonk hidj',
    '🚣🏿‍♂' => 'maan ruit buat: jonk hidj',
    '🚣🏻‍♀' => 'wüf ruit buat: laacht hidjet',
    '🚣🏼‍♀' => 'wüf ruit buat: madel laacht hidj',
    '🚣🏽‍♀' => 'wüf ruit buat: madel hidj',
    '🚣🏾‍♀' => 'wüf ruit buat: madel jonk hidj',
    '🚣🏿‍♀' => 'wüf ruit buat: jonk hidj',
    '🏊🏻‍♂' => 'a swäämer: laacht hidjet',
    '🏊🏼‍♂' => 'a swäämer: madel laacht hidj',
    '🏊🏽‍♂' => 'a swäämer: madel hidj',
    '🏊🏾‍♂' => 'a swäämer: madel jonk hidj',
    '🏊🏿‍♂' => 'a swäämer: jonk hidj',
    '🏊🏻‍♀' => 'at swäämer: laacht hidjet',
    '🏊🏼‍♀' => 'at swäämer: madel laacht hidj',
    '🏊🏽‍♀' => 'at swäämer: madel hidj',
    '🏊🏾‍♀' => 'at swäämer: madel jonk hidj',
    '🏊🏿‍♀' => 'at swäämer: jonk hidj',
    '⛹🏻‍♂' => 'a baalspeler: laacht hidjet',
    '⛹🏼‍♂' => 'a baalspeler: madel laacht hidj',
    '⛹🏽‍♂' => 'a baalspeler: madel hidj',
    '⛹🏾‍♂' => 'a baalspeler: madel jonk hidj',
    '⛹🏿‍♂' => 'a baalspeler: jonk hidj',
    '⛹🏻‍♀' => 'at baalspeler: laacht hidjet',
    '⛹🏼‍♀' => 'at baalspeler: madel laacht hidj',
    '⛹🏽‍♀' => 'at baalspeler: madel hidj',
    '⛹🏾‍♀' => 'at baalspeler: madel jonk hidj',
    '⛹🏿‍♀' => 'at baalspeler: jonk hidj',
    '🏋🏻‍♂' => 'maan laft gewicht: laacht hidjet',
    '🏋🏼‍♂' => 'maan laft gewicht: madel laacht hidj',
    '🏋🏽‍♂' => 'maan laft gewicht: madel hidj',
    '🏋🏾‍♂' => 'maan laft gewicht: madel jonk hidj',
    '🏋🏿‍♂' => 'maan laft gewicht: jonk hidj',
    '🏋🏻‍♀' => 'wüf laft gewicht: laacht hidjet',
    '🏋🏼‍♀' => 'wüf laft gewicht: madel laacht hidj',
    '🏋🏽‍♀' => 'wüf laft gewicht: madel hidj',
    '🏋🏾‍♀' => 'wüf laft gewicht: madel jonk hidj',
    '🏋🏿‍♀' => 'wüf laft gewicht: jonk hidj',
    '🚴🏻‍♂' => 'a welkeerer: laacht hidjet',
    '🚴🏼‍♂' => 'a welkeerer: madel laacht hidj',
    '🚴🏽‍♂' => 'a welkeerer: madel hidj',
    '🚴🏾‍♂' => 'a welkeerer: madel jonk hidj',
    '🚴🏿‍♂' => 'a welkeerer: jonk hidj',
    '🚴🏻‍♀' => 'at welkeerer: laacht hidjet',
    '🚴🏼‍♀' => 'at welkeerer: madel laacht hidj',
    '🚴🏽‍♀' => 'at welkeerer: madel hidj',
    '🚴🏾‍♀' => 'at welkeerer: madel jonk hidj',
    '🚴🏿‍♀' => 'at welkeerer: jonk hidj',
    '🚵🏻‍♂' => 'maan üüb gelendewel: laacht hidjet',
    '🚵🏼‍♂' => 'maan üüb gelendewel: madel laacht hidj',
    '🚵🏽‍♂' => 'maan üüb gelendewel: madel hidj',
    '🚵🏾‍♂' => 'maan üüb gelendewel: madel jonk hidj',
    '🚵🏿‍♂' => 'maan üüb gelendewel: jonk hidj',
    '🚵🏻‍♀' => 'wüf üüb gelendewel: laacht hidjet',
    '🚵🏼‍♀' => 'wüf üüb gelendewel: madel laacht hidj',
    '🚵🏽‍♀' => 'wüf üüb gelendewel: madel hidj',
    '🚵🏾‍♀' => 'wüf üüb gelendewel: madel jonk hidj',
    '🚵🏿‍♀' => 'wüf üüb gelendewel: jonk hidj',
    '🤸🏻‍♂' => 'maan slait en wel: laacht hidjet',
    '🤸🏼‍♂' => 'maan slait en wel: madel laacht hidj',
    '🤸🏽‍♂' => 'maan slait en wel: madel hidj',
    '🤸🏾‍♂' => 'maan slait en wel: madel jonk hidj',
    '🤸🏿‍♂' => 'maan slait en wel: jonk hidj',
    '🤸🏻‍♀' => 'wüf slait en wel: laacht hidjet',
    '🤸🏼‍♀' => 'wüf slait en wel: madel laacht hidj',
    '🤸🏽‍♀' => 'wüf slait en wel: madel hidj',
    '🤸🏾‍♀' => 'wüf slait en wel: madel jonk hidj',
    '🤸🏿‍♀' => 'wüf slait en wel: jonk hidj',
    '🤼🏻‍♀' => 'wüfen kemfe: laacht hidjet',
    '🤼🏼‍♀' => 'wüfen kemfe: madel laacht hidj',
    '🤼🏽‍♀' => 'wüfen kemfe: madel hidj',
    '🤼🏾‍♀' => 'wüfen kemfe: madel jonk hidj',
    '🤼🏿‍♀' => 'wüfen kemfe: jonk hidj',
    '🤼🏻‍♂' => 'maaner kemfe: laacht hidjet',
    '🤼🏼‍♂' => 'maaner kemfe: madel laacht hidj',
    '🤼🏽‍♂' => 'maaner kemfe: madel hidj',
    '🤼🏾‍♂' => 'maaner kemfe: madel jonk hidj',
    '🤼🏿‍♂' => 'maaner kemfe: jonk hidj',
    '🤽🏻‍♂' => 'a weederbaalspeler: laacht hidjet',
    '🤽🏼‍♂' => 'a weederbaalspeler: madel laacht hidj',
    '🤽🏽‍♂' => 'a weederbaalspeler: madel hidj',
    '🤽🏾‍♂' => 'a weederbaalspeler: madel jonk hidj',
    '🤽🏿‍♂' => 'a weederbaalspeler: jonk hidj',
    '🤽🏻‍♀' => 'at weederbaalspeler: laacht hidjet',
    '🤽🏼‍♀' => 'at weederbaalspeler: madel laacht hidj',
    '🤽🏽‍♀' => 'at weederbaalspeler: madel hidj',
    '🤽🏾‍♀' => 'at weederbaalspeler: madel jonk hidj',
    '🤽🏿‍♀' => 'at weederbaalspeler: jonk hidj',
    '🤾🏻‍♂' => 'a hunbaalspeler: laacht hidjet',
    '🤾🏼‍♂' => 'a hunbaalspeler: madel laacht hidj',
    '🤾🏽‍♂' => 'a hunbaalspeler: madel hidj',
    '🤾🏾‍♂' => 'a hunbaalspeler: madel jonk hidj',
    '🤾🏿‍♂' => 'a hunbaalspeler: jonk hidj',
    '🤾🏻‍♀' => 'at hunbaalspeler: laacht hidjet',
    '🤾🏼‍♀' => 'at hunbaalspeler: madel laacht hidj',
    '🤾🏽‍♀' => 'at hunbaalspeler: madel hidj',
    '🤾🏾‍♀' => 'at hunbaalspeler: madel jonk hidj',
    '🤾🏿‍♀' => 'at hunbaalspeler: jonk hidj',
    '🤹🏻‍♂' => 'maan jongliaret: laacht hidjet',
    '🤹🏼‍♂' => 'maan jongliaret: madel laacht hidj',
    '🤹🏽‍♂' => 'maan jongliaret: madel hidj',
    '🤹🏾‍♂' => 'maan jongliaret: madel jonk hidj',
    '🤹🏿‍♂' => 'maan jongliaret: jonk hidj',
    '🤹🏻‍♀' => 'wüf jongliaret: laacht hidjet',
    '🤹🏼‍♀' => 'wüf jongliaret: madel laacht hidj',
    '🤹🏽‍♀' => 'wüf jongliaret: madel hidj',
    '🤹🏾‍♀' => 'wüf jongliaret: madel jonk hidj',
    '🤹🏿‍♀' => 'wüf jongliaret: jonk hidj',
    '🧘🏻‍♂' => 'maan mä lotus bian: laacht hidjet',
    '🧘🏼‍♂' => 'maan mä lotus bian: madel laacht hidj',
    '🧘🏽‍♂' => 'maan mä lotus bian: madel hidj',
    '🧘🏾‍♂' => 'maan mä lotus bian: madel jonk hidj',
    '🧘🏿‍♂' => 'maan mä lotus bian: jonk hidj',
    '🧘🏻‍♀' => 'wüf mä lotus bian: laacht hidjet',
    '🧘🏼‍♀' => 'wüf mä lotus bian: madel laacht hidj',
    '🧘🏽‍♀' => 'wüf mä lotus bian: madel hidj',
    '🧘🏾‍♀' => 'wüf mä lotus bian: madel jonk hidj',
    '🧘🏿‍♀' => 'wüf mä lotus bian: jonk hidj',
    '🧑‍🦰' => 'persuun: ruad hiar',
    '🧑‍🦱' => 'persuun: krüüsag hiar',
    '🧑‍🦳' => 'persuun: witj hiar',
    '🧑‍🦲' => 'persuun: nian hiar',
    '👨‍🦰' => 'maan: ruad hiar',
    '👨‍🦱' => 'maan: krüüsag hiar',
    '👨‍🦳' => 'maan: witj hiar',
    '👨‍🦲' => 'maan: nian hiar',
    '👩‍🦰' => 'wüf: ruad hiar',
    '👩‍🦱' => 'wüf: krüüsag hiar',
    '👩‍🦳' => 'wüf: witj hiar',
    '👩‍🦲' => 'wüf: nian hiar',
    '🚶‍➡' => 'persuun lääpt: rochts am',
    '🧎‍➡' => 'persuun üüb knöbian: rochts am',
    '🏃‍➡' => 'persuun räänt: rochts am',
    '👨‍👦' => 'famile: maan an dring',
    '👨‍👧' => 'famile: maan an foomen',
    '👩‍👦' => 'famile: wüf an dring',
    '👩‍👧' => 'famile: wüf an foomen',
    '😶‍🌫' => 'uugen uun swarken',
    '😮‍💨' => 'ütj a püst',
    '🙂‍↕' => 'hood skööde luadrocht',
    '😵‍💫' => 'spiraal uugen',
    '❤‍🔥' => 'hart mä ial',
    '❤‍🩹' => 'hart ferbünjen',
    '👁‍🗨' => 'uug uun spriak blees',
    '🧔‍♂' => 'maan mä biard',
    '👱‍♂' => 'blond maan',
    '🧔‍♀' => 'wüf mä biard',
    '👱‍♀' => 'blond wüf',
    '🙍‍♂' => 'maan bedrüüwet',
    '🙍‍♀' => 'wüf bedrüüwet',
    '🙎‍♂' => 'maan flap',
    '🙎‍♀' => 'wüf flap',
    '🙅‍♂' => 'maan naan',
    '🙅‍♀' => 'wüf naan',
    '🙆‍♂' => 'maan bliis',
    '🙆‍♀' => 'wüf bliis',
    '💁‍♂' => 'maan wiset hun',
    '💁‍♀' => 'wüf wiset hun',
    '🙋‍♂' => 'maan gröötet',
    '🙋‍♀' => 'wüf gröötet',
    '🧏‍♂' => 'duuf maan',
    '🧏‍♀' => 'duuf wüf',
    '🙇‍♂' => 'maan bocht föör',
    '🙇‍♀' => 'wüf bocht föör',
    '🤦‍♂' => 'maan palem gesicht',
    '🤦‍♀' => 'wüf palem gesicht',
    '🤷‍♂' => 'maan skolern tak',
    '🤷‍♀' => 'wüf skolern tak',
    '🧑‍⚕' => 'dochter',
    '👨‍⚕' => 'a dochter',
    '👩‍⚕' => 'at dochter',
    '🧑‍🎓' => 'student',
    '👨‍🎓' => 'a student',
    '👩‍🎓' => 'at student',
    '🧑‍🏫' => 'skuulmääster',
    '👨‍🏫' => 'a skuulmääster',
    '👩‍🏫' => 'at skuulmääster',
    '🧑‍⚖' => 'rachter',
    '👨‍⚖' => 'a rachter',
    '👩‍⚖' => 'at rachter',
    '🧑‍🌾' => 'büür',
    '👨‍🌾' => 'a büür',
    '👩‍🌾' => 'at büür',
    '🧑‍🍳' => 'kook',
    '👨‍🍳' => 'a kook',
    '👩‍🍳' => 'at kook',
    '🧑‍🔧' => 'hoonwerker',
    '👨‍🔧' => 'a hoonwerker',
    '👩‍🔧' => 'at hoonwerker',
    '🧑‍🏭' => 'fabrik werker',
    '👨‍🏭' => 'a fabrik werker',
    '👩‍🏭' => 'at fabrik werker',
    '🧑‍💼' => 'uunstelden',
    '👨‍💼' => 'a uunsteld',
    '👩‍💼' => 'at uunsteld',
    '🧑‍🔬' => 'wedenskapler',
    '👨‍🔬' => 'wedenskapsmaan',
    '👩‍🔬' => 'wedenskapswüf',
    '🧑‍💻' => 'IT persuun',
    '👨‍💻' => 'IT maan',
    '👩‍💻' => 'IT wüf',
    '🧑‍🎤' => 'sjonger',
    '👨‍🎤' => 'a sjonger',
    '👩‍🎤' => 'at sjongster',
    '🧑‍🎨' => 'konstler',
    '👨‍🎨' => 'a konstler',
    '👩‍🎨' => 'at konstler',
    '🧑‍✈' => 'piloot',
    '👨‍✈' => 'a piloot',
    '👩‍✈' => 'at piloot',
    '🧑‍🚀' => 'astronaut',
    '👨‍🚀' => 'a astronaut',
    '👩‍🚀' => 'at astronaut',
    '🧑‍🚒' => 'feuerweer persuun',
    '👨‍🚒' => 'feuerweer maan',
    '👩‍🚒' => 'feuerweer wüf',
    '👮‍♂' => 'a sjandaarem',
    '👮‍♀' => 'at sjandaarem',
    '🕵‍♂' => 'a detektiif',
    '🕵‍♀' => 'at detektiif',
    '💂‍♂' => 'wacht maan',
    '💂‍♀' => 'wacht wüf',
    '👷‍♂' => 'a bau hoonwerker',
    '👷‍♀' => 'at bau hoonwerker',
    '👳‍♂' => 'maan mä turbaan',
    '👳‍♀' => 'wüf mä turbaan',
    '🤵‍♂' => 'maan uun uuntooch',
    '🤵‍♀' => 'wüf uun uuntooch',
    '👰‍♂' => 'maan mä sleier',
    '👰‍♀' => 'wüf mä sleier',
    '👩‍🍼' => 'wüf tetjet letj',
    '👨‍🍼' => 'maan tetjet letj',
    '🧑‍🍼' => 'persuun tetjet letj',
    '🧑‍🎄' => 'jong weinachswüf',
    '🦸‍♂' => 'a superhelt',
    '🦸‍♀' => 'at superhelt',
    '🦹‍♂' => 'a superskork',
    '🦹‍♀' => 'at superskork',
    '🧙‍♂' => 'a trool',
    '🧙‍♀' => 'at heks',
    '🧚‍♂' => 'a fee',
    '🧚‍♀' => 'at fee',
    '🧛‍♂' => 'a wampiir',
    '🧛‍♀' => 'at wampiir',
    '🧜‍♂' => 'weedermaan',
    '🧜‍♀' => 'weederwüf',
    '🧝‍♂' => 'a elf',
    '🧝‍♀' => 'at elf',
    '🧞‍♂' => 'a geist',
    '🧞‍♀' => 'at geist',
    '🧟‍♂' => 'a zombie',
    '🧟‍♀' => 'at zombie',
    '💆‍♂' => 'maan masaaj',
    '💆‍♀' => 'wüf masaaj',
    '💇‍♂' => 'maan bi amklaper',
    '💇‍♀' => 'wüf bi amklaper',
    '🚶‍♂' => 'maan lääpt',
    '🚶‍♀' => 'wüf lääpt',
    '🧍‍♂' => 'maan stäänt',
    '🧍‍♀' => 'wüf stäänt',
    '🧎‍♂' => 'man üüb knöbian',
    '🧎‍♀' => 'wüf üüb knöbian',
    '🧑‍🦯' => 'persuun mä blinjenstook',
    '👨‍🦯' => 'maan mä blinjenstook',
    '👩‍🦯' => 'wüf mä blinjenstook',
    '🧑‍🦼' => 'persuun üüb elektro rolstuul',
    '👨‍🦼' => 'maan üüb elektro rolstuul',
    '👩‍🦼' => 'wüf üüb elektro rolstuul',
    '🧑‍🦽' => 'persuun üüb rolstuul',
    '👨‍🦽' => 'maan üüb rolstuul',
    '👩‍🦽' => 'wüf üüb rolstuul',
    '🏃‍♂' => 'maan räänt',
    '🏃‍♀' => 'wüf räänt',
    '🧑‍🩰' => 'balet daanser',
    '👯‍♂' => 'maaner mä haasuaren',
    '👯‍♀' => 'wüfen mä haasuaren',
    '🧖‍♂' => 'maan uun sauna',
    '🧖‍♀' => 'wüf uun sauna',
    '🧗‍♂' => 'maan klemert',
    '🧗‍♀' => 'wüf klemert',
    '🏌‍♂' => 'a golfspeler',
    '🏌‍♀' => 'at golfspeler',
    '🏄‍♂' => 'a surfer',
    '🏄‍♀' => 'at surfer',
    '🚣‍♂' => 'maan ruit buat',
    '🚣‍♀' => 'wüf ruit buat',
    '🏊‍♂' => 'a swäämer',
    '🏊‍♀' => 'at swäämer',
    '⛹‍♂' => 'a baalspeler',
    '⛹‍♀' => 'at baalspeler',
    '🏋‍♂' => 'maan laft gewicht',
    '🏋‍♀' => 'wüf laft gewicht',
    '🚴‍♂' => 'a welkeerer',
    '🚴‍♀' => 'at welkeerer',
    '🚵‍♂' => 'maan üüb gelendewel',
    '🚵‍♀' => 'wüf üüb gelendewel',
    '🤸‍♂' => 'maan slait en wel',
    '🤸‍♀' => 'wüf slait en wel',
    '🤼‍♂' => 'maaner kemfe',
    '🤼‍♀' => 'wüfen kemfe',
    '🤽‍♂' => 'a weederbaalspeler',
    '🤽‍♀' => 'at weederbaalspeler',
    '🤾‍♂' => 'a hunbaalspeler',
    '🤾‍♀' => 'at hunbaalspeler',
    '🤹‍♂' => 'maan jongliaret',
    '🤹‍♀' => 'wüf jongliaret',
    '🧘‍♂' => 'maan mä lotus bian',
    '🧘‍♀' => 'wüf mä lotus bian',
    '🧑‍🧒' => 'ään woksenen, ian kint',
    '🐕‍🦺' => 'halep hünj',
    '🐈‍⬛' => 'suart kaat',
    '🐻‍❄' => 'isbeer',
    '🐦‍⬛' => 'kramper',
    '🐦‍🔥' => 'phoenix',
    '🍋‍🟩' => 'limoon',
    '🍄‍🟫' => 'champignon',
    '⛓‍💥' => 'breegen keed',
    '🏳‍🌈' => 'rinböög flag',
    '🏳‍⚧' => 'transgender flag',
    '🏴‍☠' => 'piraaten flag',
    '👋🏻' => 'hun wiafte: laacht hidjet',
    '👋🏼' => 'hun wiafte: madel laacht hidj',
    '👋🏽' => 'hun wiafte: madel hidj',
    '👋🏾' => 'hun wiafte: madel jonk hidj',
    '👋🏿' => 'hun wiafte: jonk hidj',
    '🤚🏻' => 'hun huuch bütjen: laacht hidjet',
    '🤚🏼' => 'hun huuch bütjen: madel laacht hidj',
    '🤚🏽' => 'hun huuch bütjen: madel hidj',
    '🤚🏾' => 'hun huuch bütjen: madel jonk hidj',
    '🤚🏿' => 'hun huuch bütjen: jonk hidj',
    '🖐🏻' => 'hun mä fangern: laacht hidjet',
    '🖐🏼' => 'hun mä fangern: madel laacht hidj',
    '🖐🏽' => 'hun mä fangern: madel hidj',
    '🖐🏾' => 'hun mä fangern: madel jonk hidj',
    '🖐🏿' => 'hun mä fangern: jonk hidj',
    '✋🏻' => 'hun huuch banen: laacht hidjet',
    '✋🏼' => 'hun huuch banen: madel laacht hidj',
    '✋🏽' => 'hun huuch banen: madel hidj',
    '✋🏾' => 'hun huuch banen: madel jonk hidj',
    '✋🏿' => 'hun huuch banen: jonk hidj',
    '🖖🏻' => 'hun wulkaan gröötnis: laacht hidjet',
    '🖖🏼' => 'hun wulkaan gröötnis: madel laacht hidj',
    '🖖🏽' => 'hun wulkaan gröötnis: madel hidj',
    '🖖🏾' => 'hun wulkaan gröötnis: madel jonk hidj',
    '🖖🏿' => 'hun wulkaan gröötnis: jonk hidj',
    '🫱🏻' => 'hun rochts: laacht hidjet',
    '🫱🏼' => 'hun rochts: madel laacht hidj',
    '🫱🏽' => 'hun rochts: madel hidj',
    '🫱🏾' => 'hun rochts: madel jonk hidj',
    '🫱🏿' => 'hun rochts: jonk hidj',
    '🫲🏻' => 'hun lachts: laacht hidjet',
    '🫲🏼' => 'hun lachts: madel laacht hidj',
    '🫲🏽' => 'hun lachts: madel hidj',
    '🫲🏾' => 'hun lachts: madel jonk hidj',
    '🫲🏿' => 'hun lachts: jonk hidj',
    '🫳🏻' => 'hun palem deel: laacht hidjet',
    '🫳🏼' => 'hun palem deel: madel laacht hidj',
    '🫳🏽' => 'hun palem deel: madel hidj',
    '🫳🏾' => 'hun palem deel: madel jonk hidj',
    '🫳🏿' => 'hun palem deel: jonk hidj',
    '🫴🏻' => 'hun palem ap: laacht hidjet',
    '🫴🏼' => 'hun palem ap: madel laacht hidj',
    '🫴🏽' => 'hun palem ap: madel hidj',
    '🫴🏾' => 'hun palem ap: madel jonk hidj',
    '🫴🏿' => 'hun palem ap: jonk hidj',
    '🫷🏻' => 'hun pui lachts: laacht hidjet',
    '🫷🏼' => 'hun pui lachts: madel laacht hidj',
    '🫷🏽' => 'hun pui lachts: madel hidj',
    '🫷🏾' => 'hun pui lachts: madel jonk hidj',
    '🫷🏿' => 'hun pui lachts: jonk hidj',
    '🫸🏻' => 'hun pui rochts: laacht hidjet',
    '🫸🏼' => 'hun pui rochts: madel laacht hidj',
    '🫸🏽' => 'hun pui rochts: madel hidj',
    '🫸🏾' => 'hun pui rochts: madel jonk hidj',
    '🫸🏿' => 'hun pui rochts: jonk hidj',
    '👌🏻' => 'hun OK: laacht hidjet',
    '👌🏼' => 'hun OK: madel laacht hidj',
    '👌🏽' => 'hun OK: madel hidj',
    '👌🏾' => 'hun OK: madel jonk hidj',
    '👌🏿' => 'hun OK: jonk hidj',
    '🤌🏻' => 'hun tuupkläämd fangern: laacht hidjet',
    '🤌🏼' => 'hun tuupkläämd fangern: madel laacht hidj',
    '🤌🏽' => 'hun tuupkläämd fangern: madel hidj',
    '🤌🏾' => 'hun tuupkläämd fangern: madel jonk hidj',
    '🤌🏿' => 'hun tuupkläämd fangern: jonk hidj',
    '🤏🏻' => 'hun tuupkläämd: laacht hidjet',
    '🤏🏼' => 'hun tuupkläämd: madel laacht hidj',
    '🤏🏽' => 'hun tuupkläämd: madel hidj',
    '🤏🏾' => 'hun tuupkläämd: madel jonk hidj',
    '🤏🏿' => 'hun tuupkläämd: jonk hidj',
    '✌🏻' => 'waner hun: laacht hidjet',
    '✌🏼' => 'waner hun: madel laacht hidj',
    '✌🏽' => 'waner hun: madel hidj',
    '✌🏾' => 'waner hun: madel jonk hidj',
    '✌🏿' => 'waner hun: jonk hidj',
    '🤞🏻' => 'fangern auerkrüs: laacht hidjet',
    '🤞🏼' => 'fangern auerkrüs: madel laacht hidj',
    '🤞🏽' => 'fangern auerkrüs: madel hidj',
    '🤞🏾' => 'fangern auerkrüs: madel jonk hidj',
    '🤞🏿' => 'fangern auerkrüs: jonk hidj',
    '🫰🏻' => 'jil fanger: laacht hidjet',
    '🫰🏼' => 'jil fanger: madel laacht hidj',
    '🫰🏽' => 'jil fanger: madel hidj',
    '🫰🏾' => 'jil fanger: madel jonk hidj',
    '🫰🏿' => 'jil fanger: jonk hidj',
    '🤟🏻' => 'leefde fangern: laacht hidjet',
    '🤟🏼' => 'leefde fangern: madel laacht hidj',
    '🤟🏽' => 'leefde fangern: madel hidj',
    '🤟🏾' => 'leefde fangern: madel jonk hidj',
    '🤟🏿' => 'leefde fangern: jonk hidj',
    '🤘🏻' => 'hurner fangern: laacht hidjet',
    '🤘🏼' => 'hurner fangern: madel laacht hidj',
    '🤘🏽' => 'hurner fangern: madel hidj',
    '🤘🏾' => 'hurner fangern: madel jonk hidj',
    '🤘🏿' => 'hurner fangern: jonk hidj',
    '🤙🏻' => 'tilefoon fangern: laacht hidjet',
    '🤙🏼' => 'tilefoon fangern: madel laacht hidj',
    '🤙🏽' => 'tilefoon fangern: madel hidj',
    '🤙🏾' => 'tilefoon fangern: madel jonk hidj',
    '🤙🏿' => 'tilefoon fangern: jonk hidj',
    '👈🏻' => 'hun bääft wiisfanger lachts: laacht hidjet',
    '👈🏼' => 'hun bääft wiisfanger lachts: madel laacht hidj',
    '👈🏽' => 'hun bääft wiisfanger lachts: madel hidj',
    '👈🏾' => 'hun bääft wiisfanger lachts: madel jonk hidj',
    '👈🏿' => 'hun bääft wiisfanger lachts: jonk hidj',
    '👉🏻' => 'hun bääft wiisfanger rochts: laacht hidjet',
    '👉🏼' => 'hun bääft wiisfanger rochts: madel laacht hidj',
    '👉🏽' => 'hun bääft wiisfanger rochts: madel hidj',
    '👉🏾' => 'hun bääft wiisfanger rochts: madel jonk hidj',
    '👉🏿' => 'hun bääft wiisfanger rochts: jonk hidj',
    '👆🏻' => 'hun bääft wiisfanger ap: laacht hidjet',
    '👆🏼' => 'hun bääft wiisfanger ap: madel laacht hidj',
    '👆🏽' => 'hun bääft wiisfanger ap: madel hidj',
    '👆🏾' => 'hun bääft wiisfanger ap: madel jonk hidj',
    '👆🏿' => 'hun bääft wiisfanger ap: jonk hidj',
    '🖕🏻' => 'hun bääft madelfanger ap: laacht hidjet',
    '🖕🏼' => 'hun bääft madelfanger ap: madel laacht hidj',
    '🖕🏽' => 'hun bääft madelfanger ap: madel hidj',
    '🖕🏾' => 'hun bääft madelfanger ap: madel jonk hidj',
    '🖕🏿' => 'hun bääft madelfanger ap: jonk hidj',
    '👇🏻' => 'hun bääft wiisfanger deeel: laacht hidjet',
    '👇🏼' => 'hun bääft wiisfanger deeel: madel laacht hidj',
    '👇🏽' => 'hun bääft wiisfanger deeel: madel hidj',
    '👇🏾' => 'hun bääft wiisfanger deeel: madel jonk hidj',
    '👇🏿' => 'hun bääft wiisfanger deeel: jonk hidj',
    '☝🏻' => 'hun föör wiisfanger ap: laacht hidjet',
    '☝🏼' => 'hun föör wiisfanger ap: madel laacht hidj',
    '☝🏽' => 'hun föör wiisfanger ap: madel hidj',
    '☝🏾' => 'hun föör wiisfanger ap: madel jonk hidj',
    '☝🏿' => 'hun föör wiisfanger ap: jonk hidj',
    '🫵🏻' => 'wiisfanger üüb mi tu: laacht hidjet',
    '🫵🏼' => 'wiisfanger üüb mi tu: madel laacht hidj',
    '🫵🏽' => 'wiisfanger üüb mi tu: madel hidj',
    '🫵🏾' => 'wiisfanger üüb mi tu: madel jonk hidj',
    '🫵🏿' => 'wiisfanger üüb mi tu: jonk hidj',
    '👍🏻' => 'süm ap: laacht hidjet',
    '👍🏼' => 'süm ap: madel laacht hidj',
    '👍🏽' => 'süm ap: madel hidj',
    '👍🏾' => 'süm ap: madel jonk hidj',
    '👍🏿' => 'süm ap: jonk hidj',
    '👎🏻' => 'süm deel: laacht hidjet',
    '👎🏼' => 'süm deel: madel laacht hidj',
    '👎🏽' => 'süm deel: madel hidj',
    '👎🏾' => 'süm deel: madel jonk hidj',
    '👎🏿' => 'süm deel: jonk hidj',
    '✊🏻' => 'fist: laacht hidjet',
    '✊🏼' => 'fist: madel laacht hidj',
    '✊🏽' => 'fist: madel hidj',
    '✊🏾' => 'fist: madel jonk hidj',
    '✊🏿' => 'fist: jonk hidj',
    '👊🏻' => 'fist üüb mi tu: laacht hidjet',
    '👊🏼' => 'fist üüb mi tu: madel laacht hidj',
    '👊🏽' => 'fist üüb mi tu: madel hidj',
    '👊🏾' => 'fist üüb mi tu: madel jonk hidj',
    '👊🏿' => 'fist üüb mi tu: jonk hidj',
    '🤛🏻' => 'fist lachts: laacht hidjet',
    '🤛🏼' => 'fist lachts: madel laacht hidj',
    '🤛🏽' => 'fist lachts: madel hidj',
    '🤛🏾' => 'fist lachts: madel jonk hidj',
    '🤛🏿' => 'fist lachts: jonk hidj',
    '🤜🏻' => 'fist rochts: laacht hidjet',
    '🤜🏼' => 'fist rochts: madel laacht hidj',
    '🤜🏽' => 'fist rochts: madel hidj',
    '🤜🏾' => 'fist rochts: madel jonk hidj',
    '🤜🏿' => 'fist rochts: jonk hidj',
    '👏🏻' => 'hunen klape: laacht hidjet',
    '👏🏼' => 'hunen klape: madel laacht hidj',
    '👏🏽' => 'hunen klape: madel hidj',
    '👏🏾' => 'hunen klape: madel jonk hidj',
    '👏🏿' => 'hunen klape: jonk hidj',
    '🙌🏻' => 'hunen huuch: laacht hidjet',
    '🙌🏼' => 'hunen huuch: madel laacht hidj',
    '🙌🏽' => 'hunen huuch: madel hidj',
    '🙌🏾' => 'hunen huuch: madel jonk hidj',
    '🙌🏿' => 'hunen huuch: jonk hidj',
    '🫶🏻' => 'hart hunen: laacht hidjet',
    '🫶🏼' => 'hart hunen: madel laacht hidj',
    '🫶🏽' => 'hart hunen: madel hidj',
    '🫶🏾' => 'hart hunen: madel jonk hidj',
    '🫶🏿' => 'hart hunen: jonk hidj',
    '👐🏻' => 'eeben hunen: laacht hidjet',
    '👐🏼' => 'eeben hunen: madel laacht hidj',
    '👐🏽' => 'eeben hunen: madel hidj',
    '👐🏾' => 'eeben hunen: madel jonk hidj',
    '👐🏿' => 'eeben hunen: jonk hidj',
    '🤲🏻' => 'palmer bienööder: laacht hidjet',
    '🤲🏼' => 'palmer bienööder: madel laacht hidj',
    '🤲🏽' => 'palmer bienööder: madel hidj',
    '🤲🏾' => 'palmer bienööder: madel jonk hidj',
    '🤲🏿' => 'palmer bienööder: jonk hidj',
    '🤝🏻' => 'hunen sködle: laacht hidjet',
    '🤝🏼' => 'hunen sködle: madel laacht hidj',
    '🤝🏽' => 'hunen sködle: madel hidj',
    '🤝🏾' => 'hunen sködle: madel jonk hidj',
    '🤝🏿' => 'hunen sködle: jonk hidj',
    '🙏🏻' => 'fualet hunen: laacht hidjet',
    '🙏🏼' => 'fualet hunen: madel laacht hidj',
    '🙏🏽' => 'fualet hunen: madel hidj',
    '🙏🏾' => 'fualet hunen: madel jonk hidj',
    '🙏🏿' => 'fualet hunen: jonk hidj',
    '✍🏻' => 'skriiw hun: laacht hidjet',
    '✍🏼' => 'skriiw hun: madel laacht hidj',
    '✍🏽' => 'skriiw hun: madel hidj',
    '✍🏾' => 'skriiw hun: madel jonk hidj',
    '✍🏿' => 'skriiw hun: jonk hidj',
    '💅🏻' => 'nailer lake: laacht hidjet',
    '💅🏼' => 'nailer lake: madel laacht hidj',
    '💅🏽' => 'nailer lake: madel hidj',
    '💅🏾' => 'nailer lake: madel jonk hidj',
    '💅🏿' => 'nailer lake: jonk hidj',
    '🤳🏻' => 'selfi: laacht hidjet',
    '🤳🏼' => 'selfi: madel laacht hidj',
    '🤳🏽' => 'selfi: madel hidj',
    '🤳🏾' => 'selfi: madel jonk hidj',
    '🤳🏿' => 'selfi: jonk hidj',
    '💪🏻' => 'boower iarem: laacht hidjet',
    '💪🏼' => 'boower iarem: madel laacht hidj',
    '💪🏽' => 'boower iarem: madel hidj',
    '💪🏾' => 'boower iarem: madel jonk hidj',
    '💪🏿' => 'boower iarem: jonk hidj',
    '🦵🏻' => 'bian: laacht hidjet',
    '🦵🏼' => 'bian: madel laacht hidj',
    '🦵🏽' => 'bian: madel hidj',
    '🦵🏾' => 'bian: madel jonk hidj',
    '🦵🏿' => 'bian: jonk hidj',
    '🦶🏻' => 'fut: laacht hidjet',
    '🦶🏼' => 'fut: madel laacht hidj',
    '🦶🏽' => 'fut: madel hidj',
    '🦶🏾' => 'fut: madel jonk hidj',
    '🦶🏿' => 'fut: jonk hidj',
    '👂🏻' => 'uar: laacht hidjet',
    '👂🏼' => 'uar: madel laacht hidj',
    '👂🏽' => 'uar: madel hidj',
    '👂🏾' => 'uar: madel jonk hidj',
    '👂🏿' => 'uar: jonk hidj',
    '🦻🏻' => 'uar mä hiaraperoot: laacht hidjet',
    '🦻🏼' => 'uar mä hiaraperoot: madel laacht hidj',
    '🦻🏽' => 'uar mä hiaraperoot: madel hidj',
    '🦻🏾' => 'uar mä hiaraperoot: madel jonk hidj',
    '🦻🏿' => 'uar mä hiaraperoot: jonk hidj',
    '👃🏻' => 'nöös: laacht hidjet',
    '👃🏼' => 'nöös: madel laacht hidj',
    '👃🏽' => 'nöös: madel hidj',
    '👃🏾' => 'nöös: madel jonk hidj',
    '👃🏿' => 'nöös: jonk hidj',
    '👶🏻' => 'baby: laacht hidjet',
    '👶🏼' => 'baby: madel laacht hidj',
    '👶🏽' => 'baby: madel hidj',
    '👶🏾' => 'baby: madel jonk hidj',
    '👶🏿' => 'baby: jonk hidj',
    '🧒🏻' => 'kint: laacht hidjet',
    '🧒🏼' => 'kint: madel laacht hidj',
    '🧒🏽' => 'kint: madel hidj',
    '🧒🏾' => 'kint: madel jonk hidj',
    '🧒🏿' => 'kint: jonk hidj',
    '👦🏻' => 'dring: laacht hidjet',
    '👦🏼' => 'dring: madel laacht hidj',
    '👦🏽' => 'dring: madel hidj',
    '👦🏾' => 'dring: madel jonk hidj',
    '👦🏿' => 'dring: jonk hidj',
    '👧🏻' => 'foomen: laacht hidjet',
    '👧🏼' => 'foomen: madel laacht hidj',
    '👧🏽' => 'foomen: madel hidj',
    '👧🏾' => 'foomen: madel jonk hidj',
    '👧🏿' => 'foomen: jonk hidj',
    '🧑🏻' => 'persuun: laacht hidjet',
    '🧑🏼' => 'persuun: madel laacht hidj',
    '🧑🏽' => 'persuun: madel hidj',
    '🧑🏾' => 'persuun: madel jonk hidj',
    '🧑🏿' => 'persuun: jonk hidj',
    '👱🏻' => 'blond persuun: laacht hidjet',
    '👱🏼' => 'blond persuun: madel laacht hidj',
    '👱🏽' => 'blond persuun: madel hidj',
    '👱🏾' => 'blond persuun: madel jonk hidj',
    '👱🏿' => 'blond persuun: jonk hidj',
    '👨🏻' => 'maan: laacht hidjet',
    '👨🏼' => 'maan: madel laacht hidj',
    '👨🏽' => 'maan: madel hidj',
    '👨🏾' => 'maan: madel jonk hidj',
    '👨🏿' => 'maan: jonk hidj',
    '🧔🏻' => 'minks mä biard: laacht hidjet',
    '🧔🏼' => 'minks mä biard: madel laacht hidj',
    '🧔🏽' => 'minks mä biard: madel hidj',
    '🧔🏾' => 'minks mä biard: madel jonk hidj',
    '🧔🏿' => 'minks mä biard: jonk hidj',
    '👩🏻' => 'wüf: laacht hidjet',
    '👩🏼' => 'wüf: madel laacht hidj',
    '👩🏽' => 'wüf: madel hidj',
    '👩🏾' => 'wüf: madel jonk hidj',
    '👩🏿' => 'wüf: jonk hidj',
    '🧓🏻' => 'ääler persuun: laacht hidjet',
    '🧓🏼' => 'ääler persuun: madel laacht hidj',
    '🧓🏽' => 'ääler persuun: madel hidj',
    '🧓🏾' => 'ääler persuun: madel jonk hidj',
    '🧓🏿' => 'ääler persuun: jonk hidj',
    '👴🏻' => 'ual maan: laacht hidjet',
    '👴🏼' => 'ual maan: madel laacht hidj',
    '👴🏽' => 'ual maan: madel hidj',
    '👴🏾' => 'ual maan: madel jonk hidj',
    '👴🏿' => 'ual maan: jonk hidj',
    '👵🏻' => 'ual wüf: laacht hidjet',
    '👵🏼' => 'ual wüf: madel laacht hidj',
    '👵🏽' => 'ual wüf: madel hidj',
    '👵🏾' => 'ual wüf: madel jonk hidj',
    '👵🏿' => 'ual wüf: jonk hidj',
    '🙍🏻' => 'braanj fuale: laacht hidjet',
    '🙍🏼' => 'braanj fuale: madel laacht hidj',
    '🙍🏽' => 'braanj fuale: madel hidj',
    '🙍🏾' => 'braanj fuale: madel jonk hidj',
    '🙍🏿' => 'braanj fuale: jonk hidj',
    '🙎🏻' => 'persuun flap: laacht hidjet',
    '🙎🏼' => 'persuun flap: madel laacht hidj',
    '🙎🏽' => 'persuun flap: madel hidj',
    '🙎🏾' => 'persuun flap: madel jonk hidj',
    '🙎🏿' => 'persuun flap: jonk hidj',
    '🙅🏻' => 'persuun naan: laacht hidjet',
    '🙅🏼' => 'persuun naan: madel laacht hidj',
    '🙅🏽' => 'persuun naan: madel hidj',
    '🙅🏾' => 'persuun naan: madel jonk hidj',
    '🙅🏿' => 'persuun naan: jonk hidj',
    '🙆🏻' => 'persuun bliis: laacht hidjet',
    '🙆🏼' => 'persuun bliis: madel laacht hidj',
    '🙆🏽' => 'persuun bliis: madel hidj',
    '🙆🏾' => 'persuun bliis: madel jonk hidj',
    '🙆🏿' => 'persuun bliis: jonk hidj',
    '💁🏻' => 'persuun wiset hun: laacht hidjet',
    '💁🏼' => 'persuun wiset hun: madel laacht hidj',
    '💁🏽' => 'persuun wiset hun: madel hidj',
    '💁🏾' => 'persuun wiset hun: madel jonk hidj',
    '💁🏿' => 'persuun wiset hun: jonk hidj',
    '🙋🏻' => 'persuun gröötet: laacht hidjet',
    '🙋🏼' => 'persuun gröötet: madel laacht hidj',
    '🙋🏽' => 'persuun gröötet: madel hidj',
    '🙋🏾' => 'persuun gröötet: madel jonk hidj',
    '🙋🏿' => 'persuun gröötet: jonk hidj',
    '🧏🏻' => 'duuf persuun: laacht hidjet',
    '🧏🏼' => 'duuf persuun: madel laacht hidj',
    '🧏🏽' => 'duuf persuun: madel hidj',
    '🧏🏾' => 'duuf persuun: madel jonk hidj',
    '🧏🏿' => 'duuf persuun: jonk hidj',
    '🙇🏻' => 'persuun bocht föör: laacht hidjet',
    '🙇🏼' => 'persuun bocht föör: madel laacht hidj',
    '🙇🏽' => 'persuun bocht föör: madel hidj',
    '🙇🏾' => 'persuun bocht föör: madel jonk hidj',
    '🙇🏿' => 'persuun bocht föör: jonk hidj',
    '🤦🏻' => 'persun palem gesicht: laacht hidjet',
    '🤦🏼' => 'persun palem gesicht: madel laacht hidj',
    '🤦🏽' => 'persun palem gesicht: madel hidj',
    '🤦🏾' => 'persun palem gesicht: madel jonk hidj',
    '🤦🏿' => 'persun palem gesicht: jonk hidj',
    '🤷🏻' => 'persuun skolern tak: laacht hidjet',
    '🤷🏼' => 'persuun skolern tak: madel laacht hidj',
    '🤷🏽' => 'persuun skolern tak: madel hidj',
    '🤷🏾' => 'persuun skolern tak: madel jonk hidj',
    '🤷🏿' => 'persuun skolern tak: jonk hidj',
    '👮🏻' => 'sjandaarem: laacht hidjet',
    '👮🏼' => 'sjandaarem: madel laacht hidj',
    '👮🏽' => 'sjandaarem: madel hidj',
    '👮🏾' => 'sjandaarem: madel jonk hidj',
    '👮🏿' => 'sjandaarem: jonk hidj',
    '🕵🏻' => 'detektiif: laacht hidjet',
    '🕵🏼' => 'detektiif: madel laacht hidj',
    '🕵🏽' => 'detektiif: madel hidj',
    '🕵🏾' => 'detektiif: madel jonk hidj',
    '🕵🏿' => 'detektiif: jonk hidj',
    '💂🏻' => 'wacht persuun: laacht hidjet',
    '💂🏼' => 'wacht persuun: madel laacht hidj',
    '💂🏽' => 'wacht persuun: madel hidj',
    '💂🏾' => 'wacht persuun: madel jonk hidj',
    '💂🏿' => 'wacht persuun: jonk hidj',
    '🥷🏻' => 'ninja: laacht hidjet',
    '🥷🏼' => 'ninja: madel laacht hidj',
    '🥷🏽' => 'ninja: madel hidj',
    '🥷🏾' => 'ninja: madel jonk hidj',
    '🥷🏿' => 'ninja: jonk hidj',
    '👷🏻' => 'bau hoonwerker: laacht hidjet',
    '👷🏼' => 'bau hoonwerker: madel laacht hidj',
    '👷🏽' => 'bau hoonwerker: madel hidj',
    '👷🏾' => 'bau hoonwerker: madel jonk hidj',
    '👷🏿' => 'bau hoonwerker: jonk hidj',
    '🫅🏻' => 'persuun mä krüün: laacht hidjet',
    '🫅🏼' => 'persuun mä krüün: madel laacht hidj',
    '🫅🏽' => 'persuun mä krüün: madel hidj',
    '🫅🏾' => 'persuun mä krüün: madel jonk hidj',
    '🫅🏿' => 'persuun mä krüün: jonk hidj',
    '🤴🏻' => 'prens: laacht hidjet',
    '🤴🏼' => 'prens: madel laacht hidj',
    '🤴🏽' => 'prens: madel hidj',
    '🤴🏾' => 'prens: madel jonk hidj',
    '🤴🏿' => 'prens: jonk hidj',
    '👸🏻' => 'prenses: laacht hidjet',
    '👸🏼' => 'prenses: madel laacht hidj',
    '👸🏽' => 'prenses: madel hidj',
    '👸🏾' => 'prenses: madel jonk hidj',
    '👸🏿' => 'prenses: jonk hidj',
    '👳🏻' => 'persuun mä turbaan: laacht hidjet',
    '👳🏼' => 'persuun mä turbaan: madel laacht hidj',
    '👳🏽' => 'persuun mä turbaan: madel hidj',
    '👳🏾' => 'persuun mä turbaan: madel jonk hidj',
    '👳🏿' => 'persuun mä turbaan: jonk hidj',
    '👲🏻' => 'maan mä trinj hud: laacht hidjet',
    '👲🏼' => 'maan mä trinj hud: madel laacht hidj',
    '👲🏽' => 'maan mä trinj hud: madel hidj',
    '👲🏾' => 'maan mä trinj hud: madel jonk hidj',
    '👲🏿' => 'maan mä trinj hud: jonk hidj',
    '🧕🏻' => 'wüf mä halnöösduk: laacht hidjet',
    '🧕🏼' => 'wüf mä halnöösduk: madel laacht hidj',
    '🧕🏽' => 'wüf mä halnöösduk: madel hidj',
    '🧕🏾' => 'wüf mä halnöösduk: madel jonk hidj',
    '🧕🏿' => 'wüf mä halnöösduk: jonk hidj',
    '🤵🏻' => 'persuun uun uuntooch: laacht hidjet',
    '🤵🏼' => 'persuun uun uuntooch: madel laacht hidj',
    '🤵🏽' => 'persuun uun uuntooch: madel hidj',
    '🤵🏾' => 'persuun uun uuntooch: madel jonk hidj',
    '🤵🏿' => 'persuun uun uuntooch: jonk hidj',
    '👰🏻' => 'persuun mä sleier: laacht hidjet',
    '👰🏼' => 'persuun mä sleier: madel laacht hidj',
    '👰🏽' => 'persuun mä sleier: madel hidj',
    '👰🏾' => 'persuun mä sleier: madel jonk hidj',
    '👰🏿' => 'persuun mä sleier: jonk hidj',
    '🤰🏻' => 'wüf mä letj: laacht hidjet',
    '🤰🏼' => 'wüf mä letj: madel laacht hidj',
    '🤰🏽' => 'wüf mä letj: madel hidj',
    '🤰🏾' => 'wüf mä letj: madel jonk hidj',
    '🤰🏿' => 'wüf mä letj: jonk hidj',
    '🫃🏻' => 'maan mä letj: laacht hidjet',
    '🫃🏼' => 'maan mä letj: madel laacht hidj',
    '🫃🏽' => 'maan mä letj: madel hidj',
    '🫃🏾' => 'maan mä letj: madel jonk hidj',
    '🫃🏿' => 'maan mä letj: jonk hidj',
    '🫄🏻' => 'persuun mä letj: laacht hidjet',
    '🫄🏼' => 'persuun mä letj: madel laacht hidj',
    '🫄🏽' => 'persuun mä letj: madel hidj',
    '🫄🏾' => 'persuun mä letj: madel jonk hidj',
    '🫄🏿' => 'persuun mä letj: jonk hidj',
    '🤱🏻' => 'wüf dää tetj: laacht hidjet',
    '🤱🏼' => 'wüf dää tetj: madel laacht hidj',
    '🤱🏽' => 'wüf dää tetj: madel hidj',
    '🤱🏾' => 'wüf dää tetj: madel jonk hidj',
    '🤱🏿' => 'wüf dää tetj: jonk hidj',
    '👼🏻' => 'kint engel: laacht hidjet',
    '👼🏼' => 'kint engel: madel laacht hidj',
    '👼🏽' => 'kint engel: madel hidj',
    '👼🏾' => 'kint engel: madel jonk hidj',
    '👼🏿' => 'kint engel: jonk hidj',
    '🎅🏻' => 'weinachsmaan: laacht hidjet',
    '🎅🏼' => 'weinachsmaan: madel laacht hidj',
    '🎅🏽' => 'weinachsmaan: madel hidj',
    '🎅🏾' => 'weinachsmaan: madel jonk hidj',
    '🎅🏿' => 'weinachsmaan: jonk hidj',
    '🤶🏻' => 'weinachswüf: laacht hidjet',
    '🤶🏼' => 'weinachswüf: madel laacht hidj',
    '🤶🏽' => 'weinachswüf: madel hidj',
    '🤶🏾' => 'weinachswüf: madel jonk hidj',
    '🤶🏿' => 'weinachswüf: jonk hidj',
    '🦸🏻' => 'superhelt: laacht hidjet',
    '🦸🏼' => 'superhelt: madel laacht hidj',
    '🦸🏽' => 'superhelt: madel hidj',
    '🦸🏾' => 'superhelt: madel jonk hidj',
    '🦸🏿' => 'superhelt: jonk hidj',
    '🦹🏻' => 'superskork: laacht hidjet',
    '🦹🏼' => 'superskork: madel laacht hidj',
    '🦹🏽' => 'superskork: madel hidj',
    '🦹🏾' => 'superskork: madel jonk hidj',
    '🦹🏿' => 'superskork: jonk hidj',
    '🧙🏻' => 'trool: laacht hidjet',
    '🧙🏼' => 'trool: madel laacht hidj',
    '🧙🏽' => 'trool: madel hidj',
    '🧙🏾' => 'trool: madel jonk hidj',
    '🧙🏿' => 'trool: jonk hidj',
    '🧚🏻' => 'fee: laacht hidjet',
    '🧚🏼' => 'fee: madel laacht hidj',
    '🧚🏽' => 'fee: madel hidj',
    '🧚🏾' => 'fee: madel jonk hidj',
    '🧚🏿' => 'fee: jonk hidj',
    '🧛🏻' => 'wampiir: laacht hidjet',
    '🧛🏼' => 'wampiir: madel laacht hidj',
    '🧛🏽' => 'wampiir: madel hidj',
    '🧛🏾' => 'wampiir: madel jonk hidj',
    '🧛🏿' => 'wampiir: jonk hidj',
    '🧜🏻' => 'weederpersuun: laacht hidjet',
    '🧜🏼' => 'weederpersuun: madel laacht hidj',
    '🧜🏽' => 'weederpersuun: madel hidj',
    '🧜🏾' => 'weederpersuun: madel jonk hidj',
    '🧜🏿' => 'weederpersuun: jonk hidj',
    '🧝🏻' => 'elf: laacht hidjet',
    '🧝🏼' => 'elf: madel laacht hidj',
    '🧝🏽' => 'elf: madel hidj',
    '🧝🏾' => 'elf: madel jonk hidj',
    '🧝🏿' => 'elf: jonk hidj',
    '💆🏻' => 'persuun masaaj: laacht hidjet',
    '💆🏼' => 'persuun masaaj: madel laacht hidj',
    '💆🏽' => 'persuun masaaj: madel hidj',
    '💆🏾' => 'persuun masaaj: madel jonk hidj',
    '💆🏿' => 'persuun masaaj: jonk hidj',
    '💇🏻' => 'persuun bi amklaper: laacht hidjet',
    '💇🏼' => 'persuun bi amklaper: madel laacht hidj',
    '💇🏽' => 'persuun bi amklaper: madel hidj',
    '💇🏾' => 'persuun bi amklaper: madel jonk hidj',
    '💇🏿' => 'persuun bi amklaper: jonk hidj',
    '🚶🏻' => 'persuun lääpt: laacht hidjet',
    '🚶🏼' => 'persuun lääpt: madel laacht hidj',
    '🚶🏽' => 'persuun lääpt: madel hidj',
    '🚶🏾' => 'persuun lääpt: madel jonk hidj',
    '🚶🏿' => 'persuun lääpt: jonk hidj',
    '🧍🏻' => 'persuun stäänt: laacht hidjet',
    '🧍🏼' => 'persuun stäänt: madel laacht hidj',
    '🧍🏽' => 'persuun stäänt: madel hidj',
    '🧍🏾' => 'persuun stäänt: madel jonk hidj',
    '🧍🏿' => 'persuun stäänt: jonk hidj',
    '🧎🏻' => 'persuun üüb knöbian: laacht hidjet',
    '🧎🏼' => 'persuun üüb knöbian: madel laacht hidj',
    '🧎🏽' => 'persuun üüb knöbian: madel hidj',
    '🧎🏾' => 'persuun üüb knöbian: madel jonk hidj',
    '🧎🏿' => 'persuun üüb knöbian: jonk hidj',
    '🏃🏻' => 'persuun räänt: laacht hidjet',
    '🏃🏼' => 'persuun räänt: madel laacht hidj',
    '🏃🏽' => 'persuun räänt: madel hidj',
    '🏃🏾' => 'persuun räänt: madel jonk hidj',
    '🏃🏿' => 'persuun räänt: jonk hidj',
    '💃🏻' => 'wüf daanset: laacht hidjet',
    '💃🏼' => 'wüf daanset: madel laacht hidj',
    '💃🏽' => 'wüf daanset: madel hidj',
    '💃🏾' => 'wüf daanset: madel jonk hidj',
    '💃🏿' => 'wüf daanset: jonk hidj',
    '🕺🏻' => 'maan daanset: laacht hidjet',
    '🕺🏼' => 'maan daanset: madel laacht hidj',
    '🕺🏽' => 'maan daanset: madel hidj',
    '🕺🏾' => 'maan daanset: madel jonk hidj',
    '🕺🏿' => 'maan daanset: jonk hidj',
    '🕴🏻' => 'persuun mä uuntooch sweewet: laacht hidjet',
    '🕴🏼' => 'persuun mä uuntooch sweewet: madel laacht hidj',
    '🕴🏽' => 'persuun mä uuntooch sweewet: madel hidj',
    '🕴🏾' => 'persuun mä uuntooch sweewet: madel jonk hidj',
    '🕴🏿' => 'persuun mä uuntooch sweewet: jonk hidj',
    '👯🏻' => 'lidj mä haasuaren: laacht hidjet',
    '👯🏼' => 'lidj mä haasuaren: madel laacht hidj',
    '👯🏽' => 'lidj mä haasuaren: madel hidj',
    '👯🏾' => 'lidj mä haasuaren: madel jonk hidj',
    '👯🏿' => 'lidj mä haasuaren: jonk hidj',
    '🧖🏻' => 'persuun uun sauna: laacht hidjet',
    '🧖🏼' => 'persuun uun sauna: madel laacht hidj',
    '🧖🏽' => 'persuun uun sauna: madel hidj',
    '🧖🏾' => 'persuun uun sauna: madel jonk hidj',
    '🧖🏿' => 'persuun uun sauna: jonk hidj',
    '🧗🏻' => 'persuun klemert: laacht hidjet',
    '🧗🏼' => 'persuun klemert: madel laacht hidj',
    '🧗🏽' => 'persuun klemert: madel hidj',
    '🧗🏾' => 'persuun klemert: madel jonk hidj',
    '🧗🏿' => 'persuun klemert: jonk hidj',
    '🏇🏻' => 'wääd ridjen: laacht hidjet',
    '🏇🏼' => 'wääd ridjen: madel laacht hidj',
    '🏇🏽' => 'wääd ridjen: madel hidj',
    '🏇🏾' => 'wääd ridjen: madel jonk hidj',
    '🏇🏿' => 'wääd ridjen: jonk hidj',
    '🏂🏻' => 'persuun üüb snäburd: laacht hidjet',
    '🏂🏼' => 'persuun üüb snäburd: madel laacht hidj',
    '🏂🏽' => 'persuun üüb snäburd: madel hidj',
    '🏂🏾' => 'persuun üüb snäburd: madel jonk hidj',
    '🏂🏿' => 'persuun üüb snäburd: jonk hidj',
    '🏌🏻' => 'golfspeler: laacht hidjet',
    '🏌🏼' => 'golfspeler: madel laacht hidj',
    '🏌🏽' => 'golfspeler: madel hidj',
    '🏌🏾' => 'golfspeler: madel jonk hidj',
    '🏌🏿' => 'golfspeler: jonk hidj',
    '🏄🏻' => 'surfer: laacht hidjet',
    '🏄🏼' => 'surfer: madel laacht hidj',
    '🏄🏽' => 'surfer: madel hidj',
    '🏄🏾' => 'surfer: madel jonk hidj',
    '🏄🏿' => 'surfer: jonk hidj',
    '🚣🏻' => 'persuun ruit buat: laacht hidjet',
    '🚣🏼' => 'persuun ruit buat: madel laacht hidj',
    '🚣🏽' => 'persuun ruit buat: madel hidj',
    '🚣🏾' => 'persuun ruit buat: madel jonk hidj',
    '🚣🏿' => 'persuun ruit buat: jonk hidj',
    '🏊🏻' => 'swäämer: laacht hidjet',
    '🏊🏼' => 'swäämer: madel laacht hidj',
    '🏊🏽' => 'swäämer: madel hidj',
    '🏊🏾' => 'swäämer: madel jonk hidj',
    '🏊🏿' => 'swäämer: jonk hidj',
    '⛹🏻' => 'baalspeler: laacht hidjet',
    '⛹🏼' => 'baalspeler: madel laacht hidj',
    '⛹🏽' => 'baalspeler: madel hidj',
    '⛹🏾' => 'baalspeler: madel jonk hidj',
    '⛹🏿' => 'baalspeler: jonk hidj',
    '🏋🏻' => 'persuun laft gewicht: laacht hidjet',
    '🏋🏼' => 'persuun laft gewicht: madel laacht hidj',
    '🏋🏽' => 'persuun laft gewicht: madel hidj',
    '🏋🏾' => 'persuun laft gewicht: madel jonk hidj',
    '🏋🏿' => 'persuun laft gewicht: jonk hidj',
    '🚴🏻' => 'welkeerer: laacht hidjet',
    '🚴🏼' => 'welkeerer: madel laacht hidj',
    '🚴🏽' => 'welkeerer: madel hidj',
    '🚴🏾' => 'welkeerer: madel jonk hidj',
    '🚴🏿' => 'welkeerer: jonk hidj',
    '🚵🏻' => 'persuun üüb gelendewel: laacht hidjet',
    '🚵🏼' => 'persuun üüb gelendewel: madel laacht hidj',
    '🚵🏽' => 'persuun üüb gelendewel: madel hidj',
    '🚵🏾' => 'persuun üüb gelendewel: madel jonk hidj',
    '🚵🏿' => 'persuun üüb gelendewel: jonk hidj',
    '🤸🏻' => 'persuun slait en wel: laacht hidjet',
    '🤸🏼' => 'persuun slait en wel: madel laacht hidj',
    '🤸🏽' => 'persuun slait en wel: madel hidj',
    '🤸🏾' => 'persuun slait en wel: madel jonk hidj',
    '🤸🏿' => 'persuun slait en wel: jonk hidj',
    '🤼🏻' => 'persuunen kemfe: laacht hidjet',
    '🤼🏼' => 'persuunen kemfe: madel laacht hidj',
    '🤼🏽' => 'persuunen kemfe: madel hidj',
    '🤼🏾' => 'persuunen kemfe: madel jonk hidj',
    '🤼🏿' => 'persuunen kemfe: jonk hidj',
    '🤽🏻' => 'weederbaalspeler: laacht hidjet',
    '🤽🏼' => 'weederbaalspeler: madel laacht hidj',
    '🤽🏽' => 'weederbaalspeler: madel hidj',
    '🤽🏾' => 'weederbaalspeler: madel jonk hidj',
    '🤽🏿' => 'weederbaalspeler: jonk hidj',
    '🤾🏻' => 'hunbaalspeler: laacht hidjet',
    '🤾🏼' => 'hunbaalspeler: madel laacht hidj',
    '🤾🏽' => 'hunbaalspeler: madel hidj',
    '🤾🏾' => 'hunbaalspeler: madel jonk hidj',
    '🤾🏿' => 'hunbaalspeler: jonk hidj',
    '🤹🏻' => 'persuun jongliaret: laacht hidjet',
    '🤹🏼' => 'persuun jongliaret: madel laacht hidj',
    '🤹🏽' => 'persuun jongliaret: madel hidj',
    '🤹🏾' => 'persuun jongliaret: madel jonk hidj',
    '🤹🏿' => 'persuun jongliaret: jonk hidj',
    '🧘🏻' => 'persuun mä lotus bian: laacht hidjet',
    '🧘🏼' => 'persuun mä lotus bian: madel laacht hidj',
    '🧘🏽' => 'persuun mä lotus bian: madel hidj',
    '🧘🏾' => 'persuun mä lotus bian: madel jonk hidj',
    '🧘🏿' => 'persuun mä lotus bian: jonk hidj',
    '🛀🏻' => 'persuun baaset: laacht hidjet',
    '🛀🏼' => 'persuun baaset: madel laacht hidj',
    '🛀🏽' => 'persuun baaset: madel hidj',
    '🛀🏾' => 'persuun baaset: madel jonk hidj',
    '🛀🏿' => 'persuun baaset: jonk hidj',
    '🛌🏻' => 'persuun slääpt: laacht hidjet',
    '🛌🏼' => 'persuun slääpt: madel laacht hidj',
    '🛌🏽' => 'persuun slääpt: madel hidj',
    '🛌🏾' => 'persuun slääpt: madel jonk hidj',
    '🛌🏿' => 'persuun slääpt: jonk hidj',
    '👭🏻' => 'wüfen hual hunen: laacht hidjet',
    '👭🏼' => 'wüfen hual hunen: madel laacht hidj',
    '👭🏽' => 'wüfen hual hunen: madel hidj',
    '👭🏾' => 'wüfen hual hunen: madel jonk hidj',
    '👭🏿' => 'wüfen hual hunen: jonk hidj',
    '👫🏻' => 'maan an wüf hual hunen: laacht hidjet',
    '👫🏼' => 'maan an wüf hual hunen: madel laacht hidj',
    '👫🏽' => 'maan an wüf hual hunen: madel hidj',
    '👫🏾' => 'maan an wüf hual hunen: madel jonk hidj',
    '👫🏿' => 'maan an wüf hual hunen: jonk hidj',
    '👬🏻' => 'maaner hual hunen: laacht hidjet',
    '👬🏼' => 'maaner hual hunen: madel laacht hidj',
    '👬🏽' => 'maaner hual hunen: madel hidj',
    '👬🏾' => 'maaner hual hunen: madel jonk hidj',
    '👬🏿' => 'maaner hual hunen: jonk hidj',
    '💏🏻' => 'süüse: laacht hidjet',
    '💏🏼' => 'süüse: madel laacht hidj',
    '💏🏽' => 'süüse: madel hidj',
    '💏🏾' => 'süüse: madel jonk hidj',
    '💏🏿' => 'süüse: jonk hidj',
    '💑🏻' => 'paar mä hart: laacht hidjet',
    '💑🏼' => 'paar mä hart: madel laacht hidj',
    '💑🏽' => 'paar mä hart: madel hidj',
    '💑🏾' => 'paar mä hart: madel jonk hidj',
    '💑🏿' => 'paar mä hart: jonk hidj',
    '🏻' => 'laacht hidjet',
    '🏼' => 'madel laacht hidj',
    '🏽' => 'madel hidj',
    '🏾' => 'madel jonk hidj',
    '🏿' => 'jonk hidj',
    '😀' => 'griine',
    '😃' => 'griine mä grat uugen',
    '😄' => 'griine mä smiilin uugen',
    '😁' => 'struale mä smiilin uugen',
    '😆' => 'griine an pliire',
    '😅' => 'griine an sweet',
    '🤣' => 'laache auer a miaten',
    '😂' => 'tuaren uun a uugen',
    '🙂' => 'bekneeben smiile',
    '🙃' => 'üüb’t hood',
    '🫠' => 'wechsmolt',
    '😉' => 'pliire',
    '😊' => 'smiile mä smiilin uugen',
    '😇' => 'hilag smiile',
    '🥰' => 'smiile mä harten',
    '😍' => 'smiile mä hart uugen',
    '🤩' => 'griine mä stäären',
    '😘' => 'süüse uundüüde',
    '😗' => 'hood süüset',
    '☺' => 'smiile ianfach',
    '😚' => 'süüse mä uugen tu',
    '😙' => 'süüse mä smiilin uugen',
    '🥲' => 'smiile mä tuar',
    '😋' => 'laker',
    '😛' => 'hood mä tong',
    '😜' => 'pliire an tong',
    '🤪' => 'ferdreid',
    '😝' => 'spei mä tong',
    '🤑' => 'dooler uugen',
    '🤗' => 'laache mä eeben hunen',
    '🤭' => 'hun üüb müs',
    '🫢' => 'ferwonert mä hun üüb müs',
    '🫣' => 'mä ian uug luke',
    '🤫' => 'fanger üüb müs',
    '🤔' => 'hun oner müs',
    '🫡' => 'hun üüb braanj',
    '🤐' => 'riiwsloot müs',
    '🤨' => 'huuchtaanj uugbriad',
    '😐' => 'ianerlei müs',
    '😑' => 'saner ütjdruk',
    '😶' => 'nään müs',
    '🫥' => 'ferswünjen',
    '😏' => 'fülk müs',
    '😒' => 'bedrüüwet',
    '🙄' => 'rolin uugen',
    '😬' => 'tes wise',
    '🤥' => 'lung nöös',
    '🫨' => 'dobelt hood',
    '😌' => 'bliis',
    '😔' => 'träät',
    '😪' => 'jibin',
    '🤤' => 'kwiilin',
    '😴' => 'sliapen',
    '🫩' => 'uug ringer',
    '😷' => 'müs nöösduk',
    '🤒' => 'hood mä termomeeter',
    '🤕' => 'hood amslach',
    '🤢' => 'speiag',
    '🤮' => 'spei',
    '🤧' => 'snüüw nöösduk',
    '🥵' => 'glamen hood',
    '🥶' => 'kuul hood',
    '🥴' => 'ünwel',
    '😵' => 'krüs uugen',
    '🤯' => 'hood flocht uun a loft',
    '🤠' => 'cowboy hud',
    '🥳' => 'party hud',
    '🥸' => 'trinj bral snorbiard',
    '😎' => 'smiile mä sanbral',
    '🤓' => 'kluukskitjer',
    '🧐' => 'monokel',
    '😕' => 'trochenööder',
    '🫤' => 'sküüns müs',
    '😟' => 'apreeget',
    '🙁' => 'benaud',
    '☹' => 'böös benaud',
    '😮' => 'eeben müs',
    '😯' => 'skrekd',
    '😲' => 'böös skrekd',
    '😳' => 'ferwonert',
    '🥺' => 'skrial',
    '🥹' => 'skrial för lok',
    '😦' => 'ei liaw',
    '😧' => 'piinagt',
    '😨' => 'baang',
    '😰' => 'baang swäät',
    '😥' => 'bedrüüwet tuaren',
    '😢' => 'skrial tuaren',
    '😭' => 'fiks skrial',
    '😱' => 'böös baang',
    '😖' => 'ei ütjhual',
    '😣' => 'hoodwark',
    '😞' => 'üntufrees',
    '😓' => 'üntufrees swäät',
    '😩' => 'jaamre',
    '😫' => 'böös träät',
    '🥱' => 'jibe',
    '😤' => 'damp faan nöös',
    '😡' => 'roosendol',
    '😠' => 'dol',
    '🤬' => 'gesicht sümboolen',
    '😈' => 'griine mä hurner',
    '👿' => 'dol mä hurner',
    '💀' => 'hoodskrook',
    '☠' => 'hoodskrook mä knooken',
    '💩' => 'skeet',
    '🤡' => 'kloon',
    '👹' => 'deiwel',
    '👺' => 'klabolter',
    '👻' => 'geist hood',
    '👽' => 'alien',
    '👾' => 'alien monster',
    '🤖' => 'roboter',
    '😺' => 'griine kaat',
    '😸' => 'griine smiile kaat',
    '😹' => 'kaat tuaren',
    '😻' => 'kaat mä hart uugen',
    '😼' => 'kaat mä fülk müs',
    '😽' => 'süüse kaat',
    '🙀' => 'fuuch kaat',
    '😿' => 'kaat skrialt',
    '😾' => 'dol kaat',
    '🙈' => 'blinj aab',
    '🙉' => 'duuf aab',
    '🙊' => 'stom aab',
    '💌' => 'leefde briaf',
    '💘' => 'hart mä piil',
    '💝' => 'hart mä sleuf',
    '💖' => 'hart mä stäären',
    '💗' => 'hart wääkst',
    '💓' => 'hart klupet',
    '💞' => 'tau harten drei amenööder',
    '💕' => 'tau harten',
    '💟' => 'hart sümbool',
    '❣' => 'hart mä ponkt',
    '💔' => 'breegen hart',
    '❤' => 'ruad hart',
    '🩷' => 'ruusa hart',
    '🧡' => 'orangj hart',
    '💛' => 'güül hart',
    '💚' => 'green hart',
    '💙' => 'blä hart',
    '🩵' => 'laachtblä hart',
    '💜' => 'brons hart',
    '🤎' => 'brün hart',
    '🖤' => 'suart hart',
    '🩶' => 'grä hart',
    '🤍' => 'witj hart',
    '💋' => 'kleeb',
    '💯' => 'hunert ponkter',
    '💢' => 'fertret',
    '🫯' => 'stridj swark',
    '💥' => 'stup',
    '💫' => 'düüsag',
    '💦' => 'sweet drööber',
    '💨' => 'wech flä',
    '🕳' => 'hool',
    '💬' => 'spriak blees',
    '🗨' => 'lachts spriak blees',
    '🗯' => 'rochts blees',
    '💭' => 'toocht balong',
    '💤' => 'ZZZ',
    '👋' => 'hun wiafte',
    '🤚' => 'hun huuch bütjen',
    '🖐' => 'hun mä fangern',
    '✋' => 'hun huuch banen',
    '🖖' => 'hun wulkaan gröötnis',
    '🫱' => 'hun rochts',
    '🫲' => 'hun lachts',
    '🫳' => 'hun palem deel',
    '🫴' => 'hun palem ap',
    '🫷' => 'hun pui lachts',
    '🫸' => 'hun pui rochts',
    '👌' => 'hun OK',
    '🤌' => 'hun tuupkläämd fangern',
    '🤏' => 'hun tuupkläämd',
    '✌' => 'waner hun',
    '🤞' => 'fangern auerkrüs',
    '🫰' => 'jil fanger',
    '🤟' => 'leefde fangern',
    '🤘' => 'hurner fangern',
    '🤙' => 'tilefoon fangern',
    '👈' => 'hun bääft wiisfanger lachts',
    '👉' => 'hun bääft wiisfanger rochts',
    '👆' => 'hun bääft wiisfanger ap',
    '🖕' => 'hun bääft madelfanger ap',
    '👇' => 'hun bääft wiisfanger deeel',
    '☝' => 'hun föör wiisfanger ap',
    '🫵' => 'wiisfanger üüb mi tu',
    '👍' => 'süm ap',
    '👎' => 'süm deel',
    '✊' => 'fist',
    '👊' => 'fist üüb mi tu',
    '🤛' => 'fist lachts',
    '🤜' => 'fist rochts',
    '👏' => 'hunen klape',
    '🙌' => 'hunen huuch',
    '🫶' => 'hart hunen',
    '👐' => 'eeben hunen',
    '🤲' => 'palmer bienööder',
    '🤝' => 'hunen sködle',
    '🙏' => 'fualet hunen',
    '✍' => 'skriiw hun',
    '💅' => 'nailer lake',
    '🤳' => 'selfi',
    '💪' => 'boower iarem',
    '🦾' => 'maskiin iarem',
    '🦿' => 'maskiin bian',
    '🦵' => 'bian',
    '🦶' => 'fut',
    '👂' => 'uar',
    '🦻' => 'uar mä hiaraperoot',
    '👃' => 'nöös',
    '🧠' => 'hoodmörag',
    '🫀' => 'hart',
    '🫁' => 'longen',
    '🦷' => 'tus',
    '🦴' => 'knook',
    '👀' => 'uugen',
    '👁' => 'uug',
    '👅' => 'tong',
    '👄' => 'müs',
    '🫦' => 'lapen bitj',
    '👶' => 'baby',
    '🧒' => 'kint',
    '👦' => 'dring',
    '👧' => 'foomen',
    '🧑' => 'persuun',
    '👱' => 'blond persuun',
    '👨' => 'maan',
    '🧔' => 'minks mä biard',
    '👩' => 'wüf',
    '🧓' => 'ääler persuun',
    '👴' => 'ual maan',
    '👵' => 'ual wüf',
    '🙍' => 'braanj fuale',
    '🙎' => 'persuun flap',
    '🙅' => 'persuun naan',
    '🙆' => 'persuun bliis',
    '💁' => 'persuun wiset hun',
    '🙋' => 'persuun gröötet',
    '🧏' => 'duuf persuun',
    '🙇' => 'persuun bocht föör',
    '🤦' => 'persun palem gesicht',
    '🤷' => 'persuun skolern tak',
    '👮' => 'sjandaarem',
    '🕵' => 'detektiif',
    '💂' => 'wacht persuun',
    '🥷' => 'ninja',
    '👷' => 'bau hoonwerker',
    '🫅' => 'persuun mä krüün',
    '🤴' => 'prens',
    '👸' => 'prenses',
    '👳' => 'persuun mä turbaan',
    '👲' => 'maan mä trinj hud',
    '🧕' => 'wüf mä halnöösduk',
    '🤵' => 'persuun uun uuntooch',
    '👰' => 'persuun mä sleier',
    '🤰' => 'wüf mä letj',
    '🫃' => 'maan mä letj',
    '🫄' => 'persuun mä letj',
    '🤱' => 'wüf dää tetj',
    '👼' => 'kint engel',
    '🎅' => 'weinachsmaan',
    '🤶' => 'weinachswüf',
    '🦸' => 'superhelt',
    '🦹' => 'superskork',
    '🧙' => 'trool',
    '🧚' => 'fee',
    '🧛' => 'wampiir',
    '🧜' => 'weederpersuun',
    '🧝' => 'elf',
    '🧞' => 'geist',
    '🧟' => 'zombie',
    '🧌' => 'monster',
    '🫈' => 'hiaret kreatüür',
    '💆' => 'persuun masaaj',
    '💇' => 'persuun bi amklaper',
    '🚶' => 'persuun lääpt',
    '🧍' => 'persuun stäänt',
    '🧎' => 'persuun üüb knöbian',
    '🏃' => 'persuun räänt',
    '💃' => 'wüf daanset',
    '🕺' => 'maan daanset',
    '🕴' => 'persuun mä uuntooch sweewet',
    '👯' => 'lidj mä haasuaren',
    '🧖' => 'persuun uun sauna',
    '🧗' => 'persuun klemert',
    '🤺' => 'persuun fechtet',
    '🏇' => 'wääd ridjen',
    '⛷' => 'sjii luupen',
    '🏂' => 'persuun üüb snäburd',
    '🏌' => 'golfspeler',
    '🏄' => 'surfer',
    '🚣' => 'persuun ruit buat',
    '🏊' => 'swäämer',
    '⛹' => 'baalspeler',
    '🏋' => 'persuun laft gewicht',
    '🚴' => 'welkeerer',
    '🚵' => 'persuun üüb gelendewel',
    '🤸' => 'persuun slait en wel',
    '🤼' => 'persuunen kemfe',
    '🤽' => 'weederbaalspeler',
    '🤾' => 'hunbaalspeler',
    '🤹' => 'persuun jongliaret',
    '🧘' => 'persuun mä lotus bian',
    '🛀' => 'persuun baaset',
    '🛌' => 'persuun slääpt',
    '👭' => 'wüfen hual hunen',
    '👫' => 'maan an wüf hual hunen',
    '👬' => 'maaner hual hunen',
    '💏' => 'süüse',
    '💑' => 'paar mä hart',
    '🗣' => 'hood snaaket',
    '👤' => 'hood',
    '👥' => 'tau hööd',
    '🫂' => 'tau uun iarem',
    '👪' => 'famile',
    '👣' => 'tau fut ufdrüker',
    '🫆' => 'fanger ufdruk',
    '🦰' => 'ruad hiar',
    '🦱' => 'krüüsag hiar',
    '🦳' => 'witj hiar',
    '🦲' => 'nian hiar',
    '🐵' => 'aab hood',
    '🐒' => 'aab',
    '🦍' => 'gorila',
    '🦧' => 'orang utan',
    '🐶' => 'hünj hood',
    '🐕' => 'hünj',
    '🦮' => 'blinjen hünj',
    '🐩' => 'puudel',
    '🐺' => 'wulew',
    '🦊' => 'foos',
    '🦝' => 'wask beer',
    '🐱' => 'kaat hood',
    '🐈' => 'kaat',
    '🦁' => 'lööw',
    '🐯' => 'tiiger hood',
    '🐅' => 'tiiger',
    '🐆' => 'leopard',
    '🐴' => 'hingst hood',
    '🫎' => 'elch',
    '🫏' => 'eesel',
    '🐎' => 'hingst',
    '🦄' => 'ianhurn',
    '🦓' => 'seebra',
    '🦌' => 'hirsk',
    '🦬' => 'biison',
    '🐮' => 'kü hood',
    '🐂' => 'oks',
    '🐃' => 'weeder büfel',
    '🐄' => 'kü',
    '🐷' => 'swin hood',
    '🐖' => 'swin',
    '🐗' => 'wilswin',
    '🐽' => 'swin nöös',
    '🐏' => 'room',
    '🐑' => 'sjep',
    '🐐' => 'siig',
    '🐪' => 'kameel',
    '🐫' => 'baktrisk kameel',
    '🦙' => 'laama',
    '🦒' => 'giraf',
    '🐘' => 'elefant',
    '🦣' => 'mamuut',
    '🦏' => 'nööshurn',
    '🦛' => 'hipo',
    '🐭' => 'müs hood',
    '🐁' => 'müs diart',
    '🐀' => 'root',
    '🐹' => 'hamster',
    '🐰' => 'haas hood',
    '🐇' => 'haas',
    '🐿' => 'buumkaat',
    '🦫' => 'biiber',
    '🦔' => 'iigel',
    '🦇' => 'fladermüs',
    '🐻' => 'beer',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'luidiart',
    '🦦' => 'oter',
    '🦨' => 'sjonkdiart',
    '🦘' => 'kengeruu',
    '🦡' => 'daks',
    '🐾' => 'puat spöör',
    '🦃' => 'puut',
    '🐔' => 'han',
    '🐓' => 'höön',
    '🐣' => 'henk ai',
    '🐤' => 'henk',
    '🐥' => 'henk föör',
    '🐦' => 'fögel',
    '🐧' => 'pinguin',
    '🕊' => 'düüw',
    '🦅' => 'iarn',
    '🦆' => 'an',
    '🦢' => 'swaan',
    '🦉' => 'kadüül',
    '🦤' => 'dodo',
    '🪶' => 'feeder',
    '🦩' => 'flamingo',
    '🦚' => 'paufögel',
    '🦜' => 'popegei',
    '🪽' => 'jüg',
    '🪿' => 'gus',
    '🐸' => 'hobelfask',
    '🐊' => 'krokodiil',
    '🐢' => 'skiltpod',
    '🦎' => 'haagedisj',
    '🐍' => 'slaang',
    '🐲' => 'draag hood',
    '🐉' => 'draag',
    '🦕' => 'dinosaurier',
    '🦖' => 'T-Rex',
    '🐳' => 'waal spütj',
    '🐋' => 'waal',
    '🐬' => 'delfiin',
    '🫍' => 'orca',
    '🦭' => 'selag',
    '🐟' => 'fask',
    '🐠' => 'troopisk fask',
    '🐡' => 'kuugelfask',
    '🦈' => 'hei',
    '🐙' => 'oktopus',
    '🐚' => 'snek höske',
    '🪸' => 'koral',
    '🪼' => 'glaag',
    '🦀' => 'weeder kraab',
    '🦞' => 'homer',
    '🦐' => 'por',
    '🦑' => 'blakfask',
    '🦪' => 'uastrang',
    '🐌' => 'snek',
    '🦋' => 'flenerk',
    '🐛' => 'rip',
    '🐜' => 'miir',
    '🐝' => 'im',
    '🪲' => 'kraab',
    '🐞' => 'godshenk',
    '🦗' => 'gäärshoper',
    '🪳' => 'kakelak',
    '🕷' => 'koonker',
    '🕸' => 'spenwääb',
    '🦂' => 'skorpion',
    '🦟' => 'mag',
    '🪰' => 'fleeg',
    '🪱' => 'wirem',
    '🦠' => 'uurdiart',
    '💐' => 'bluum straus',
    '🌸' => 'käärs bloos',
    '💮' => 'witj bloos',
    '🪷' => 'lotus',
    '🏵' => 'ruus bloos',
    '🌹' => 'ruus',
    '🥀' => 'wel bluum',
    '🌺' => 'hibiskus',
    '🌻' => 'sanbluum',
    '🌼' => 'bloos',
    '🌷' => 'tulp',
    '🪻' => 'hyasint',
    '🌱' => 'sprööd',
    '🪴' => 'potbluum',
    '🌲' => 'näädelbuum',
    '🌳' => 'bleedenbuum',
    '🌴' => 'pualem',
    '🌵' => 'kaktus',
    '🌾' => 'ris aaks',
    '🌿' => 'greenen',
    '☘' => 'kliawer',
    '🍀' => 'sjauer bleed kliawer',
    '🍁' => 'ahurn bleed',
    '🍂' => 'fäälen bleeden',
    '🍃' => 'bleed uun a winj',
    '🪹' => 'nääst leesag',
    '🪺' => 'nääst mä aier',
    '🍄' => 'hünjmots',
    '🪾' => 'buum saner bleeden',
    '🍇' => 'windrüüwen',
    '🍈' => 'meloon',
    '🍉' => 'weeder meloon',
    '🍊' => 'mandariin',
    '🍋' => 'sitroon',
    '🍌' => 'banaan',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'ruad aapel',
    '🍏' => 'green aapel',
    '🍐' => 'peer',
    '🍑' => 'firsich',
    '🍒' => 'käärsen',
    '🍓' => 'eerdbei',
    '🫐' => 'bläbei',
    '🥝' => 'kiiwi frücht',
    '🍅' => 'tomoot',
    '🫒' => 'oliiw',
    '🥥' => 'kokosnöd',
    '🥑' => 'awokaado',
    '🍆' => 'aubergine',
    '🥔' => 'irpel',
    '🥕' => 'wochel',
    '🌽' => 'meis',
    '🌶' => 'spoonsk pöber',
    '🫑' => 'paprika',
    '🥒' => 'gurk',
    '🥬' => 'green saloot',
    '🥦' => 'brokoli',
    '🧄' => 'knooplook',
    '🧅' => 'skalot',
    '🥜' => 'eerdnöden',
    '🫘' => 'buanen',
    '🌰' => 'haaselnöd',
    '🫚' => 'ingefeer',
    '🫛' => 'irt',
    '🫜' => 'ruad beet',
    '🍞' => 'bruad',
    '🥐' => 'croissant',
    '🥖' => 'baguette',
    '🫓' => 'flaak bruad',
    '🥨' => 'kringel',
    '🥯' => 'runstük',
    '🥞' => 'pankuuk',
    '🧇' => 'wafel',
    '🧀' => 'stak sees',
    '🍖' => 'flääsk mä knook',
    '🍗' => 'haks',
    '🥩' => 'stak flääsk',
    '🥓' => 'spääk',
    '🍔' => 'hamburger',
    '🍟' => 'pomfrits',
    '🍕' => 'pizza',
    '🌭' => 'hot dog',
    '🥪' => 'sandwich',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'döner',
    '🧆' => 'falafel',
    '🥚' => 'ai',
    '🍳' => 'braaset ai',
    '🥘' => 'paella',
    '🍲' => 'sop',
    '🫕' => 'fondue',
    '🥣' => 'dask mä skai',
    '🥗' => 'bak mä saloot',
    '🍿' => 'popkorn',
    '🧈' => 'böder',
    '🧂' => 'saalt',
    '🥫' => 'duusenfuder',
    '🍱' => 'klob',
    '🍘' => 'ris keek',
    '🍙' => 'ris baal',
    '🍚' => 'bak mä ris',
    '🍛' => 'ris curry',
    '🍜' => 'iidjbak',
    '🍝' => 'spaghetti',
    '🍠' => 'swet irpel',
    '🍢' => 'preg',
    '🍣' => 'sushi',
    '🍤' => 'beegen garneel',
    '🍥' => 'fask kuuk mä kringel',
    '🥮' => 'muun kuuk',
    '🍡' => 'preg mä sweten',
    '🥟' => 'empanada',
    '🥠' => 'lok keek',
    '🥡' => 'iidj tu mänemen',
    '🍦' => 'soft is',
    '🍧' => 'heewelt is',
    '🍨' => 'bak mä is',
    '🍩' => 'donut',
    '🍪' => 'keek',
    '🎂' => 'gebursdai tort',
    '🍰' => 'stak torts',
    '🧁' => 'cupcake',
    '🥧' => 'pei',
    '🍫' => 'stak sakelaad',
    '🍬' => 'kinje',
    '🍭' => 'loli',
    '🍮' => 'podang',
    '🍯' => 'hönang pot',
    '🍼' => 'moolk butel',
    '🥛' => 'moolk glääs',
    '☕' => 'kop kofe',
    '🫖' => 'trepot',
    '🍵' => 'tee kop',
    '🍶' => 'saake',
    '🍾' => 'sekt butel',
    '🍷' => 'win glääs',
    '🍸' => 'cocktail glääs',
    '🍹' => 'cocktail',
    '🍺' => 'biir glääs',
    '🍻' => 'tau biir glees',
    '🥂' => 'sekt glees',
    '🥃' => 'whisky glääs',
    '🫗' => 'leetst drööb',
    '🥤' => 'glääs mä strähalem',
    '🧋' => 'sküm tee',
    '🧃' => 'saft rochtkaant',
    '🧉' => 'mate',
    '🧊' => 'is knölk',
    '🥢' => 'sjineesk pregen',
    '🍽' => 'furk knif dask',
    '🍴' => 'furk an knif',
    '🥄' => 'skai',
    '🔪' => 'köögem knif',
    '🫙' => 'glääs pot',
    '🏺' => 'amfoore',
    '🌍' => 'gloobus Euroopa Afrikoo',
    '🌎' => 'gloobus Ameerikoo',
    '🌏' => 'gloobus Aasien Austraalien',
    '🌐' => 'gloobus meridiaanen',
    '🗺' => 'koord welt',
    '🗾' => 'koord Jaapan',
    '🧭' => 'kompaas',
    '🏔' => 'berag mä snä',
    '⛰' => 'berag',
    '🛘' => 'stianslach',
    '🌋' => 'wulkaan',
    '🗻' => 'berag Fuji',
    '🏕' => 'camping telt',
    '🏖' => 'strun mä skirem',
    '🏜' => 'wüüst mä kaktus',
    '🏝' => 'wüüst eilun mä pualem',
    '🏞' => 'natsionaalpark',
    '🏟' => 'stadion',
    '🏛' => 'gebüüde mä piilern',
    '🏗' => 'huuchbau',
    '🧱' => 'tegelstianer',
    '🪨' => 'fels',
    '🪵' => 'holt',
    '🛖' => 'höske',
    '🏘' => 'wenhüsang',
    '🏚' => 'ruiin',
    '🏠' => 'wenhüs',
    '🏡' => 'wenhüs mä guard',
    '🏢' => 'büroo hüs',
    '🏣' => 'Japoonsk post hüs',
    '🏤' => 'post hüs',
    '🏥' => 'kraankenhüs',
    '🏦' => 'beenk hüs',
    '🏨' => 'hotel',
    '🏩' => 'stünjen hotel',
    '🏪' => 'kuuplooden',
    '🏫' => 'skuul',
    '🏬' => 'kuuphüs',
    '🏭' => 'fabrik',
    '🏯' => 'Japoonsk borag',
    '🏰' => 'sloot',
    '💒' => 'sark bradlep',
    '🗼' => 'Tokio türn',
    '🗽' => 'freihaidsdenkmool',
    '⛪' => 'sark',
    '🕌' => 'moschee',
    '🛕' => 'hindu tempel',
    '🕍' => 'sünagoog',
    '⛩' => 'shinto puurt',
    '🕋' => 'kaaba',
    '⛲' => 'kwel',
    '⛺' => 'telt',
    '🌁' => 'stääd mä mist',
    '🌃' => 'stääd uun a naacht',
    '🏙' => 'stääd üüb en dai',
    '🌄' => 'san gongt ap auer berger',
    '🌅' => 'san gongt ap auer sia',
    '🌆' => 'stääd uun’t hualewjonken',
    '🌇' => 'san gongt ap uun a stääd',
    '🌉' => 'brag uun a naacht',
    '♨' => 'hiat kwel',
    '🎠' => 'karusel hingst',
    '🛝' => 'glidjlis',
    '🎡' => 'riisenwel',
    '🎢' => 'aachterboon',
    '💈' => 'amklaper pual',
    '🎪' => 'sirkus telt',
    '🚂' => 'damp iisenboon',
    '🚃' => 'wagon',
    '🚄' => 'huuch faard boon',
    '🚅' => 'gau faard boon',
    '🚆' => 'iisenboon',
    '🚇' => 'u-boon',
    '🚈' => 'stäädboon',
    '🚉' => 'boonhoof',
    '🚊' => 'struatenboon',
    '🚝' => 'ian skiin boon',
    '🚞' => 'berag boon',
    '🚋' => 'struatenboon waanj',
    '🚌' => 'bus',
    '🚍' => 'kemen bus',
    '🚎' => 'o-bus',
    '🚐' => 'minibus',
    '🚑' => 'kraankenwaanj',
    '🚒' => 'feuerweer auto',
    '🚓' => 'politsei auto',
    '🚔' => 'kemen politsei auto',
    '🚕' => 'taksi',
    '🚖' => 'kemen taksi',
    '🚗' => 'auto',
    '🚘' => 'kemen auto',
    '🚙' => 'SUV',
    '🛻' => 'pickup waanj',
    '🚚' => 'leewerwaanj',
    '🚛' => 'lastwaanj',
    '🚜' => 'treker',
    '🏎' => 'räänwaanj',
    '🏍' => 'motoorwel',
    '🛵' => 'motoor roler',
    '🦽' => 'rolstuul',
    '🦼' => 'motoor rolstuul',
    '🛺' => 'rikscha auto',
    '🚲' => 'wel',
    '🛴' => 'roler',
    '🛹' => 'skateburd',
    '🛼' => 'rolskuch',
    '🚏' => 'bus haltesteed',
    '🛣' => 'autoboon',
    '🛤' => 'iisenboon skiinen',
    '🛢' => 'ööle fäät',
    '⛽' => 'bensiin pomp',
    '🛞' => 'sjüürwel',
    '🚨' => 'ruad laacht',
    '🚥' => 'ampel wairocht',
    '🚦' => 'ampel luadrocht',
    '🛑' => 'stop skilt',
    '🚧' => 'bausteed',
    '⚓' => 'anker',
    '🛟' => 'redangsring',
    '⛵' => 'siilbuat',
    '🛶' => 'kaanu',
    '🚤' => 'räänbuat',
    '🛳' => 'pasajiir damper',
    '⛴' => 'damper',
    '🛥' => 'motoorbuat',
    '🚢' => 'skap',
    '✈' => 'fliiger',
    '🛩' => 'letj fliiger',
    '🛫' => 'fliiger laft uf',
    '🛬' => 'fliiger lunagt',
    '🪂' => 'glidjskirem',
    '💺' => 'satplaats',
    '🚁' => 'heeli',
    '🚟' => 'sweew boon',
    '🚠' => 'berag gondel boon',
    '🚡' => 'gondel boon',
    '🛰' => 'satelit',
    '🚀' => 'rakeet',
    '🛸' => 'UFO',
    '🛎' => 'hotel klook',
    '🧳' => 'kofer',
    '⌛' => 'stünjenglääs fol',
    '⏳' => 'stünjenglääs leesag',
    '⌚' => 'iarembian klook',
    '⏰' => 'weker klook',
    '⏱' => 'stop klook',
    '⏲' => 'meed klook',
    '🕰' => 'dörnsk klook',
    '🕛' => 'klook twaalew',
    '🕧' => 'klook hualew ian',
    '🕐' => 'klook ian',
    '🕜' => 'klook hualew tau',
    '🕑' => 'klook tau',
    '🕝' => 'klook hualew trii',
    '🕒' => 'klook trii',
    '🕞' => 'klook hualew sjauer',
    '🕓' => 'klook sjauer',
    '🕟' => 'klook hualew fiiw',
    '🕔' => 'klook fiiw',
    '🕠' => 'klook hualew sääks',
    '🕕' => 'klook sääks',
    '🕡' => 'klook hualew sööwen',
    '🕖' => 'klook sööwen',
    '🕢' => 'klook hualew aacht',
    '🕗' => 'klook aacht',
    '🕣' => 'klook hualew njügen',
    '🕘' => 'klook njügen',
    '🕤' => 'klook hualew tjiin',
    '🕙' => 'klook tjiin',
    '🕥' => 'klook hualew elwen',
    '🕚' => 'klook elwen',
    '🕦' => 'klook hualew twaalew',
    '🌑' => 'neimuun',
    '🌒' => 'tunem muun iarst sjuarden',
    '🌓' => 'iarst hualew muun',
    '🌔' => 'tunemen muun traad sjuarden',
    '🌕' => 'folmuun',
    '🌖' => 'ufnemen muun iarst sjuarden',
    '🌗' => 'leetst hualew muun',
    '🌘' => 'ufnemen muun traad sjuarden',
    '🌙' => 'muun sakel',
    '🌚' => 'neimuun laachet',
    '🌛' => 'muun sakel laachet iarst sjuarden',
    '🌜' => 'muun sakel laachet leetst sjuarden',
    '🌡' => 'termomeeter',
    '☀' => 'san',
    '🌝' => 'folmuun laachet',
    '🌞' => 'san laachet',
    '🪐' => 'planeet mä ring',
    '⭐' => 'stäär',
    '🌟' => 'glamen stäär',
    '🌠' => 'meteoor',
    '🌌' => 'moolkstruat',
    '☁' => 'swark',
    '⛅' => 'san bääft swark',
    '⛈' => 'swark mä laid an rin',
    '🌤' => 'san bääft letj swark',
    '🌥' => 'san bääft grat swark',
    '🌦' => 'san bääft rin swark',
    '🌧' => 'swark mä rin',
    '🌨' => 'swark mä snä',
    '🌩' => 'swark mä laid',
    '🌪' => 'horelwinj',
    '🌫' => 'mist',
    '🌬' => 'swark püüstet',
    '🌀' => 'tsükloon',
    '🌈' => 'rinböög',
    '🌂' => 'rinskirem tu',
    '☂' => 'rinskirem eeben',
    '☔' => 'rinskirem mä rindrööber',
    '⛱' => 'sanskirem bi strun',
    '⚡' => 'huuch späänang',
    '❄' => 'snä kristal',
    '☃' => 'snämaan mä snä',
    '⛄' => 'snämaan saner snä',
    '☄' => 'komeet',
    '🔥' => 'ial',
    '💧' => 'drööb',
    '🌊' => 'weeder waag',
    '🎃' => 'halloween kürbis',
    '🎄' => 'tanebuum',
    '🎆' => 'ialwerk',
    '🎇' => 'wonerkerts',
    '🧨' => 'knaler',
    '✨' => 'fonkler',
    '🎈' => 'balong',
    '🎉' => 'konfeti sjiter',
    '🎊' => 'konfeti baal',
    '🎋' => 'tanabata buum',
    '🎍' => 'bambus straus',
    '🎎' => 'japoonsk popin',
    '🎏' => 'karp flag',
    '🎐' => 'winjspal',
    '🎑' => 'muun uunluke',
    '🧧' => 'ruad amslach',
    '🎀' => 'ruad sleuf',
    '🎁' => 'goow',
    '🎗' => 'seenk sleuf',
    '🎟' => 'iinläät koorden',
    '🎫' => 'koord',
    '🎖' => 'orden',
    '🏆' => 'pokool',
    '🏅' => 'sport medalje',
    '🥇' => 'iarst pris medalje',
    '🥈' => 'naist pris medalje',
    '🥉' => 'traad pris medalje',
    '⚽' => 'futbaal',
    '⚾' => 'slachbaal',
    '🥎' => 'softbaal',
    '🏀' => 'basketbaal',
    '🏐' => 'volleybaal',
    '🏈' => 'amerikoonsk futbaal',
    '🏉' => 'rugby futbaal',
    '🎾' => 'tenisbaal',
    '🥏' => 'frisbii',
    '🎳' => 'bowling',
    '🏏' => 'cricket',
    '🏑' => 'fial hockey',
    '🏒' => 'is hockey',
    '🥍' => 'lacrosse',
    '🏓' => 'boosel tenis',
    '🏸' => 'feederbaal',
    '🥊' => 'box hoonskuch',
    '🥋' => 'stridj konst tjüch',
    '🥅' => 'futbaal toor',
    '⛳' => 'flag uun hool',
    '⛸' => 'skor',
    '🎣' => 'angel stook',
    '🤿' => 'dük bral',
    '🎽' => 'rään sjürt',
    '🎿' => 'schii',
    '🛷' => 'sled',
    '🥌' => 'curling stook',
    '🎯' => 'bullseye',
    '🪀' => 'jojo',
    '🪁' => 'loft draag',
    '🔫' => 'weeder pistool',
    '🎱' => 'biljaard 8 baal',
    '🔮' => 'glääskuugel',
    '🪄' => 'troolstook',
    '🎮' => 'wiideo spal',
    '🕹' => 'joystick',
    '🎰' => 'lok spal maskiin',
    '🎲' => 'dööbel',
    '🧩' => 'pusel stak',
    '🧸' => 'teddy beer',
    '🪅' => 'pinjata',
    '🪩' => 'speegel baal',
    '🪆' => 'matroschka',
    '♠' => 'piken',
    '♥' => 'harten',
    '♦' => 'rütjen',
    '♣' => 'krüsen',
    '♟' => 'schach büür',
    '🃏' => 'joker',
    '🀄' => 'mahjong ruad draag',
    '🎴' => 'spelkoord',
    '🎭' => 'teooter spal',
    '🖼' => 'bil mä raam',
    '🎨' => 'moolburd',
    '🧵' => 'triad',
    '🪡' => 'seinäädel',
    '🧶' => 'juarn',
    '🪢' => 'knoot',
    '👓' => 'bral',
    '🕶' => 'sanbral',
    '🥽' => 'swäämbral',
    '🥼' => 'kitel',
    '🦺' => 'seekerhaidswest',
    '👔' => 'slips',
    '👕' => 't-shirt',
    '👖' => 'lanenboks',
    '🧣' => 'sjool',
    '🧤' => 'hoonkluader',
    '🧥' => 'jak',
    '🧦' => 'höösen',
    '👗' => 'kleet',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'baaseuuntooch',
    '🩲' => 'baaseboks',
    '🩳' => 'kurt boks',
    '👙' => 'bikini',
    '👚' => 'bluus',
    '🪭' => 'weier',
    '👛' => 'jilkniper',
    '👜' => 'hunskrääp',
    '👝' => 'letj hunskrääp',
    '🛍' => 'äärn pöös',
    '🎒' => 'ruksääk',
    '🩴' => 'tuan tofel',
    '👞' => 'maan skuch',
    '👟' => 'rään skuch',
    '🥾' => 'waaner skuch',
    '🥿' => 'flaak skuch',
    '👠' => 'huuch haielt skuch',
    '👡' => 'wüf skuch',
    '🩰' => 'balet skuch',
    '👢' => 'wüf steewel',
    '🪮' => 'kum',
    '👑' => 'krüün',
    '👒' => 'wüf hud',
    '🎩' => 'maan hud',
    '🎓' => 'dokter hud',
    '🧢' => 'skirem mots',
    '🪖' => 'soldooten helem',
    '⛑' => 'halper helem',
    '📿' => 'ruus kraans',
    '💄' => 'lap stook',
    '💍' => 'ring',
    '💎' => 'diamant',
    '🔇' => 'stal tuun',
    '🔈' => 'letjem tuun',
    '🔉' => 'madel tuun',
    '🔊' => 'gratem tuun',
    '📢' => 'elektrisk megafoon',
    '📣' => 'megafoon',
    '📯' => 'post hurn',
    '🔔' => 'sark klook',
    '🔕' => 'klook stregen',
    '🎼' => 'musiik nuutenrä',
    '🎵' => 'musiik nuut',
    '🎶' => 'musiik nuuten',
    '🎙' => 'studio mikrofoon',
    '🎚' => 'sküüw reegler',
    '🎛' => 'drei reegler',
    '🎤' => 'hun mikrofoon',
    '🎧' => 'uar hiarer',
    '📻' => 'raadio',
    '🎷' => 'saksofoon',
    '🎺' => 'trompeet',
    '🪊' => 'posaun',
    '🪗' => 'akordeon',
    '🎸' => 'gitaar',
    '🎹' => 'klawiar',
    '🎻' => 'gichel',
    '🪕' => 'banjo',
    '🥁' => 'trumel',
    '🪘' => 'lung trumel',
    '🪇' => 'marakas',
    '🪈' => 'fleut',
    '🪉' => 'harp',
    '📱' => 'handy',
    '📲' => 'handy mä piil',
    '☎' => 'tilefoon',
    '📞' => 'tilefoon hiarer',
    '📟' => 'pager',
    '📠' => 'faks aperoot',
    '🔋' => 'baterii',
    '🪫' => 'baterii leesag',
    '🔌' => 'elektro steeger',
    '💻' => 'laptop',
    '🖥' => 'kompjuuter',
    '🖨' => 'druker',
    '⌨' => 'tastatuur',
    '🖱' => 'kompjuuter müs',
    '🖲' => 'trackbaal',
    '💽' => 'mini disk',
    '💾' => 'floppy disk',
    '💿' => 'kompjuuter disk',
    '📀' => 'dvd',
    '🧮' => 'abakus',
    '🎥' => 'film kamera',
    '🎞' => 'stak film',
    '📽' => 'film projektor',
    '🎬' => 'film klap',
    '📺' => 'fernseen',
    '📷' => 'knipser',
    '📸' => 'knipser mä laid',
    '📹' => 'wiideo kamera',
    '📼' => 'wiideo kaset',
    '🔍' => 'fergrater glääs lachts',
    '🔎' => 'fergrater glääs rochts',
    '🕯' => 'tualaglaacht',
    '💡' => 'elektro peer',
    '🔦' => 'lochter',
    '🏮' => 'ruad papiir latern',
    '🪔' => 'ööle lamp',
    '📔' => 'daibuk',
    '📕' => 'slööden buk',
    '📖' => 'eeben buk',
    '📗' => 'green buk',
    '📘' => 'blä buk',
    '📙' => 'orangj buk',
    '📚' => 'buken',
    '📓' => 'skriiwbuk',
    '📒' => 'kasenbuk',
    '📃' => 'bleed mä kral',
    '📜' => 'bleed mä kralen',
    '📄' => 'bleed mä skraft',
    '📰' => 'bleed',
    '🗞' => 'aprolet bleed',
    '📑' => 'lees tiaken',
    '🔖' => 'lees tiaken mä triad',
    '🏷' => 'etiket',
    '🪙' => 'jilstak',
    '💰' => 'jilsääk',
    '🪎' => 'gulkast',
    '💴' => 'yen jilskiin',
    '💵' => 'dooler jilskiin',
    '💶' => 'euro jilskiin',
    '💷' => 'pünj jilskiin',
    '💸' => 'jilskiin mä jügen',
    '💳' => 'kredit koord',
    '🧾' => 'kasen seedel',
    '💹' => 'diagram uunstiigen mä yen',
    '✉' => 'amslach',
    '📧' => 'e-mail',
    '📨' => 'amslach wechsjüür',
    '📩' => 'amslach mä piil',
    '📤' => 'briaw ütjgung kurew',
    '📥' => 'briaw iingung kurew',
    '📦' => 'pakeet',
    '📫' => 'postkasche mä flag huuch',
    '📪' => 'postkasche mä flag deel',
    '📬' => 'eeben postkasche mä flag huuch',
    '📭' => 'eeben postkasche mä flag deel',
    '📮' => 'postkasche',
    '🗳' => 'woolkasche mä stemseedel',
    '✏' => 'pokluad',
    '✒' => 'skriiwfeeder',
    '🖋' => 'feederhalter',
    '🖊' => 'kuugelskriiwer',
    '🖌' => 'pensel',
    '🖍' => 'bruket pokluad',
    '📝' => 'smerseedel',
    '💼' => 'aktenskrääp',
    '📁' => 'aktenmap',
    '📂' => 'eeben aktenmap',
    '🗂' => 'akten dialer',
    '📅' => 'kalender',
    '📆' => 'ufriiw kalender',
    '🗒' => 'spiraal buk',
    '🗓' => 'spiraal kalender',
    '📇' => 'koord indeks',
    '📈' => 'uunstiigen diagram',
    '📉' => 'ufstiigen diagram',
    '📊' => 'türn diagram',
    '📋' => 'seedelburd',
    '📌' => 'traknäädel',
    '📍' => 'trinj traknäädel',
    '📎' => 'büroo klääm',
    '🖇' => 'ferbünjen büroo kläämen',
    '📏' => 'linjeool',
    '📐' => 'tiaken triihuk',
    '✂' => 'sjuar',
    '🗃' => 'kartei kasche',
    '🗄' => 'aktenskaab',
    '🗑' => 'papiirkurew',
    '🔒' => 'sloot tu',
    '🔓' => 'sloot eeben',
    '🔏' => 'sloot tu mä feeder',
    '🔐' => 'sloot tu mä kai',
    '🔑' => 'kai',
    '🗝' => 'ual kai',
    '🔨' => 'höömerk',
    '🪓' => 'ääks',
    '⛏' => 'pikääks',
    '⚒' => 'höömerk an pikääks',
    '🛠' => 'höömerk an skrüüwenkai',
    '🗡' => 'swörd',
    '⚔' => 'swörden auerkrüs',
    '💣' => 'bomb',
    '🪃' => 'buumerang',
    '🏹' => 'piil an böög',
    '🛡' => 'skilt',
    '🪚' => 'holtseeg',
    '🔧' => 'skrüüwenkai',
    '🪛' => 'skrüüwendreier',
    '🔩' => 'boolt an möderk',
    '⚙' => 'kumwel',
    '🗜' => 'tswing',
    '⚖' => 'waag',
    '🦯' => 'blinjenstook',
    '🔗' => 'keed',
    '⛓' => 'keeden',
    '🪝' => 'haag',
    '🧰' => 'werktjüchkasche',
    '🧲' => 'magneet',
    '🪜' => 'lääder',
    '🪏' => 'skofel',
    '⚗' => 'destiliar glääs',
    '🧪' => 'reagens glääs',
    '🧫' => 'petri skeel',
    '🧬' => 'dna',
    '🔬' => 'mikroskoop',
    '🔭' => 'teleskoop',
    '📡' => 'satelit anten',
    '💉' => 'sprütj',
    '🩸' => 'blud drööb',
    '💊' => 'tablet',
    '🩹' => 'plooster',
    '🩼' => 'krak',
    '🩺' => 'stetoskoop',
    '🩻' => 'röntgen bil',
    '🚪' => 'dör',
    '🛗' => 'aptooch',
    '🪞' => 'speegel',
    '🪟' => 'wönang',
    '🛏' => 'baad',
    '🛋' => 'suufa an lamp',
    '🪑' => 'stuul',
    '🚽' => 'sekreet',
    '🪠' => 'pümpel',
    '🚿' => 'duusje',
    '🛁' => 'baasebale',
    '🪤' => 'müs trap',
    '🪒' => 'raagknif',
    '🧴' => 'siap butel',
    '🧷' => 'seekerhaidsnäädel',
    '🧹' => 'beesem',
    '🧺' => 'kurew',
    '🧻' => 'sekreetpapiir',
    '🪣' => 'amer',
    '🧼' => 'siap',
    '🫧' => 'bleesen',
    '🪥' => 'tusbasel',
    '🧽' => 'swaamp',
    '🧯' => 'ial dääsker',
    '🛒' => 'iinkuupswaanj',
    '🚬' => 'sigaret',
    '⚰' => 'kast',
    '🪦' => 'likstian',
    '⚱' => 'urne',
    '🧿' => 'nazar amulet',
    '🪬' => 'hamsa amulet',
    '🗿' => 'moai',
    '🪧' => 'plakoot',
    '🪪' => 'ütjwis',
    '🏧' => 'jil automoot',
    '🚮' => 'uffaal amer',
    '🚰' => 'drankweeder',
    '♿' => 'rolstuul tiaken',
    '🚹' => 'maaner sekreet',
    '🚺' => 'wüfen sekreet',
    '🚻' => 'sekreet tiaken',
    '🚼' => 'baby tiaken',
    '🚾' => 'weeder sekreet',
    '🛂' => 'paas kontrol',
    '🛃' => 'tol kontrol',
    '🛄' => 'kofer bian',
    '🛅' => 'koffer fääk',
    '⚠' => 'üübpaase',
    '🚸' => 'jongen üüb a stich',
    '⛔' => 'iingung ferbeeden',
    '🚫' => 'ferbeeden',
    '🚳' => 'nian welen',
    '🚭' => 'riken ferbeeden',
    '🚯' => 'nään uffaal wechsmitj',
    '🚱' => 'nian drankweeder',
    '🚷' => 'nian futgengern',
    '📵' => 'nian handy',
    '🔞' => 'oner 18 ferbeeden',
    '☢' => 'raadioaktiif',
    '☣' => 'bio gefoor',
    '⬆' => 'ap piil',
    '↗' => 'rochts ap piil',
    '➡' => 'rochts piil',
    '↘' => 'rochts deel piil',
    '⬇' => 'deel piil',
    '↙' => 'lachts deel piil',
    '⬅' => 'lachts piil',
    '↖' => 'lachts ap piil',
    '↕' => 'ap deel piil',
    '↔' => 'rochts lachts piil',
    '↩' => 'lachts am piil',
    '↪' => 'rochts am piil',
    '⤴' => 'ap am piil',
    '⤵' => 'deel am piil',
    '🔃' => 'klookwiis piiler',
    '🔄' => 'jin klookwiis piiler',
    '🔙' => 'turag piil',
    '🔚' => 'aanj piil',
    '🔛' => 'uun dobelpiil',
    '🔜' => 'bal piil',
    '🔝' => 'toop piil',
    '🛐' => 'beedge steed',
    '⚛' => 'atoom tiaken',
    '🕉' => 'om tiaken',
    '✡' => 'juuden stäär',
    '☸' => 'dharma wel',
    '☯' => 'yin yang',
    '✝' => 'krastelk krüs',
    '☦' => 'orthodoks krüs',
    '☪' => 'stäär an hualewmuun',
    '☮' => 'frees tiaken',
    '🕎' => 'menorah',
    '🔯' => 'juuden stäär mä ponkt',
    '🪯' => 'khanda',
    '♈' => 'stäärbil room',
    '♉' => 'stäärbil hole',
    '♊' => 'stäärbil twanlanger',
    '♋' => 'stäärbil kraab',
    '♌' => 'stäärbil lööw',
    '♍' => 'stäärbil jongfoomen',
    '♎' => 'stäärbil waag',
    '♏' => 'stäärbil skorpioon',
    '♐' => 'stäärbil böögsjiter',
    '♑' => 'stäärbil stianbok',
    '♒' => 'stäärbil weedermaan',
    '♓' => 'stäärbil fasker',
    '⛎' => 'stäärbil slaang',
    '🔀' => 'spöörwaksel knoop',
    '🔁' => 'wederhaale knoop',
    '🔂' => 'iansis wederhaale knoop',
    '▶' => 'ufspele knoop',
    '⏩' => 'gau föörütj knoop',
    '⏭' => 'naist stak knoop',
    '⏯' => 'skoft of widjer knoop',
    '◀' => 'turag knoop',
    '⏪' => 'gau turag knoop',
    '⏮' => 'leetst stak knoop',
    '🔼' => 'ap knoop',
    '⏫' => 'gau ap knoop',
    '🔽' => 'deel knoop',
    '⏬' => 'gau deel knoop',
    '⏸' => 'skoft knoop',
    '⏹' => 'stop knoop',
    '⏺' => 'apnem knoop',
    '⏏' => 'ütjsmitj knoop',
    '🎦' => 'kiino',
    '🔅' => 'jonker knoop',
    '🔆' => 'laachter knoop',
    '📶' => 'anten diagram',
    '🛜' => 'funk tiaken',
    '📳' => 'sködel muude',
    '📴' => 'handy ütj',
    '♀' => 'wiifelk tiaken',
    '♂' => 'menelk tiaken',
    '⚧' => 'transgender tiaken',
    '✖' => 'moolnem',
    '➕' => 'plus',
    '➖' => 'minus',
    '➗' => 'dial',
    '🟰' => 'stark likedenang',
    '♾' => 'ünentelk',
    '‼' => 'dobel ütjrep tiaken',
    '⁉' => 'ütjrep an fraag tiaken',
    '❓' => 'ruad fraag tiaken',
    '❔' => 'witj fraag tiaken',
    '❕' => 'witj ütjrep tiaken',
    '❗' => 'ruad ütjrep tiaken',
    '〰' => 'waag tiaken',
    '💱' => 'jil bütje',
    '💲' => 'dooler tiaken',
    '⚕' => 'medesiin tiaken',
    '♻' => 'recycling tiaken',
    '⚜' => 'fleur de lis',
    '🔱' => 'trii tinj tiaken',
    '📛' => 'nööm skilt',
    '🔰' => 'Japoonsk beganer tiaken',
    '⭕' => 'hool ruad kreis',
    '✅' => 'ufhaaget tiaken knoop',
    '☑' => 'ufhaaget tiaken mä kasche',
    '✔' => 'ufhaaget tiaken',
    '❌' => 'trochstregen tiaken',
    '❎' => 'trochstregen knoop',
    '➰' => 'kral',
    '➿' => 'dobel kral',
    '〽' => 'part alternation tiaken',
    '✳' => 'ponkt mä aacht strualen',
    '✴' => 'stäär mä aacht strualen',
    '❇' => 'skürne',
    '™' => 'markin tiaken',
    '🫟' => 'plak',
    '🔠' => 'grat buksteewen',
    '🔡' => 'letj buksteewen',
    '🔢' => 'taalen',
    '🔣' => 'sümboolen',
    '🔤' => 'latiinsk buksteewen',
    '🅰' => 'bludskööl A',
    '🆎' => 'bludskööl AB',
    '🅱' => 'bludskööl B',
    '🆑' => 'CL knoop',
    '🆒' => 'cool knoop',
    '🆓' => 'free knoop',
    'ℹ' => 'informatsion',
    '🆔' => 'ID knoop',
    'Ⓜ' => 'M uun kreis',
    '🆕' => 'NEW knoop',
    '🆖' => 'NG knoop',
    '🅾' => 'bludskööl 0',
    '🆗' => 'OK knoop',
    '🅿' => 'P knoop',
    '🆘' => 'SOS knoop',
    '🆙' => 'UP! knoop',
    '🆚' => 'VS knoop',
    '🈁' => 'Japoonsk ‘heer’ knoop',
    '🈂' => 'Japoonsk ‘drankjil’ knoop',
    '🈷' => 'Japoonsk ‘muun pris’ knoop',
    '🈶' => 'Japoonsk ‘ei amsunst’ knoop',
    '🈯' => 'Japoonsk ‘reserwiaret’ knoop',
    '🉐' => 'Japoonsk ‘geleegenhaid’ knoop',
    '🈹' => 'Japoonsk ‘bilag’ knoop',
    '🈚' => 'Japoonsk ‘amsunst’ knoop',
    '🈲' => 'Japoonsk ‘ferbeeden’ knoop',
    '🉑' => 'Japoonsk ‘as gud’ knoop',
    '🈸' => 'Japoonsk ‘uundrach’ knoop',
    '🈴' => 'Japoonsk ‘lingt so’ knoop',
    '🈳' => 'Japoonsk ‘frei’ knoop',
    '㊗' => 'Japoonsk ‘gratliare’ knoop',
    '㊙' => 'Japoonsk ‘gehiam’ knoop',
    '🈺' => 'Japoonsk ‘eeben’ knoop',
    '🈵' => 'Japoonsk ‘besaat’ knoop',
    '🔴' => 'ruad kreis',
    '🟠' => 'orangj kreis',
    '🟡' => 'güül kreis',
    '🟢' => 'green kreis',
    '🔵' => 'blä kreis',
    '🟣' => 'brons kreis',
    '🟤' => 'brün kreis',
    '⚫' => 'suart kreis',
    '⚪' => 'witj kreis',
    '🟥' => 'ruad kwadroot',
    '🟧' => 'orangj kwadroot',
    '🟨' => 'güül kwadroot',
    '🟩' => 'green kwadroot',
    '🟦' => 'blä kwadroot',
    '🟪' => 'brons kwadroot',
    '🟫' => 'brün kwadroot',
    '⬛' => 'grat suart kwadroot',
    '⬜' => 'grat witj kwadroot',
    '◼' => 'madelgrat suart kwadroot',
    '◻' => 'madelgrat witj kwadroot',
    '◾' => 'madelletj suart kwadroot',
    '◽' => 'madelletj witj kwadroot',
    '▪' => 'letj suart kwadroot',
    '▫' => 'letj witj kwadroot',
    '🔶' => 'grat orangj rütj',
    '🔷' => 'grat blä rütj',
    '🔸' => 'letj orangj rütj',
    '🔹' => 'letj blä rütj',
    '🔺' => 'ruad triihuk ap',
    '🔻' => 'ruad triihuk deel',
    '💠' => 'blä rütj mä ponkt',
    '🔘' => 'trinj blä knoop',
    '🔳' => 'witj kwadroot knoop',
    '🔲' => 'suart kwadroot knoop',
    '🏁' => 'kariaret flag',
    '🚩' => 'triihuket flag',
    '🎌' => 'auerkrüs flagen',
    '🏴' => 'suart flag',
    '🏳' => 'witj flag',
];
